@@ -16,15 +16,6 @@
 #import <video_player_avfoundation/FVPNativeVideoViewFactory.h>
 #endif
 
-// TODO(stuartmorgan): Convert to using mock registrars instead.
-NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
-#if TARGET_OS_IOS
-  return (NSObject<FlutterPluginRegistry> *)[[UIApplication sharedApplication] delegate];
-#else
-  return (FlutterViewController *)NSApplication.sharedApplication.windows[0].contentViewController;
-#endif
-}
-
 #if TARGET_OS_IOS
 @interface FakeAVAssetTrack : AVAssetTrack
 @property(readonly, nonatomic) CGAffineTransform preferredTransform;
@@ -91,6 +82,26 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 
 @end
 
+// Convience to avoid having two copies of the StubViewProvider code.
+#if TARGET_OS_OSX
+#define PROVIDED_VIEW_TYPE NSView
+#else
+#define PROVIDED_VIEW_TYPE UIView
+#endif
+
+@interface StubViewProvider : NSObject <FVPViewProvider>
+- (instancetype)initWithView:(PROVIDED_VIEW_TYPE *)view;
+@property(nonatomic, nullable) PROVIDED_VIEW_TYPE *view;
+@end
+
+@implementation StubViewProvider
+- (instancetype)initWithView:(PROVIDED_VIEW_TYPE *)view {
+  self = [super init];
+  _view = view;
+  return self;
+}
+@end
+
 @interface StubFVPAVFactory : NSObject <FVPAVFactory>
 
 @property(nonatomic, strong) StubAVPlayer *stubAVPlayer;
@@ -126,48 +137,44 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 
 #pragma mark -
 
-/** Test implementation of FVPDisplayLinkFactory that returns a provided display link instance.  */
+@interface StubFVPDisplayLink : NSObject <FVPDisplayLink>
+@property(nonatomic, assign) BOOL running;
+@end
+
+@implementation StubFVPDisplayLink
+- (CFTimeInterval)duration {
+  return 1.0 / 60.0;
+}
+@end
+
+/** Test implementation of FVPDisplayLinkFactory that returns a stub display link instance.  */
 @interface StubFVPDisplayLinkFactory : NSObject <FVPDisplayLinkFactory>
-
 /** This display link to return. */
-@property(nonatomic, strong) FVPDisplayLink *displayLink;
-
-- (instancetype)initWithDisplayLink:(FVPDisplayLink *)displayLink;
-
+@property(nonatomic, strong) StubFVPDisplayLink *displayLink;
+@property(nonatomic, copy) void (^fireDisplayLink)(void);
 @end
 
 @implementation StubFVPDisplayLinkFactory
-- (instancetype)initWithDisplayLink:(FVPDisplayLink *)displayLink {
+- (instancetype)init {
   self = [super init];
-  _displayLink = displayLink;
+  _displayLink = [[StubFVPDisplayLink alloc] init];
   return self;
 }
-- (FVPDisplayLink *)displayLinkWithRegistrar:(id<FlutterPluginRegistrar>)registrar
-                                    callback:(void (^)(void))callback {
+- (NSObject<FVPDisplayLink> *)displayLinkWithRegistrar:(id<FlutterPluginRegistrar>)registrar
+                                              callback:(void (^)(void))callback {
+  self.fireDisplayLink = callback;
   return self.displayLink;
 }
 
 @end
 
-/** Non-test implementation of the diplay link factory. */
-@interface FVPDefaultDisplayLinkFactory : NSObject <FVPDisplayLinkFactory>
-@end
-
-@implementation FVPDefaultDisplayLinkFactory
-- (FVPDisplayLink *)displayLinkWithRegistrar:(id<FlutterPluginRegistrar>)registrar
-                                    callback:(void (^)(void))callback {
-  return [[FVPDisplayLink alloc] initWithRegistrar:registrar callback:callback];
-}
-
-@end
-
 #pragma mark -
 
 @implementation VideoPlayerTests
 
 - (void)testCreateWithOptionsReturnsErrorForInvalidAssetPath {
-  NSObject<FlutterPluginRegistrar> *registrar = [GetPluginRegistry()
-      registrarForPlugin:@"testCreateWithOptionsReturnsErrorForInvalidAssetPath"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  OCMStub([registrar lookupKeyForAsset:[OCMArg any]]).andReturn(nil);
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       [[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
 
@@ -175,9 +182,6 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   [videoPlayerPlugin initialize:&initializationError];
   XCTAssertNil(initializationError);
 
-  id mockRegistrar = OCMPartialMock(registrar);
-  OCMStub([mockRegistrar lookupKeyForAsset:[OCMArg any]]).andReturn(nil);
-
   FVPCreationOptions *create =
       [FVPCreationOptions makeWithAsset:@"invalid/path/to/asset"
                                     uri:nil
@@ -200,10 +204,18 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   // video streams (not just iOS 16).  (https://github.com/flutter/flutter/issues/109116). An
   // invisible AVPlayerLayer is used to overwrite the protection of pixel buffers in those streams
   // for issue #1, and restore the correct width and height for issue #2.
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testPlayerLayerWorkaround"];
-  FVPVideoPlayerPlugin *videoPlayerPlugin =
-      [[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
+#if TARGET_OS_OSX
+  NSView *view = [[NSView alloc] initWithFrame:NSMakeRect(0, 0, 10, 10)];
+  view.wantsLayer = true;
+#else
+  UIView *view = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 10, 10)];
+#endif
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
+       initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:nil output:nil]
+      displayLinkFactory:nil
+            viewProvider:[[StubViewProvider alloc] initWithView:view]
+               registrar:registrar];
 
   FlutterError *error;
   [videoPlayerPlugin initialize:&error];
@@ -224,27 +236,22 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   XCTAssertNotNil(player);
 
   XCTAssertNotNil(player.playerLayer, @"AVPlayerLayer should be present.");
-  XCTAssertNotNil(player.playerLayer.superlayer, @"AVPlayerLayer should be added on screen.");
+  XCTAssertEqual(player.playerLayer.superlayer, view.layer,
+                 @"AVPlayerLayer should be added on screen.");
 }
 
 - (void)testPlayerForPlatformViewDoesNotRegisterTexture {
   NSObject<FlutterTextureRegistry> *mockTextureRegistry =
       OCMProtocolMock(@protocol(FlutterTextureRegistry));
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testPlayerForPlatformViewDoesNotRegisterTexture"];
-  NSObject<FlutterPluginRegistrar> *partialRegistrar = OCMPartialMock(registrar);
-  OCMStub([partialRegistrar textures]).andReturn(mockTextureRegistry);
-  FVPDisplayLink *mockDisplayLink =
-      OCMPartialMock([[FVPDisplayLink alloc] initWithRegistrar:registrar
-                                                      callback:^(){
-                                                      }]);
-  StubFVPDisplayLinkFactory *stubDisplayLinkFactory =
-      [[StubFVPDisplayLinkFactory alloc] initWithDisplayLink:mockDisplayLink];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  OCMStub([registrar textures]).andReturn(mockTextureRegistry);
+  StubFVPDisplayLinkFactory *stubDisplayLinkFactory = [[StubFVPDisplayLinkFactory alloc] init];
   AVPlayerItemVideoOutput *mockVideoOutput = OCMPartialMock([[AVPlayerItemVideoOutput alloc] init]);
   FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
        initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:nil output:mockVideoOutput]
       displayLinkFactory:stubDisplayLinkFactory
-               registrar:partialRegistrar];
+            viewProvider:[[StubViewProvider alloc] initWithView:nil]
+               registrar:registrar];
 
   FlutterError *initalizationError;
   [videoPlayerPlugin initialize:&initalizationError];
@@ -265,21 +272,15 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 - (void)testSeekToWhilePausedStartsDisplayLinkTemporarily {
   NSObject<FlutterTextureRegistry> *mockTextureRegistry =
       OCMProtocolMock(@protocol(FlutterTextureRegistry));
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"SeekToWhilePausedStartsDisplayLinkTemporarily"];
-  NSObject<FlutterPluginRegistrar> *partialRegistrar = OCMPartialMock(registrar);
-  OCMStub([partialRegistrar textures]).andReturn(mockTextureRegistry);
-  FVPDisplayLink *mockDisplayLink =
-      OCMPartialMock([[FVPDisplayLink alloc] initWithRegistrar:registrar
-                                                      callback:^(){
-                                                      }]);
-  StubFVPDisplayLinkFactory *stubDisplayLinkFactory =
-      [[StubFVPDisplayLinkFactory alloc] initWithDisplayLink:mockDisplayLink];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  OCMStub([registrar textures]).andReturn(mockTextureRegistry);
+  StubFVPDisplayLinkFactory *stubDisplayLinkFactory = [[StubFVPDisplayLinkFactory alloc] init];
   AVPlayerItemVideoOutput *mockVideoOutput = OCMPartialMock([[AVPlayerItemVideoOutput alloc] init]);
   FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
        initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:nil output:mockVideoOutput]
       displayLinkFactory:stubDisplayLinkFactory
-               registrar:partialRegistrar];
+            viewProvider:[[StubViewProvider alloc] initWithView:nil]
+               registrar:registrar];
 
   FlutterError *initalizationError;
   [videoPlayerPlugin initialize:&initalizationError];
@@ -307,7 +308,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   [self waitForExpectationsWithTimeout:30.0 handler:nil];
 
   // Seeking to a new position should start the display link temporarily.
-  OCMVerify([mockDisplayLink setRunning:YES]);
+  XCTAssertTrue(stubDisplayLinkFactory.displayLink.running);
   FVPTextureBasedVideoPlayer *player =
       (FVPTextureBasedVideoPlayer *)videoPlayerPlugin.playersByIdentifier[playerIdentifier];
   // Wait for the player's position to update, it shouldn't take long.
@@ -321,37 +322,32 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   OCMStub([mockVideoOutput hasNewPixelBufferForItemTime:kCMTimeZero])
       .ignoringNonObjectArgs()
       .andReturn(YES);
-  // Any non-zero value is fine here since it won't actually be used, just NULL-checked.
-  CVPixelBufferRef fakeBufferRef = (CVPixelBufferRef)1;
+  CVPixelBufferRef bufferRef;
+  CVPixelBufferCreate(NULL, 1, 1, kCVPixelFormatType_32BGRA, NULL, &bufferRef);
   OCMStub([mockVideoOutput copyPixelBufferForItemTime:kCMTimeZero itemTimeForDisplay:NULL])
       .ignoringNonObjectArgs()
-      .andReturn(fakeBufferRef);
+      .andReturn(bufferRef);
   // Simulate a callback from the engine to request a new frame.
-  [player copyPixelBuffer];
+  stubDisplayLinkFactory.fireDisplayLink();
+  CFRelease([player copyPixelBuffer]);
   // Since a frame was found, and the video is paused, the display link should be paused again.
-  OCMVerify([mockDisplayLink setRunning:NO]);
+  XCTAssertFalse(stubDisplayLinkFactory.displayLink.running);
 }
 
 - (void)testInitStartsDisplayLinkTemporarily {
   NSObject<FlutterTextureRegistry> *mockTextureRegistry =
       OCMProtocolMock(@protocol(FlutterTextureRegistry));
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"InitStartsDisplayLinkTemporarily"];
-  NSObject<FlutterPluginRegistrar> *partialRegistrar = OCMPartialMock(registrar);
-  OCMStub([partialRegistrar textures]).andReturn(mockTextureRegistry);
-  FVPDisplayLink *mockDisplayLink =
-      OCMPartialMock([[FVPDisplayLink alloc] initWithRegistrar:registrar
-                                                      callback:^(){
-                                                      }]);
-  StubFVPDisplayLinkFactory *stubDisplayLinkFactory =
-      [[StubFVPDisplayLinkFactory alloc] initWithDisplayLink:mockDisplayLink];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  OCMStub([registrar textures]).andReturn(mockTextureRegistry);
+  StubFVPDisplayLinkFactory *stubDisplayLinkFactory = [[StubFVPDisplayLinkFactory alloc] init];
   AVPlayerItemVideoOutput *mockVideoOutput = OCMPartialMock([[AVPlayerItemVideoOutput alloc] init]);
   StubAVPlayer *stubAVPlayer = [[StubAVPlayer alloc] init];
   FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
        initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:stubAVPlayer
                                                            output:mockVideoOutput]
       displayLinkFactory:stubDisplayLinkFactory
-               registrar:partialRegistrar];
+            viewProvider:[[StubViewProvider alloc] initWithView:nil]
+               registrar:registrar];
 
   FlutterError *initalizationError;
   [videoPlayerPlugin initialize:&initalizationError];
@@ -367,43 +363,38 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   NSNumber *playerIdentifier = [videoPlayerPlugin createWithOptions:create error:&createError];
 
   // Init should start the display link temporarily.
-  OCMVerify([mockDisplayLink setRunning:YES]);
+  XCTAssertTrue(stubDisplayLinkFactory.displayLink.running);
 
   // Simulate a buffer being available.
   OCMStub([mockVideoOutput hasNewPixelBufferForItemTime:kCMTimeZero])
       .ignoringNonObjectArgs()
       .andReturn(YES);
-  // Any non-zero value is fine here since it won't actually be used, just NULL-checked.
-  CVPixelBufferRef fakeBufferRef = (CVPixelBufferRef)1;
+  CVPixelBufferRef bufferRef;
+  CVPixelBufferCreate(NULL, 1, 1, kCVPixelFormatType_32BGRA, NULL, &bufferRef);
   OCMStub([mockVideoOutput copyPixelBufferForItemTime:kCMTimeZero itemTimeForDisplay:NULL])
       .ignoringNonObjectArgs()
-      .andReturn(fakeBufferRef);
+      .andReturn(bufferRef);
   // Simulate a callback from the engine to request a new frame.
   FVPTextureBasedVideoPlayer *player =
       (FVPTextureBasedVideoPlayer *)videoPlayerPlugin.playersByIdentifier[playerIdentifier];
-  [player copyPixelBuffer];
+  stubDisplayLinkFactory.fireDisplayLink();
+  CFRelease([player copyPixelBuffer]);
   // Since a frame was found, and the video is paused, the display link should be paused again.
-  OCMVerify([mockDisplayLink setRunning:NO]);
+  XCTAssertFalse(stubDisplayLinkFactory.displayLink.running);
 }
 
 - (void)testSeekToWhilePlayingDoesNotStopDisplayLink {
   NSObject<FlutterTextureRegistry> *mockTextureRegistry =
       OCMProtocolMock(@protocol(FlutterTextureRegistry));
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"SeekToWhilePlayingDoesNotStopDisplayLink"];
-  NSObject<FlutterPluginRegistrar> *partialRegistrar = OCMPartialMock(registrar);
-  OCMStub([partialRegistrar textures]).andReturn(mockTextureRegistry);
-  FVPDisplayLink *mockDisplayLink =
-      OCMPartialMock([[FVPDisplayLink alloc] initWithRegistrar:registrar
-                                                      callback:^(){
-                                                      }]);
-  StubFVPDisplayLinkFactory *stubDisplayLinkFactory =
-      [[StubFVPDisplayLinkFactory alloc] initWithDisplayLink:mockDisplayLink];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  OCMStub([registrar textures]).andReturn(mockTextureRegistry);
+  StubFVPDisplayLinkFactory *stubDisplayLinkFactory = [[StubFVPDisplayLinkFactory alloc] init];
   AVPlayerItemVideoOutput *mockVideoOutput = OCMPartialMock([[AVPlayerItemVideoOutput alloc] init]);
   FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
        initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:nil output:mockVideoOutput]
       displayLinkFactory:stubDisplayLinkFactory
-               registrar:partialRegistrar];
+            viewProvider:[[StubViewProvider alloc] initWithView:nil]
+               registrar:registrar];
 
   FlutterError *initalizationError;
   [videoPlayerPlugin initialize:&initalizationError];
@@ -429,45 +420,45 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
                    [initializedExpectation fulfill];
                  }];
   [self waitForExpectationsWithTimeout:30.0 handler:nil];
-  OCMVerify([mockDisplayLink setRunning:YES]);
+  XCTAssertTrue(stubDisplayLinkFactory.displayLink.running);
 
   FVPTextureBasedVideoPlayer *player =
       (FVPTextureBasedVideoPlayer *)videoPlayerPlugin.playersByIdentifier[playerIdentifier];
-  XCTAssertEqual([player position], 1234);
+  // Wait for the player's position to update, it shouldn't take long.
+  XCTestExpectation *positionExpectation =
+      [self expectationForPredicate:[NSPredicate predicateWithFormat:@"position == 1234"]
+                evaluatedWithObject:player
+                            handler:nil];
+  [self waitForExpectations:@[ positionExpectation ] timeout:3.0];
 
   // Simulate a buffer being available.
   OCMStub([mockVideoOutput hasNewPixelBufferForItemTime:kCMTimeZero])
       .ignoringNonObjectArgs()
       .andReturn(YES);
-  // Any non-zero value is fine here since it won't actually be used, just NULL-checked.
-  CVPixelBufferRef fakeBufferRef = (CVPixelBufferRef)1;
+  CVPixelBufferRef bufferRef;
+  CVPixelBufferCreate(NULL, 1, 1, kCVPixelFormatType_32BGRA, NULL, &bufferRef);
   OCMStub([mockVideoOutput copyPixelBufferForItemTime:kCMTimeZero itemTimeForDisplay:NULL])
       .ignoringNonObjectArgs()
-      .andReturn(fakeBufferRef);
+      .andReturn(bufferRef);
   // Simulate a callback from the engine to request a new frame.
-  [player copyPixelBuffer];
+  stubDisplayLinkFactory.fireDisplayLink();
+  CFRelease([player copyPixelBuffer]);
   // Since the video was playing, the display link should not be paused after getting a buffer.
-  OCMVerify(never(), [mockDisplayLink setRunning:NO]);
+  XCTAssertTrue(stubDisplayLinkFactory.displayLink.running);
 }
 
 - (void)testPauseWhileWaitingForFrameDoesNotStopDisplayLink {
   NSObject<FlutterTextureRegistry> *mockTextureRegistry =
       OCMProtocolMock(@protocol(FlutterTextureRegistry));
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"PauseWhileWaitingForFrameDoesNotStopDisplayLink"];
-  NSObject<FlutterPluginRegistrar> *partialRegistrar = OCMPartialMock(registrar);
-  OCMStub([partialRegistrar textures]).andReturn(mockTextureRegistry);
-  FVPDisplayLink *mockDisplayLink =
-      OCMPartialMock([[FVPDisplayLink alloc] initWithRegistrar:registrar
-                                                      callback:^(){
-                                                      }]);
-  StubFVPDisplayLinkFactory *stubDisplayLinkFactory =
-      [[StubFVPDisplayLinkFactory alloc] initWithDisplayLink:mockDisplayLink];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  OCMStub([registrar textures]).andReturn(mockTextureRegistry);
+  StubFVPDisplayLinkFactory *stubDisplayLinkFactory = [[StubFVPDisplayLinkFactory alloc] init];
   AVPlayerItemVideoOutput *mockVideoOutput = OCMPartialMock([[AVPlayerItemVideoOutput alloc] init]);
   FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
        initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:nil output:mockVideoOutput]
       displayLinkFactory:stubDisplayLinkFactory
-               registrar:partialRegistrar];
+            viewProvider:[[StubViewProvider alloc] initWithView:nil]
+               registrar:registrar];
 
   FlutterError *initalizationError;
   [videoPlayerPlugin initialize:&initalizationError];
@@ -488,12 +479,11 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   [videoPlayerPlugin pausePlayer:playerIdentifier.integerValue error:&playPauseError];
 
   // Since a buffer hasn't been available yet, the pause should not have stopped the display link.
-  OCMVerify(never(), [mockDisplayLink setRunning:NO]);
+  XCTAssertTrue(stubDisplayLinkFactory.displayLink.running);
 }
 
 - (void)testDeregistersFromPlayer {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testDeregistersFromPlayer"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       (FVPVideoPlayerPlugin *)[[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
 
@@ -525,8 +515,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 }
 
 - (void)testBufferingStateFromPlayer {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testLiveStreamBufferEndFromPlayer"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       (FVPVideoPlayerPlugin *)[[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
 
@@ -570,8 +559,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 }
 
 - (void)testVideoControls {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"TestVideoControls"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       (FVPVideoPlayerPlugin *)[[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
@@ -585,8 +573,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 }
 
 - (void)testAudioControls {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"TestAudioControls"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       (FVPVideoPlayerPlugin *)[[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
@@ -601,8 +588,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 }
 
 - (void)testHLSControls {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"TestHLSControls"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       (FVPVideoPlayerPlugin *)[[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
@@ -616,8 +602,8 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 }
 
 - (void)testAudioOnlyHLSControls {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"TestAudioOnlyHLSControls"];
+  XCTSkip(@"Flaky; see https://github.com/flutter/flutter/issues/164381");
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       (FVPVideoPlayerPlugin *)[[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
@@ -645,8 +631,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 #endif
 
 - (void)testSeekToleranceWhenNotSeekingToEnd {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"TestSeekTolerance"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   StubAVPlayer *stubAVPlayer = [[StubAVPlayer alloc] init];
   StubFVPAVFactory *stubAVFactory = [[StubFVPAVFactory alloc] initWithPlayer:stubAVPlayer
@@ -654,6 +639,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   FVPVideoPlayerPlugin *pluginWithMockAVPlayer =
       [[FVPVideoPlayerPlugin alloc] initWithAVFactory:stubAVFactory
                                    displayLinkFactory:nil
+                                         viewProvider:[[StubViewProvider alloc] initWithView:nil]
                                             registrar:registrar];
 
   FlutterError *initializationError;
@@ -684,8 +670,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 }
 
 - (void)testSeekToleranceWhenSeekingToEnd {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"TestSeekToEndTolerance"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   StubAVPlayer *stubAVPlayer = [[StubAVPlayer alloc] init];
   StubFVPAVFactory *stubAVFactory = [[StubFVPAVFactory alloc] initWithPlayer:stubAVPlayer
@@ -693,6 +678,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   FVPVideoPlayerPlugin *pluginWithMockAVPlayer =
       [[FVPVideoPlayerPlugin alloc] initWithAVFactory:stubAVFactory
                                    displayLinkFactory:nil
+                                         viewProvider:[[StubViewProvider alloc] initWithView:nil]
                                             registrar:registrar];
 
   FlutterError *initializationError;
@@ -781,8 +767,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 //
 // Failing to de-register results in a crash in [AVPlayer willChangeValueForKey:].
 - (void)testDoesNotCrashOnRateObservationAfterDisposal {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testDoesNotCrashOnRateObservationAfterDisposal"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   AVPlayer *avPlayer = nil;
   __weak FVPVideoPlayer *weakPlayer = nil;
@@ -837,8 +822,7 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 // Both of these methods dispatch [FVPVideoPlayer dispose] on the main thread
 // leading to a possible crash when de-registering observers twice.
 - (void)testHotReloadDoesNotCrash {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testHotReloadDoesNotCrash"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   __weak FVPVideoPlayer *weakPlayer = nil;
 
@@ -889,42 +873,32 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 
 #if TARGET_OS_IOS
 - (void)testNativeVideoViewFactoryRegistration {
-  NSObject<FlutterPluginRegistry> *registry = GetPluginRegistry();
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [registry registrarForPlugin:@"testNativeVideoViewFactoryRegistration"];
-  id mockRegistrar = OCMPartialMock(registrar);
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
-  OCMExpect([mockRegistrar
-      registerViewFactory:[OCMArg isKindOfClass:[FVPNativeVideoViewFactory class]]
-                   withId:@"plugins.flutter.dev/video_player_ios"]);
-  [FVPVideoPlayerPlugin registerWithRegistrar:mockRegistrar];
+  OCMExpect([registrar registerViewFactory:[OCMArg isKindOfClass:[FVPNativeVideoViewFactory class]]
+                                    withId:@"plugins.flutter.dev/video_player_ios"]);
+  [FVPVideoPlayerPlugin registerWithRegistrar:registrar];
 
-  OCMVerifyAll(mockRegistrar);
+  OCMVerifyAll(registrar);
 }
 #endif
 
 - (void)testPublishesInRegistration {
-  NSString *pluginKey = @"TestRegistration";
-  NSObject<FlutterPluginRegistry> *registry = GetPluginRegistry();
-  NSObject<FlutterPluginRegistrar> *registrar = [registry registrarForPlugin:pluginKey];
-  id mockRegistrar = OCMPartialMock(registrar);
-  // Empty stub to pass a check in Flutter's engine (double factory registration).
-  // registerWithRegistrar gets called at the beginning of the test, and factory is registered
-  // there. Additional call would try to register the same factory another time, which would fail a
-  // check in the engine.
-  OCMStub([mockRegistrar registerViewFactory:[OCMArg any] withId:[OCMArg any]]);
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  __block NSObject *publishedValue;
+  OCMStub([registrar publish:[OCMArg checkWithBlock:^BOOL(id value) {
+                       publishedValue = value;
+                       return YES;
+                     }]]);
 
-  [FVPVideoPlayerPlugin registerWithRegistrar:mockRegistrar];
-
-  id publishedValue = [registry valuePublishedByPlugin:pluginKey];
+  [FVPVideoPlayerPlugin registerWithRegistrar:registrar];
 
   XCTAssertNotNil(publishedValue);
   XCTAssertTrue([publishedValue isKindOfClass:[FVPVideoPlayerPlugin class]]);
 }
 
 - (void)testFailedToLoadVideoEventShouldBeAlwaysSent {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testFailedToLoadVideoEventShouldBeAlwaysSent"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       [[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
   FlutterError *error;
@@ -958,12 +932,12 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
 }
 
 - (void)testUpdatePlayingStateShouldNotResetRate {
-  NSObject<FlutterPluginRegistrar> *registrar =
-      [GetPluginRegistry() registrarForPlugin:@"testUpdatePlayingStateShouldNotResetRate"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
 
   FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
        initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:nil output:nil]
       displayLinkFactory:nil
+            viewProvider:[[StubViewProvider alloc] initWithView:nil]
                registrar:registrar];
 
   FlutterError *error;
@@ -993,10 +967,82 @@ NSObject<FlutterPluginRegistry> *GetPluginRegistry(void) {
   XCTAssertEqual(player.player.rate, 2);
 }
 
+- (void)testPlayerShouldNotDropEverySecondFrame {
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
+  NSObject<FlutterTextureRegistry> *mockTextureRegistry =
+      OCMProtocolMock(@protocol(FlutterTextureRegistry));
+  OCMStub([registrar textures]).andReturn(mockTextureRegistry);
+
+  StubFVPDisplayLinkFactory *stubDisplayLinkFactory = [[StubFVPDisplayLinkFactory alloc] init];
+  AVPlayerItemVideoOutput *mockVideoOutput = OCMPartialMock([[AVPlayerItemVideoOutput alloc] init]);
+  FVPVideoPlayerPlugin *videoPlayerPlugin = [[FVPVideoPlayerPlugin alloc]
+       initWithAVFactory:[[StubFVPAVFactory alloc] initWithPlayer:nil output:mockVideoOutput]
+      displayLinkFactory:stubDisplayLinkFactory
+            viewProvider:[[StubViewProvider alloc] initWithView:nil]
+               registrar:registrar];
+
+  FlutterError *error;
+  [videoPlayerPlugin initialize:&error];
+  XCTAssertNil(error);
+  FVPCreationOptions *create = [FVPCreationOptions
+      makeWithAsset:nil
+                uri:@"https://flutter.github.io/assets-for-api-docs/assets/videos/bee.mp4"
+        packageName:nil
+         formatHint:nil
+        httpHeaders:@{}
+           viewType:FVPPlatformVideoViewTypeTextureView];
+  NSNumber *playerIdentifier = [videoPlayerPlugin createWithOptions:create error:&error];
+  FVPTextureBasedVideoPlayer *player =
+      (FVPTextureBasedVideoPlayer *)videoPlayerPlugin.playersByIdentifier[playerIdentifier];
+
+  __block CMTime currentTime = kCMTimeZero;
+  OCMStub([mockVideoOutput itemTimeForHostTime:0])
+      .ignoringNonObjectArgs()
+      .andDo(^(NSInvocation *invocation) {
+        [invocation setReturnValue:&currentTime];
+      });
+  __block NSMutableSet *pixelBuffers = NSMutableSet.new;
+  OCMStub([mockVideoOutput hasNewPixelBufferForItemTime:kCMTimeZero])
+      .ignoringNonObjectArgs()
+      .andDo(^(NSInvocation *invocation) {
+        CMTime itemTime;
+        [invocation getArgument:&itemTime atIndex:2];
+        BOOL has = [pixelBuffers containsObject:[NSValue valueWithCMTime:itemTime]];
+        [invocation setReturnValue:&has];
+      });
+  OCMStub([mockVideoOutput copyPixelBufferForItemTime:kCMTimeZero
+                                   itemTimeForDisplay:[OCMArg anyPointer]])
+      .ignoringNonObjectArgs()
+      .andDo(^(NSInvocation *invocation) {
+        CMTime itemTime;
+        [invocation getArgument:&itemTime atIndex:2];
+        CVPixelBufferRef bufferRef = NULL;
+        if ([pixelBuffers containsObject:[NSValue valueWithCMTime:itemTime]]) {
+          CVPixelBufferCreate(NULL, 1, 1, kCVPixelFormatType_32BGRA, NULL, &bufferRef);
+        }
+        [pixelBuffers removeObject:[NSValue valueWithCMTime:itemTime]];
+        [invocation setReturnValue:&bufferRef];
+      });
+  void (^advanceFrame)(void) = ^{
+    currentTime.value++;
+    [pixelBuffers addObject:[NSValue valueWithCMTime:currentTime]];
+  };
+
+  advanceFrame();
+  OCMExpect([mockTextureRegistry textureFrameAvailable:playerIdentifier.intValue]);
+  stubDisplayLinkFactory.fireDisplayLink();
+  OCMVerifyAllWithDelay(mockTextureRegistry, 10);
+
+  advanceFrame();
+  OCMExpect([mockTextureRegistry textureFrameAvailable:playerIdentifier.intValue]);
+  CFRelease([player copyPixelBuffer]);
+  stubDisplayLinkFactory.fireDisplayLink();
+  OCMVerifyAllWithDelay(mockTextureRegistry, 10);
+}
+
 #if TARGET_OS_IOS
 - (void)testVideoPlayerShouldNotOverwritePlayAndRecordNorDefaultToSpeaker {
-  NSObject<FlutterPluginRegistrar> *registrar = [GetPluginRegistry()
-      registrarForPlugin:@"testVideoPlayerShouldNotOverwritePlayAndRecordNorDefaultToSpeaker"];
+  NSObject<FlutterPluginRegistrar> *registrar = OCMProtocolMock(@protocol(FlutterPluginRegistrar));
   FVPVideoPlayerPlugin *videoPlayerPlugin =
       [[FVPVideoPlayerPlugin alloc] initWithRegistrar:registrar];
   FlutterError *error;
