@@ -14,18 +14,14 @@ class CkVertices implements ui.Vertices {
     List<ui.Color>? colors,
     List<int>? indices,
   }) {
-    if (textureCoordinates != null &&
-        textureCoordinates.length != positions.length) {
-      throw ArgumentError(
-          '"positions" and "textureCoordinates" lengths must match.');
+    if (textureCoordinates != null && textureCoordinates.length != positions.length) {
+      throw ArgumentError('"positions" and "textureCoordinates" lengths must match.');
     }
     if (colors != null && colors.length != positions.length) {
       throw ArgumentError('"positions" and "colors" lengths must match.');
     }
-    if (indices != null &&
-        indices.any((int i) => i < 0 || i >= positions.length)) {
-      throw ArgumentError(
-          '"indices" values must be valid indices in the positions list.');
+    if (indices != null && indices.any((int i) => i < 0 || i >= positions.length)) {
+      throw ArgumentError('"indices" values must be valid indices in the positions list.');
     }
 
     return CkVertices._(
@@ -44,18 +40,14 @@ class CkVertices implements ui.Vertices {
     Int32List? colors,
     Uint16List? indices,
   }) {
-    if (textureCoordinates != null &&
-        textureCoordinates.length != positions.length) {
-      throw ArgumentError(
-          '"positions" and "textureCoordinates" lengths must match.');
+    if (textureCoordinates != null && textureCoordinates.length != positions.length) {
+      throw ArgumentError('"positions" and "textureCoordinates" lengths must match.');
     }
     if (colors != null && colors.length * 2 != positions.length) {
       throw ArgumentError('"positions" and "colors" lengths must match.');
     }
-    if (indices != null &&
-        indices.any((int i) => i < 0 || i >= positions.length)) {
-      throw ArgumentError(
-          '"indices" values must be valid indices in the positions list.');
+    if (indices != null && indices.any((int i) => i < 0 || i >= positions.length)) {
+      throw ArgumentError('"indices" values must be valid indices in the positions list.');
     }
 
     Uint32List? unsignedColors;
@@ -72,21 +64,23 @@ class CkVertices implements ui.Vertices {
     );
   }
 
-  CkVertices._(
-    this._mode,
-    this._positions,
-    this._textureCoordinates,
-    this._colors,
-    this._indices,
-  ) {
-    final SkVertices skVertices = canvasKit.MakeVertices(
-      _mode,
-      _positions,
-      _textureCoordinates,
-      _colors,
-      _indices,
-    );
-    _ref = UniqueRef<SkVertices>(this, skVertices, 'Vertices');
+  CkVertices._(this._mode, this._positions, this._textureCoordinates, this._colors, this._indices) {
+    // If [_positions] is empty, then [canvasKit.MakeVertices] will return
+    // `null`, which breaks our JS interop. So, if we see that [_positions] is
+    // empty, we do not create a [SkVertices] object and just treat this as
+    // an empty vertices. Drawing an empty Vertices object is a no-op.
+    if (_positions.isNotEmpty) {
+      final SkVertices skVertices = canvasKit.MakeVertices(
+        _mode,
+        _positions,
+        _textureCoordinates,
+        _colors,
+        _indices,
+      );
+      _ref = UniqueRef<SkVertices>(this, skVertices, 'Vertices');
+    } else {
+      _ref = null;
+    }
   }
 
   final SkVertexMode _mode;
@@ -94,15 +88,20 @@ class CkVertices implements ui.Vertices {
   final Float32List? _textureCoordinates;
   final Uint32List? _colors;
   final Uint16List? _indices;
-  late final UniqueRef<SkVertices> _ref;
+  late final UniqueRef<SkVertices>? _ref;
 
-  SkVertices get skiaObject => _ref.nativeObject;
+  SkVertices get skiaObject => _ref!.nativeObject;
+
+  bool get hasNoPoints => _ref == null;
+
+  bool _isDisposed = false;
 
   @override
   void dispose() {
-    _ref.dispose();
+    _ref?.dispose();
+    _isDisposed = true;
   }
 
   @override
-  bool get debugDisposed => _ref.isDisposed;
+  bool get debugDisposed => _isDisposed;
 }
