@@ -11,30 +11,20 @@ part of dart._engine;
 /// element, so it plays "nice" with other web frameworks.
 class CustomElementEmbeddingStrategy implements EmbeddingStrategy {
   /// Creates a [CustomElementEmbeddingStrategy] to embed a Flutter view into [_hostElement].
-  CustomElementEmbeddingStrategy(this._hostElement) {
-    _hostElement.clearChildren();
+  CustomElementEmbeddingStrategy(this.hostElement) {
+    hostElement.clearChildren();
+    hostElement.setAttribute('flt-embedding', 'custom-element');
   }
 
   @override
   DomEventTarget get globalEventTarget => _rootElement;
 
-  /// The target element in which this strategy will embed the Flutter view.
-  final DomElement _hostElement;
+  @override
+  final DomElement hostElement;
 
   /// The root element of the Flutter view.
   late final DomElement _rootElement;
 
-  @override
-  void initialize({
-    Map<String, String>? hostElementAttributes,
-  }) {
-    // ignore:avoid_function_literals_in_foreach_calls
-    hostElementAttributes?.entries.forEach((MapEntry<String, String> entry) {
-      _setHostAttribute(entry.key, entry.value);
-    });
-    _setHostAttribute('flt-embedding', 'custom-element');
-  }
-
   @override
   void attachViewRoot(DomElement rootElement) {
     rootElement
@@ -42,22 +32,14 @@ class CustomElementEmbeddingStrategy implements EmbeddingStrategy {
       ..style.height = '100%'
       ..style.display = 'block'
       ..style.overflow = 'hidden'
-      ..style.position = 'relative';
+      ..style.position = 'relative'
+      // This is needed so the browser lets flutter handle all pointer events
+      // it receives, without canceling them.
+      ..style.touchAction = 'none';
 
-    _hostElement.appendChild(rootElement);
+    hostElement.appendChild(rootElement);
 
     registerElementForCleanup(rootElement);
     _rootElement = rootElement;
   }
-
-  @override
-  void attachResourcesHost(DomElement resourceHost, {DomElement? nextTo}) {
-    _hostElement.insertBefore(resourceHost, nextTo);
-
-    registerElementForCleanup(resourceHost);
-  }
-
-  void _setHostAttribute(String name, String value) {
-    _hostElement.setAttribute(name, value);
-  }
 }
