@@ -30,6 +30,9 @@ class SkwasmPaint implements ui.Paint {
     final shaderHandle = _shader?.handle;
     if (shaderHandle != null) {
       paintSetShader(rawPaint, shaderHandle);
+      if (_shader!.isGradient) {
+        paintSetDither(rawPaint, true);
+      }
     }
 
     final localMaskFilter = maskFilter;
@@ -53,8 +56,9 @@ class SkwasmPaint implements ui.Paint {
   /// If `invertColors` is true or `colorFilter` is not null, sets the
   /// appropriate Skia color filter. Otherwise, does nothing.
   void _maybeSetEffectiveColorFilter(Pointer<RawPaint> handle) {
-    final nativeFilter =
-        _colorFilter != null ? SkwasmColorFilter.fromEngineColorFilter(_colorFilter!) : null;
+    final nativeFilter = _colorFilter != null
+        ? SkwasmColorFilter.fromEngineColorFilter(_colorFilter!)
+        : null;
     if (invertColors) {
       if (nativeFilter != null) {
         final composedFilter = SkwasmColorFilter.composed(_invertColorFilter, nativeFilter);
