@@ -50,16 +50,16 @@ enum Channel { dev, beta, stable }
 
 String getChannelName(Channel channel) {
   return switch (channel) {
-    Channel.beta   => 'beta',
-    Channel.dev    => 'dev',
+    Channel.beta => 'beta',
+    Channel.dev => 'dev',
     Channel.stable => 'stable',
   };
 }
 
 Channel fromChannelName(String? name) {
   return switch (name) {
-    'beta'   => Channel.beta,
-    'dev'    => Channel.dev,
+    'beta' => Channel.beta,
+    'dev' => Channel.dev,
     'stable' => Channel.stable,
     _ => throw ArgumentError('Invalid channel name.'),
   };
@@ -69,16 +69,16 @@ enum PublishedPlatform { linux, macos, windows }
 
 String getPublishedPlatform(PublishedPlatform platform) {
   return switch (platform) {
-    PublishedPlatform.linux   => 'linux',
-    PublishedPlatform.macos   => 'macos',
+    PublishedPlatform.linux => 'linux',
+    PublishedPlatform.macos => 'macos',
     PublishedPlatform.windows => 'windows',
   };
 }
 
 PublishedPlatform fromPublishedPlatform(String name) {
   return switch (name) {
-    'linux'   => PublishedPlatform.linux,
-    'macos'   => PublishedPlatform.macos,
+    'linux' => PublishedPlatform.linux,
+    'macos' => PublishedPlatform.macos,
     'windows' => PublishedPlatform.windows,
     _ => throw ArgumentError('Invalid published platform name.'),
   };
@@ -150,42 +150,36 @@ class ProcessRunner {
         workingDirectory: workingDirectory.absolute.path,
         environment: environment,
       );
-      process.stdout.listen(
-        (List<int> event) {
-          output.addAll(event);
-          if (subprocessOutput) {
-            stdout.add(event);
-          }
-        },
-        onDone: () async => stdoutComplete.complete(),
-      );
+      process.stdout.listen((List<int> event) {
+        output.addAll(event);
+        if (subprocessOutput) {
+          stdout.add(event);
+        }
+      }, onDone: () async => stdoutComplete.complete());
       if (subprocessOutput) {
-        process.stderr.listen(
-          (List<int> event) {
-            stderr.add(event);
-          },
-          onDone: () async => stderrComplete.complete(),
-        );
+        process.stderr.listen((List<int> event) {
+          stderr.add(event);
+        }, onDone: () async => stderrComplete.complete());
       } else {
         stderrComplete.complete();
       }
     } on ProcessException catch (e) {
-      final String message = 'Running "${commandLine.join(' ')}" in ${workingDirectory.path} '
+      final String message =
+          'Running "${commandLine.join(' ')}" in ${workingDirectory.path} '
           'failed with:\n$e';
       throw UnpublishException(message);
     } on ArgumentError catch (e) {
-      final String message = 'Running "${commandLine.join(' ')}" in ${workingDirectory.path} '
+      final String message =
+          'Running "${commandLine.join(' ')}" in ${workingDirectory.path} '
           'failed with:\n$e';
       throw UnpublishException(message);
     }
 
     final int exitCode = await allComplete();
     if (exitCode != 0 && !failOk) {
-      final String message = 'Running "${commandLine.join(' ')}" in ${workingDirectory.path} failed';
-      throw UnpublishException(
-        message,
-        ProcessResult(0, exitCode, null, 'returned $exitCode'),
-      );
+      final String message =
+          'Running "${commandLine.join(' ')}" in ${workingDirectory.path} failed';
+      throw UnpublishException(message, ProcessResult(0, exitCode, null, 'returned $exitCode'));
     }
     return utf8.decoder.convert(output).trim();
   }
@@ -200,12 +194,12 @@ class ArchiveUnpublisher {
     this.confirmed = false,
     ProcessManager? processManager,
     bool subprocessOutput = true,
-  })  : assert(revisionsBeingRemoved.length == 40),
-        metadataGsPath = '$gsReleaseFolder/${getMetadataFilename(platform)}',
-        _processRunner = ProcessRunner(
-          processManager: processManager ?? const LocalProcessManager(),
-          subprocessOutput: subprocessOutput,
-        );
+  }) : assert(revisionsBeingRemoved.length == 40),
+       metadataGsPath = '$gsReleaseFolder/${getMetadataFilename(platform)}',
+       _processRunner = ProcessRunner(
+         processManager: processManager ?? const LocalProcessManager(),
+         subprocessOutput: subprocessOutput,
+       );
 
   final PublishedPlatform platform;
   final String metadataGsPath;
@@ -214,17 +208,24 @@ class ArchiveUnpublisher {
   final bool confirmed;
   final Directory tempDir;
   final ProcessRunner _processRunner;
-  static String getMetadataFilename(PublishedPlatform platform) => 'releases_${getPublishedPlatform(platform)}.json';
+  static String getMetadataFilename(PublishedPlatform platform) =>
+      'releases_${getPublishedPlatform(platform)}.json';
 
   /// Remove the archive from Google Storage.
   Future<void> unpublishArchive() async {
     final Map<String, dynamic> jsonData = await _loadMetadata();
-    final List<Map<String, String>> releases = (jsonData['releases'] as List<dynamic>).map<Map<String, String>>((dynamic entry) {
-      final Map<String, dynamic> mapEntry = entry as Map<String, dynamic>;
-      return mapEntry.cast<String, String>();
-    }).toList();
+    final List<Map<String, String>> releases = (jsonData['releases'] as List<dynamic>)
+        .map<Map<String, String>>((dynamic entry) {
+          final Map<String, dynamic> mapEntry = entry as Map<String, dynamic>;
+          return mapEntry.cast<String, String>();
+        })
+        .toList();
     final Map<Channel, Map<String, String>> paths = await _getArchivePaths(releases);
-    releases.removeWhere((Map<String, String> value) => revisionsBeingRemoved.contains(value['hash']) && channels.contains(fromChannelName(value['channel'])));
+    releases.removeWhere(
+      (Map<String, String> value) =>
+          revisionsBeingRemoved.contains(value['hash']) &&
+          channels.contains(fromChannelName(value['channel'])),
+    );
     releases.sort((Map<String, String> a, Map<String, String> b) {
       final DateTime aDate = DateTime.parse(a['release_date']!);
       final DateTime bDate = DateTime.parse(b['release_date']!);
@@ -232,22 +233,29 @@ class ArchiveUnpublisher {
     });
     jsonData['releases'] = releases;
     for (final Channel channel in channels) {
-      if (!revisionsBeingRemoved.contains((jsonData['current_release'] as Map<String, dynamic>)[getChannelName(channel)])) {
+      if (!revisionsBeingRemoved.contains(
+        (jsonData['current_release'] as Map<String, dynamic>)[getChannelName(channel)],
+      )) {
         // Don't replace the current release if it's not one of the revisions we're removing.
         continue;
       }
-      final Map<String, String> replacementRelease = releases.firstWhere((Map<String, String> value) => value['channel'] == getChannelName(channel));
-      (jsonData['current_release'] as Map<String, dynamic>)[getChannelName(channel)] = replacementRelease['hash'];
+      final Map<String, String> replacementRelease = releases.firstWhere(
+        (Map<String, String> value) => value['channel'] == getChannelName(channel),
+      );
+      (jsonData['current_release'] as Map<String, dynamic>)[getChannelName(channel)] =
+          replacementRelease['hash'];
       print(
         '${confirmed ? 'Reverting' : 'Would revert'} current ${getChannelName(channel)} '
-        '${getPublishedPlatform(platform)} release to ${replacementRelease['hash']} (version ${replacementRelease['version']}).'
+        '${getPublishedPlatform(platform)} release to ${replacementRelease['hash']} (version ${replacementRelease['version']}).',
       );
     }
     await _cloudRemoveArchive(paths);
     await _updateMetadata(jsonData);
   }
 
-  Future<Map<Channel, Map<String, String>>> _getArchivePaths(List<Map<String, String>> releases) async {
+  Future<Map<Channel, Map<String, String>>> _getArchivePaths(
+    List<Map<String, String>> releases,
+  ) async {
     final Set<String> hashes = <String>{};
     final Map<Channel, Map<String, String>> paths = <Channel, Map<String, String>>{};
     for (final Map<String, String> revision in releases) {
@@ -259,18 +267,20 @@ class ArchiveUnpublisher {
         paths[channel]![hash] = revision['archive']!;
       }
     }
-    final Set<String> missingRevisions = revisionsBeingRemoved.difference(hashes.intersection(revisionsBeingRemoved));
+    final Set<String> missingRevisions = revisionsBeingRemoved.difference(
+      hashes.intersection(revisionsBeingRemoved),
+    );
     if (missingRevisions.isNotEmpty) {
       final bool plural = missingRevisions.length > 1;
-      throw UnpublishException('Revision${plural ? 's' : ''} $missingRevisions ${plural ? 'are' : 'is'} not present in the server metadata.');
+      throw UnpublishException(
+        'Revision${plural ? 's' : ''} $missingRevisions ${plural ? 'are' : 'is'} not present in the server metadata.',
+      );
     }
     return paths;
   }
 
   Future<Map<String, dynamic>> _loadMetadata() async {
-    final File metadataFile = File(
-      path.join(tempDir.absolute.path, getMetadataFilename(platform)),
-    );
+    final File metadataFile = File(path.join(tempDir.absolute.path, getMetadataFilename(platform)));
     // Always run this, even in dry runs.
     await _runGsUtil(<String>['cp', metadataGsPath, metadataFile.absolute.path], confirm: true);
     final String currentMetadata = metadataFile.readAsStringSync();
@@ -293,12 +303,12 @@ class ArchiveUnpublisher {
     // Windows wants to echo the commands that execute in gsutil.bat to the
     // stdout when we do that. So, we copy the file locally and then read it
     // back in.
-    final File metadataFile = File(
-      path.join(tempDir.absolute.path, getMetadataFilename(platform)),
-    );
+    final File metadataFile = File(path.join(tempDir.absolute.path, getMetadataFilename(platform)));
     const JsonEncoder encoder = JsonEncoder.withIndent('  ');
     metadataFile.writeAsStringSync(encoder.convert(jsonData));
-    print('${confirmed ? 'Overwriting' : 'Would overwrite'} $metadataGsPath with contents of ${metadataFile.absolute.path}');
+    print(
+      '${confirmed ? 'Overwriting' : 'Would overwrite'} $metadataGsPath with contents of ${metadataFile.absolute.path}',
+    );
     await _cloudReplaceDest(metadataFile.absolute.path, metadataGsPath);
   }
 
@@ -310,11 +320,7 @@ class ArchiveUnpublisher {
   }) async {
     final List<String> command = <String>['gsutil', '--', ...args];
     if (confirm) {
-      return _processRunner.runProcess(
-        command,
-        workingDirectory: workingDirectory,
-        failOk: failOk,
-      );
+      return _processRunner.runProcess(command, workingDirectory: workingDirectory, failOk: failOk);
     } else {
       print('Would run: ${command.join(' ')}');
       return '';
@@ -372,25 +378,34 @@ void _printBanner(String message) {
 
 /// Prepares a flutter git repo to be removed from the published cloud storage.
 Future<void> main(List<String> rawArguments) async {
-  final List<String> allowedChannelValues = Channel.values.map<String>((Channel channel) => getChannelName(channel)).toList();
-  final List<String> allowedPlatformNames = PublishedPlatform.values.map<String>((PublishedPlatform platform) => getPublishedPlatform(platform)).toList();
+  final List<String> allowedChannelValues = Channel.values
+      .map<String>((Channel channel) => getChannelName(channel))
+      .toList();
+  final List<String> allowedPlatformNames = PublishedPlatform.values
+      .map<String>((PublishedPlatform platform) => getPublishedPlatform(platform))
+      .toList();
   final ArgParser argParser = ArgParser();
   argParser.addOption(
     'temp_dir',
-    help: 'A location where temporary files may be written. Defaults to a '
+    help:
+        'A location where temporary files may be written. Defaults to a '
         'directory in the system temp folder. If a temp_dir is not '
         'specified, then by default a generated temporary directory will be '
         'created, used, and removed automatically when the script exits.',
   );
-  argParser.addMultiOption('revision',
-      help: 'The Flutter git repo revisions to remove from the published site. '
-          'Must be full 40-character hashes. More than one may be specified, '
-          'either by giving the option more than once, or by giving a comma '
-          'separated list. Required.');
+  argParser.addMultiOption(
+    'revision',
+    help:
+        'The Flutter git repo revisions to remove from the published site. '
+        'Must be full 40-character hashes. More than one may be specified, '
+        'either by giving the option more than once, or by giving a comma '
+        'separated list. Required.',
+  );
   argParser.addMultiOption(
     'channel',
     allowed: allowedChannelValues,
-    help: 'The Flutter channels to remove the archives corresponding to the '
+    help:
+        'The Flutter channels to remove the archives corresponding to the '
         'revisions given with --revision. More than one may be specified, '
         'either by giving the option more than once, or by giving a '
         'comma separated list. If not specified, then the archives from all '
@@ -399,24 +414,22 @@ Future<void> main(List<String> rawArguments) async {
   argParser.addMultiOption(
     'platform',
     allowed: allowedPlatformNames,
-    help: 'The Flutter platforms to remove the archive from. May specify more '
+    help:
+        'The Flutter platforms to remove the archive from. May specify more '
         'than one, either by giving the option more than once, or by giving a '
         'comma separated list. If not specified, then the archives from all '
         'platforms that a revision appears in will be removed.',
   );
   argParser.addFlag(
     'confirm',
-    help: 'If set, will actually remove the archive from Google Cloud Storage '
+    help:
+        'If set, will actually remove the archive from Google Cloud Storage '
         'upon successful execution of this script. Published archives will be '
         'removed from this directory: $baseUrl$releaseFolder. This option '
         'must be set to perform any action on the server, otherwise only a dry '
         'run is performed.',
   );
-  argParser.addFlag(
-    'help',
-    negatable: false,
-    help: 'Print help for this command.',
-  );
+  argParser.addFlag('help', negatable: false, help: 'Print help for this command.');
 
   final ArgResults parsedArguments = argParser.parse(rawArguments);
 
@@ -437,7 +450,9 @@ Future<void> main(List<String> rawArguments) async {
   }
   for (final String revision in revisions) {
     if (revision.length != 40) {
-      errorExit('Invalid argument: --revision "$revision" must be the entire hash, not just a prefix.');
+      errorExit(
+        'Invalid argument: --revision "$revision" must be the entire hash, not just a prefix.',
+      );
     }
     if (revision.contains(RegExp(r'[^a-fA-F0-9]'))) {
       errorExit('Invalid argument: --revision "$revision" contains non-hex characters.');
@@ -458,15 +473,21 @@ Future<void> main(List<String> rawArguments) async {
   }
 
   if (!(parsedArguments['confirm'] as bool)) {
-    _printBanner('This will be just a dry run. To actually perform the changes below, re-run with --confirm argument.');
+    _printBanner(
+      'This will be just a dry run. To actually perform the changes below, re-run with --confirm argument.',
+    );
   }
 
   final List<String> channelArg = parsedArguments['channel'] as List<String>;
   final List<String> channelOptions = channelArg.isNotEmpty ? channelArg : allowedChannelValues;
-  final Set<Channel> channels = channelOptions.map<Channel>((String value) => fromChannelName(value)).toSet();
+  final Set<Channel> channels = channelOptions
+      .map<Channel>((String value) => fromChannelName(value))
+      .toSet();
   final List<String> platformArg = parsedArguments['platform'] as List<String>;
   final List<String> platformOptions = platformArg.isNotEmpty ? platformArg : allowedPlatformNames;
-  final List<PublishedPlatform> platforms = platformOptions.map<PublishedPlatform>((String value) => fromPublishedPlatform(value)).toList();
+  final List<PublishedPlatform> platforms = platformOptions
+      .map<PublishedPlatform>((String value) => fromPublishedPlatform(value))
+      .toList();
   int exitCode = 0;
   late String message;
   late String stack;
@@ -497,7 +518,9 @@ Future<void> main(List<String> rawArguments) async {
       errorExit('$message\n$stack', exitCode: exitCode);
     }
     if (!(parsedArguments['confirm'] as bool)) {
-      _printBanner('This was just a dry run. To actually perform the above changes, re-run with --confirm argument.');
+      _printBanner(
+        'This was just a dry run. To actually perform the above changes, re-run with --confirm argument.',
+      );
     }
     exit(0);
   }
