@@ -14,16 +14,10 @@ Future<void> main() async {
     String? simulatorDeviceId;
     TaskResult res = TaskResult.success(null);
     try {
-      await testWithNewIOSSimulator(
-        'TestNativeAssetsSim',
-        (String deviceId) async {
-          simulatorDeviceId = deviceId;
-          res = await createNativeAssetsTest(
-            deviceIdOverride: deviceId,
-            isIosSimulator: true,
-          )();
-        },
-      );
+      await testWithNewIOSSimulator('TestNativeAssetsSim', (String deviceId) async {
+        simulatorDeviceId = deviceId;
+        res = await createNativeAssetsTest(deviceIdOverride: deviceId, isIosSimulator: true)();
+      });
     } finally {
       await removeIOSSimulator(simulatorDeviceId);
     }
