@@ -2,12 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-enum Category {
-  all,
-  accessories,
-  clothing,
-  home,
-}
+enum Category { all, accessories, clothing, home }
 
 class Product {
   const Product({
