@@ -3,19 +3,16 @@
 // found in the LICENSE file.
 
 import 'package:collection/collection.dart';
+import 'package:flutter/foundation.dart';
 import 'package:flutter/material.dart';
-import 'package:flutter/rendering.dart';
 import 'package:flutter/services.dart';
 
-VoidCallback? originalSemanticsListener;
-
 void main() {
-  WidgetsFlutterBinding.ensureInitialized();
   // Disconnects semantics listener for testing purposes.
-  originalSemanticsListener = WidgetsBinding.instance.platformDispatcher.onSemanticsEnabledChanged;
-  RendererBinding.instance.platformDispatcher.onSemanticsEnabledChanged = null;
-  RendererBinding.instance.setSemanticsEnabled(false);
   // If the test passes, LifeCycleSpy will rewire the semantics listener back.
+  SwitchableSemanticsBinding.ensureInitialized();
+  assert(!SwitchableSemanticsBinding.instance.semanticsEnabled);
+
   runApp(const LifeCycleSpy());
 }
 
@@ -45,9 +42,7 @@ class _LifeCycleSpyState extends State<LifeCycleSpy> with WidgetsBindingObserver
   void initState() {
     super.initState();
     WidgetsBinding.instance.addObserver(this);
-    _actualLifeCycleSequence =  <AppLifecycleState?>[
-      ServicesBinding.instance.lifecycleState,
-    ];
+    _actualLifeCycleSequence = <AppLifecycleState?>[ServicesBinding.instance.lifecycleState];
   }
 
   @override
@@ -66,14 +61,62 @@ class _LifeCycleSpyState extends State<LifeCycleSpy> with WidgetsBindingObserver
 
   @override
   Widget build(BuildContext context) {
-    if (const ListEquality<AppLifecycleState?>().equals(_actualLifeCycleSequence, _expectedLifeCycleSequence)) {
+    if (const ListEquality<AppLifecycleState?>().equals(
+      _actualLifeCycleSequence,
+      _expectedLifeCycleSequence,
+    )) {
       // Rewires the semantics harness if test passes.
-      RendererBinding.instance.setSemanticsEnabled(true);
-      RendererBinding.instance.platformDispatcher.onSemanticsEnabledChanged = originalSemanticsListener;
+      SwitchableSemanticsBinding.instance.semanticsEnabled = true;
     }
-    return const MaterialApp(
-      title: 'Flutter View',
-      home: Text('test'),
-    );
+    return const MaterialApp(title: 'Flutter View', home: Text('test'));
+  }
+}
+
+class SwitchableSemanticsBinding extends WidgetsFlutterBinding {
+  static SwitchableSemanticsBinding get instance => BindingBase.checkInstance(_instance);
+  static SwitchableSemanticsBinding? _instance;
+
+  static SwitchableSemanticsBinding ensureInitialized() {
+    if (_instance == null) {
+      SwitchableSemanticsBinding();
+    }
+    return SwitchableSemanticsBinding.instance;
+  }
+
+  VoidCallback? _originalSemanticsListener;
+
+  @override
+  void initInstances() {
+    super.initInstances();
+    _instance = this;
+    _updateHandler();
+  }
+
+  @override
+  bool get semanticsEnabled => _semanticsEnabled.value;
+  final ValueNotifier<bool> _semanticsEnabled = ValueNotifier<bool>(false);
+  set semanticsEnabled(bool value) {
+    _semanticsEnabled.value = value;
+    _updateHandler();
+  }
+
+  void _updateHandler() {
+    if (_semanticsEnabled.value) {
+      platformDispatcher.onSemanticsEnabledChanged = _originalSemanticsListener;
+      _originalSemanticsListener = null;
+    } else {
+      _originalSemanticsListener = platformDispatcher.onSemanticsEnabledChanged;
+      platformDispatcher.onSemanticsEnabledChanged = null;
+    }
+  }
+
+  @override
+  void addSemanticsEnabledListener(VoidCallback listener) {
+    _semanticsEnabled.addListener(listener);
+  }
+
+  @override
+  void removeSemanticsEnabledListener(VoidCallback listener) {
+    _semanticsEnabled.removeListener(listener);
   }
 }
