@@ -71,10 +71,7 @@ class _DropdownButtonExampleState extends State<DropdownButtonExample> {
                 }).toList();
               },
               items: cities.keys.map<DropdownMenuItem<String>>((String item) {
-                return DropdownMenuItem<String>(
-                  value: item,
-                  child: Text(item),
-                );
+                return DropdownMenuItem<String>(value: item, child: Text(item));
               }).toList(),
             ),
           ),
