@@ -8,9 +8,7 @@ import 'package:flutter_test/flutter_test.dart';
 
 void main() {
   testWidgets('Vertical Divider', (WidgetTester tester) async {
-    await tester.pumpWidget(
-      const example.VerticalDividerExampleApp(),
-    );
+    await tester.pumpWidget(const example.VerticalDividerExampleApp());
 
     expect(find.byType(VerticalDivider), findsOneWidget);
 
