@@ -21,8 +21,8 @@ import 'theme.dart';
 /// between [ListTile]s, and dividers between rows in [DataTable]s.
 ///
 /// Descendant widgets obtain the current [DividerThemeData] object using
-/// `DividerTheme.of(context)`. Instances of [DividerThemeData]
-/// can be customized with [DividerThemeData.copyWith].
+/// [DividerTheme.of]. Instances of [DividerThemeData] can be customized with
+/// [DividerThemeData.copyWith].
 ///
 /// Typically a [DividerThemeData] is specified as part of the overall
 /// [Theme] with [ThemeData.dividerTheme].
@@ -38,7 +38,14 @@ import 'theme.dart';
 class DividerThemeData with Diagnosticable {
   /// Creates a theme that can be used for [DividerTheme] or
   /// [ThemeData.dividerTheme].
-  const DividerThemeData({this.color, this.space, this.thickness, this.indent, this.endIndent});
+  const DividerThemeData({
+    this.color,
+    this.space,
+    this.thickness,
+    this.indent,
+    this.endIndent,
+    this.radius,
+  });
 
   /// The color of [Divider]s and [VerticalDivider]s, also
   /// used between [ListTile]s, between rows in [DataTable]s, and so forth.
@@ -61,6 +68,11 @@ class DividerThemeData with Diagnosticable {
   /// of [VerticalDivider].
   final double? endIndent;
 
+  /// The border radius applied to the [Divider] or [VerticalDivider].
+  ///
+  /// If non-null, this radius will be used to round the corners of the divider.
+  final BorderRadiusGeometry? radius;
+
   /// Creates a copy of this object with the given fields replaced with the
   /// new values.
   DividerThemeData copyWith({
@@ -69,6 +81,7 @@ class DividerThemeData with Diagnosticable {
     double? thickness,
     double? indent,
     double? endIndent,
+    BorderRadiusGeometry? radius,
   }) {
     return DividerThemeData(
       color: color ?? this.color,
@@ -76,6 +89,7 @@ class DividerThemeData with Diagnosticable {
       thickness: thickness ?? this.thickness,
       indent: indent ?? this.indent,
       endIndent: endIndent ?? this.endIndent,
+      radius: radius ?? this.radius,
     );
   }
 
@@ -92,11 +106,12 @@ class DividerThemeData with Diagnosticable {
       thickness: lerpDouble(a?.thickness, b?.thickness, t),
       indent: lerpDouble(a?.indent, b?.indent, t),
       endIndent: lerpDouble(a?.endIndent, b?.endIndent, t),
+      radius: BorderRadiusGeometry.lerp(a?.radius, b?.radius, t),
     );
   }
 
   @override
-  int get hashCode => Object.hash(color, space, thickness, indent, endIndent);
+  int get hashCode => Object.hash(color, space, thickness, indent, endIndent, radius);
 
   @override
   bool operator ==(Object other) {
@@ -111,7 +126,8 @@ class DividerThemeData with Diagnosticable {
         other.space == space &&
         other.thickness == thickness &&
         other.indent == indent &&
-        other.endIndent == endIndent;
+        other.endIndent == endIndent &&
+        other.radius == radius;
   }
 
   @override
@@ -122,6 +138,7 @@ class DividerThemeData with Diagnosticable {
     properties.add(DoubleProperty('thickness', thickness, defaultValue: null));
     properties.add(DoubleProperty('indent', indent, defaultValue: null));
     properties.add(DoubleProperty('endIndent', endIndent, defaultValue: null));
+    properties.add(DiagnosticsProperty<BorderRadiusGeometry>('radius', radius, defaultValue: null));
   }
 }
 
