@@ -2,8 +2,13 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'card.dart';
+/// @docImport 'divider_theme.dart';
+library;
+
 import 'dart:ui' show lerpDouble;
 
+import 'package:flutter/foundation.dart';
 import 'package:flutter/rendering.dart';
 import 'package:flutter/widgets.dart';
 
@@ -36,11 +41,7 @@ abstract class MergeableMaterialItem {
 class MaterialSlice extends MergeableMaterialItem {
   /// Creates a slice of [Material] that's mergeable within a
   /// [MergeableMaterial].
-  const MaterialSlice({
-    required LocalKey key,
-    required this.child,
-    this.color,
-  }) : super(key);
+  const MaterialSlice({required LocalKey key, required this.child, this.color}) : super(key);
 
   /// The contents of this slice.
   ///
@@ -63,10 +64,7 @@ class MaterialSlice extends MergeableMaterialItem {
 /// All [MaterialGap] objects need a [LocalKey].
 class MaterialGap extends MergeableMaterialItem {
   /// Creates a Material gap with a given size.
-  const MaterialGap({
-    required LocalKey key,
-    this.size = 16.0,
-  }) : super(key);
+  const MaterialGap({required LocalKey key, this.size = 16.0}) : super(key);
 
   /// The main axis extent of this gap. For example, if the [MergeableMaterial]
   /// is vertical, then this is the height of the gap.
@@ -147,7 +145,9 @@ class _AnimationTuple {
     required this.startAnimation,
     required this.endAnimation,
     required this.gapAnimation,
-  });
+  }) {
+    assert(debugMaybeDispatchCreated('material', '_AnimationTuple', this));
+  }
 
   final AnimationController controller;
   final CurvedAnimation startAnimation;
@@ -157,6 +157,7 @@ class _AnimationTuple {
 
   @mustCallSuper
   void dispose() {
+    assert(debugMaybeDispatchDisposed(this));
     controller.dispose();
     startAnimation.dispose();
     endAnimation.dispose();
@@ -230,8 +231,7 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
 
   bool _debugHasConsecutiveGaps(List<MergeableMaterialItem> children) {
     for (int i = 0; i < widget.children.length - 1; i += 1) {
-      if (widget.children[i] is MaterialGap &&
-          widget.children[i + 1] is MaterialGap) {
+      if (widget.children[i] is MaterialGap && widget.children[i + 1] is MaterialGap) {
         return true;
       }
     }
@@ -273,24 +273,17 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
 
   bool _isClosingGap(int index) {
     if (index < _children.length - 1 && _children[index] is MaterialGap) {
-      return _animationTuples[_children[index].key]!.controller.status ==
-          AnimationStatus.reverse;
+      return _animationTuples[_children[index].key]!.controller.status == AnimationStatus.reverse;
     }
 
     return false;
   }
 
   void _removeEmptyGaps() {
-    int j = 0;
-
-    while (j < _children.length) {
-      if (
-        _children[j] is MaterialGap &&
-        _animationTuples[_children[j].key]!.controller.status == AnimationStatus.dismissed
-      ) {
+    for (int j = _children.length - 1; j >= 0; j -= 1) {
+      if (_children[j] is MaterialGap &&
+          _animationTuples[_children[j].key]!.controller.isDismissed) {
         _removeChild(j);
-      } else {
-        j += 1;
       }
     }
   }
@@ -299,12 +292,12 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
   void didUpdateWidget(MergeableMaterial oldWidget) {
     super.didUpdateWidget(oldWidget);
 
-    final Set<LocalKey> oldKeys = oldWidget.children.map<LocalKey>(
-      (MergeableMaterialItem child) => child.key,
-    ).toSet();
-    final Set<LocalKey> newKeys = widget.children.map<LocalKey>(
-      (MergeableMaterialItem child) => child.key,
-    ).toSet();
+    final Set<LocalKey> oldKeys = oldWidget.children
+        .map<LocalKey>((MergeableMaterialItem child) => child.key)
+        .toSet();
+    final Set<LocalKey> newKeys = widget.children
+        .map<LocalKey>((MergeableMaterialItem child) => child.key)
+        .toSet();
     final Set<LocalKey> newOnly = newKeys.difference(oldKeys);
     final Set<LocalKey> oldOnly = oldKeys.difference(newKeys);
 
@@ -317,8 +310,7 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
     _removeEmptyGaps();
 
     while (i < newChildren.length && j < _children.length) {
-      if (newOnly.contains(newChildren[i].key) ||
-          oldOnly.contains(_children[j].key)) {
+      if (newOnly.contains(newChildren[i].key) || oldOnly.contains(_children[j].key)) {
         final int startNew = i;
         final int startOld = j;
 
@@ -336,8 +328,7 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
         final int oldLength = j - startOld;
 
         if (newLength > 0) {
-          if (oldLength > 1 ||
-              oldLength == 1 && _children[startOld] is MaterialSlice) {
+          if (oldLength > 1 || oldLength == 1 && _children[startOld] is MaterialSlice) {
             if (newLength == 1 && newChildren[startNew] is MaterialGap) {
               // Shrink all gaps into the size of the new one.
               double gapSizeSum = 0.0;
@@ -371,7 +362,8 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
               j += newLength - oldLength;
             }
           } else if (oldLength == 1) {
-            if (newLength == 1 && newChildren[startNew] is MaterialGap &&
+            if (newLength == 1 &&
+                newChildren[startNew] is MaterialGap &&
                 _children[startOld].key == newChildren[startNew].key) {
               /// Special case: gap added back.
               _animationTuples[newChildren[startNew].key]!.controller.forward();
@@ -422,8 +414,7 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
           }
         } else {
           // If more than a gap disappeared, just remove slices and shrink gaps.
-          if (oldLength > 1 ||
-              oldLength == 1 && _children[startOld] is MaterialSlice) {
+          if (oldLength > 1 || oldLength == 1 && _children[startOld] is MaterialSlice) {
             double gapSizeSum = 0.0;
 
             while (startOld < j) {
@@ -437,10 +428,7 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
             }
 
             if (gapSizeSum != 0.0) {
-              final MaterialGap gap = MaterialGap(
-                key: UniqueKey(),
-                size: gapSizeSum,
-              );
+              final MaterialGap gap = MaterialGap(key: UniqueKey(), size: gapSizeSum);
               _insertChild(startOld, gap);
               _animationTuples[gap.key]!.gapStart = 0.0;
               _animationTuples[gap.key]!.controller
@@ -490,9 +478,15 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
   }
 
   BorderRadius _borderRadius(int index, bool start, bool end) {
-    assert(kMaterialEdges[MaterialType.card]!.topLeft == kMaterialEdges[MaterialType.card]!.topRight);
-    assert(kMaterialEdges[MaterialType.card]!.topLeft == kMaterialEdges[MaterialType.card]!.bottomLeft);
-    assert(kMaterialEdges[MaterialType.card]!.topLeft == kMaterialEdges[MaterialType.card]!.bottomRight);
+    assert(
+      kMaterialEdges[MaterialType.card]!.topLeft == kMaterialEdges[MaterialType.card]!.topRight,
+    );
+    assert(
+      kMaterialEdges[MaterialType.card]!.topLeft == kMaterialEdges[MaterialType.card]!.bottomLeft,
+    );
+    assert(
+      kMaterialEdges[MaterialType.card]!.topLeft == kMaterialEdges[MaterialType.card]!.bottomRight,
+    );
     final Radius cardRadius = kMaterialEdges[MaterialType.card]!.topLeft;
 
     Radius startRadius = Radius.zero;
@@ -557,20 +551,13 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
     for (i = 0; i < _children.length; i += 1) {
       if (_children[i] is MaterialGap) {
         assert(slices.isNotEmpty);
-        widgets.add(
-          ListBody(
-            mainAxis: widget.mainAxis,
-            children: slices,
-          ),
-        );
+        widgets.add(ListBody(mainAxis: widget.mainAxis, children: slices));
         slices = <Widget>[];
 
-        widgets.add(
-          SizedBox(
-            width: widget.mainAxis == Axis.horizontal ? _getGapSize(i) : null,
-            height: widget.mainAxis == Axis.vertical ? _getGapSize(i) : null,
-          ),
-        );
+        widgets.add(switch (widget.mainAxis) {
+          Axis.horizontal => SizedBox(width: _getGapSize(i)),
+          Axis.vertical => SizedBox(height: _getGapSize(i)),
+        });
       } else {
         final MaterialSlice slice = _children[i] as MaterialSlice;
         Widget child = slice.child;
@@ -581,19 +568,16 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
 
           final BorderSide divider = Divider.createBorderSide(
             context,
-            width: 0.5, // TODO(ianh): This probably looks terrible when the dpr isn't a power of two.
+            width:
+                0.5, // TODO(ianh): This probably looks terrible when the dpr isn't a power of two.
             color: widget.dividerColor,
           );
 
           final Border border;
           if (i == 0) {
-            border = Border(
-              bottom: hasBottomDivider ? divider : BorderSide.none,
-            );
+            border = Border(bottom: hasBottomDivider ? divider : BorderSide.none);
           } else if (i == _children.length - 1) {
-            border = Border(
-              top: hasTopDivider ? divider : BorderSide.none,
-            );
+            border = Border(top: hasTopDivider ? divider : BorderSide.none);
           } else {
             border = Border(
               top: hasTopDivider ? divider : BorderSide.none,
@@ -616,22 +600,14 @@ class _MergeableMaterialState extends State<MergeableMaterial> with TickerProvid
               color: (_children[i] as MaterialSlice).color ?? Theme.of(context).cardColor,
               borderRadius: _borderRadius(i, i == 0, i == _children.length - 1),
             ),
-            child: Material(
-              type: MaterialType.transparency,
-              child: child,
-            ),
+            child: Material(type: MaterialType.transparency, child: child),
           ),
         );
       }
     }
 
     if (slices.isNotEmpty) {
-      widgets.add(
-        ListBody(
-          mainAxis: widget.mainAxis,
-          children: slices,
-        ),
-      );
+      widgets.add(ListBody(mainAxis: widget.mainAxis, children: slices));
       slices = <Widget>[];
     }
 
@@ -653,8 +629,7 @@ class _MergeableMaterialSliceKey extends GlobalKey {
 
   @override
   bool operator ==(Object other) {
-    return other is _MergeableMaterialSliceKey
-        && other.value == value;
+    return other is _MergeableMaterialSliceKey && other.value == value;
   }
 
   @override
@@ -691,7 +666,8 @@ class _MergeableMaterialListBody extends ListBody {
 
   @override
   void updateRenderObject(BuildContext context, RenderListBody renderObject) {
-    final _RenderMergeableMaterialListBody materialRenderListBody = renderObject as _RenderMergeableMaterialListBody;
+    final _RenderMergeableMaterialListBody materialRenderListBody =
+        renderObject as _RenderMergeableMaterialListBody;
     materialRenderListBody
       ..axisDirection = _getDirection(context)
       ..elevation = elevation;
@@ -699,10 +675,8 @@ class _MergeableMaterialListBody extends ListBody {
 }
 
 class _RenderMergeableMaterialListBody extends RenderListBody {
-  _RenderMergeableMaterialListBody({
-    super.axisDirection,
-    double elevation = 0.0,
-  }) : _elevation = elevation;
+  _RenderMergeableMaterialListBody({super.axisDirection, double elevation = 0.0})
+    : _elevation = elevation;
 
   double get elevation => _elevation;
   double _elevation;
