@@ -2,6 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'circle_avatar.dart';
+/// @docImport 'drawer.dart';
+/// @docImport 'material.dart';
+library;
+
 import 'dart:math' as math;
 
 import 'package:flutter/widgets.dart';
@@ -42,10 +47,7 @@ class _AccountPictures extends StatelessWidget {
                   container: true,
                   child: Padding(
                     padding: const EdgeInsets.only(left: 8.0, bottom: 8.0),
-                    child: SizedBox.fromSize(
-                      size: otherAccountsPicturesSize,
-                      child: picture,
-                    ),
+                    child: SizedBox.fromSize(size: otherAccountsPicturesSize, child: picture),
                   ),
                 ),
               );
@@ -56,10 +58,7 @@ class _AccountPictures extends StatelessWidget {
           top: 0.0,
           child: Semantics(
             explicitChildNodes: true,
-            child: SizedBox.fromSize(
-              size: currentAccountPictureSize,
-              child: currentAccountPicture,
-            ),
+            child: SizedBox.fromSize(size: currentAccountPictureSize, child: currentAccountPicture),
           ),
         ),
       ],
@@ -90,21 +89,23 @@ class _AccountDetailsState extends State<_AccountDetails> with SingleTickerProvi
   late final CurvedAnimation _animation;
   late final AnimationController _controller;
   @override
-  void initState () {
+  void initState() {
     super.initState();
     _controller = AnimationController(
       value: widget.isOpen ? 1.0 : 0.0,
       duration: const Duration(milliseconds: 200),
       vsync: this,
     );
-    _animation = CurvedAnimation(
-      parent: _controller,
-      curve: Curves.fastOutSlowIn,
-      reverseCurve: Curves.fastOutSlowIn.flipped,
-    )
-      ..addListener(() => setState(() {
-        // [animation]'s value has changed here.
-      }));
+    _animation =
+        CurvedAnimation(
+          parent: _controller,
+          curve: Curves.fastOutSlowIn,
+          reverseCurve: Curves.fastOutSlowIn.flipped,
+        )..addListener(
+          () => setState(() {
+            // [animation]'s value has changed here.
+          }),
+        );
   }
 
   @override
@@ -115,7 +116,7 @@ class _AccountDetailsState extends State<_AccountDetails> with SingleTickerProvi
   }
 
   @override
-  void didUpdateWidget (_AccountDetails oldWidget) {
+  void didUpdateWidget(_AccountDetails oldWidget) {
     super.didUpdateWidget(oldWidget);
     // If the state of the arrow did not change, there is no need to trigger the animation
     if (oldWidget.isOpen == widget.isOpen) {
@@ -139,9 +140,7 @@ class _AccountDetailsState extends State<_AccountDetails> with SingleTickerProvi
     final MaterialLocalizations localizations = MaterialLocalizations.of(context);
 
     Widget accountDetails = CustomMultiChildLayout(
-      delegate: _AccountDetailsLayout(
-        textDirection: Directionality.of(context),
-      ),
+      delegate: _AccountDetailsLayout(textDirection: Directionality.of(context)),
       children: <Widget>[
         if (widget.accountName != null)
           LayoutId(
@@ -203,18 +202,14 @@ class _AccountDetailsState extends State<_AccountDetails> with SingleTickerProvi
       );
     }
 
-    return SizedBox(
-      height: _kAccountDetailsHeight,
-      child: accountDetails,
-    );
+    return SizedBox(height: _kAccountDetailsHeight, child: accountDetails);
   }
 }
 
 const double _kAccountDetailsHeight = 56.0;
 
 class _AccountDetailsLayout extends MultiChildLayoutDelegate {
-
-  _AccountDetailsLayout({ required this.textDirection });
+  _AccountDetailsLayout({required this.textDirection});
 
   static const String accountName = 'accountName';
   static const String accountEmail = 'accountEmail';
@@ -231,10 +226,14 @@ class _AccountDetailsLayout extends MultiChildLayoutDelegate {
       positionChild(dropdownIcon, _offsetForIcon(size, iconSize));
     }
 
-    final String? bottomLine = hasChild(accountEmail) ? accountEmail : (hasChild(accountName) ? accountName : null);
+    final String? bottomLine = hasChild(accountEmail)
+        ? accountEmail
+        : (hasChild(accountName) ? accountName : null);
 
     if (bottomLine != null) {
-      final Size constraintSize = iconSize == null ? size : Size(size.width - iconSize.width, size.height);
+      final Size constraintSize = iconSize == null
+          ? size
+          : Size(size.width - iconSize.width, size.height);
       iconSize ??= const Size(_kAccountDetailsHeight, _kAccountDetailsHeight);
 
       // place bottom line center at same height as icon center
@@ -362,7 +361,8 @@ class _UserAccountsDrawerHeaderState extends State<UserAccountsDrawerHeader> {
       container: true,
       label: MaterialLocalizations.of(context).signedInLabel,
       child: DrawerHeader(
-        decoration: widget.decoration ?? BoxDecoration(color: Theme.of(context).colorScheme.primary),
+        decoration:
+            widget.decoration ?? BoxDecoration(color: Theme.of(context).colorScheme.primary),
         margin: widget.margin,
         padding: const EdgeInsetsDirectional.only(top: 16.0, start: 16.0),
         child: SafeArea(
