@@ -11,6 +11,7 @@ library;
 import 'package:flutter/foundation.dart';
 
 import 'basic_types.dart';
+import 'debug.dart';
 
 /// Base class for [BorderRadius] that allows for text-direction aware resolution.
 ///
@@ -26,6 +27,68 @@ abstract class BorderRadiusGeometry {
   /// const constructors so that they can be used in const expressions.
   const BorderRadiusGeometry();
 
+  /// Creates a [BorderRadius] where all radii are `radius`.
+  // The radius applies equally on all sides, so BorderRadiusDirectional is
+  // irrelevant in this case.
+  const factory BorderRadiusGeometry.all(Radius radius) = BorderRadius.all;
+
+  /// Creates a [BorderRadius] where all radii are [Radius.circular(radius)].
+  // The radius applies equally on all sides, so BorderRadiusDirectional is
+  // irrelevant in this case.
+  factory BorderRadiusGeometry.circular(double radius) = BorderRadius.circular;
+
+  /// Creates a horizontally symmetrical border radius.
+  ///
+  /// Utilizing the `left` and `right` properties will return a [BorderRadius],
+  /// while `start` and `end` will yield a [BorderRadiusDirectional]. These
+  /// properties cannot be used interchangeably.
+  factory BorderRadiusGeometry.horizontal({
+    Radius? left, // BorderRadius
+    Radius? right, // BorderRadius
+    Radius? start, // BorderRadiusDirectional
+    Radius? end, // BorderRadiusDirectional
+  }) {
+    assert(
+      (left == null && right == null) || (start == null && end == null),
+      'The left and right values cannot be used in conjunction with start and end.',
+    );
+
+    if (start != null || end != null) {
+      return BorderRadiusDirectional.horizontal(
+        start: start ?? Radius.zero,
+        end: end ?? Radius.zero,
+      );
+    }
+    return BorderRadius.horizontal(left: left ?? Radius.zero, right: right ?? Radius.zero);
+  }
+
+  /// Creates a [BorderRadius] with only the given non-zero values.
+  ///
+  /// The other corners will be right angles.
+  const factory BorderRadiusGeometry.only({
+    Radius topLeft,
+    Radius topRight,
+    Radius bottomLeft,
+    Radius bottomRight,
+  }) = BorderRadius.only;
+
+  /// Creates a [BorderRadiusDirectional] with only the given non-zero values.
+  ///
+  /// The other corners will be right angles.
+  const factory BorderRadiusGeometry.directional({
+    Radius topStart,
+    Radius topEnd,
+    Radius bottomStart,
+    Radius bottomEnd,
+  }) = BorderRadiusDirectional.only;
+
+  /// Creates a vertically symmetric [BorderRadius] where the top and bottom
+  /// sides of the rectangle have the same radii.
+  const factory BorderRadiusGeometry.vertical({Radius top, Radius bottom}) = BorderRadius.vertical;
+
+  /// A [BorderRadius] with all zero radii.
+  static const BorderRadiusGeometry zero = BorderRadius.zero;
+
   Radius get _topLeft;
   Radius get _topRight;
   Radius get _bottomLeft;
@@ -157,9 +220,7 @@ abstract class BorderRadiusGeometry {
   @override
   String toString() {
     String? visual, logical;
-    if (_topLeft == _topRight &&
-        _topRight == _bottomLeft &&
-        _bottomLeft == _bottomRight) {
+    if (_topLeft == _topRight && _topRight == _bottomLeft && _bottomLeft == _bottomRight) {
       if (_topLeft != Radius.zero) {
         if (_topLeft.x == _topLeft.y) {
           visual = 'BorderRadius.circular(${_topLeft.x.toStringAsFixed(1)})';
@@ -199,9 +260,7 @@ abstract class BorderRadiusGeometry {
       result.write(')');
       visual = result.toString();
     }
-    if (_topStart == _topEnd &&
-        _topEnd == _bottomEnd &&
-        _bottomEnd == _bottomStart) {
+    if (_topStart == _topEnd && _topEnd == _bottomEnd && _bottomEnd == _bottomStart) {
       if (_topStart != Radius.zero) {
         if (_topStart.x == _topStart.y) {
           logical = 'BorderRadiusDirectional.circular(${_topStart.x.toStringAsFixed(1)})';
@@ -255,15 +314,15 @@ abstract class BorderRadiusGeometry {
     if (other.runtimeType != runtimeType) {
       return false;
     }
-    return other is BorderRadiusGeometry
-        && other._topLeft == _topLeft
-        && other._topRight == _topRight
-        && other._bottomLeft == _bottomLeft
-        && other._bottomRight == _bottomRight
-        && other._topStart == _topStart
-        && other._topEnd == _topEnd
-        && other._bottomStart == _bottomStart
-        && other._bottomEnd == _bottomEnd;
+    return other is BorderRadiusGeometry &&
+        other._topLeft == _topLeft &&
+        other._topRight == _topRight &&
+        other._bottomLeft == _bottomLeft &&
+        other._bottomRight == _bottomRight &&
+        other._topStart == _topStart &&
+        other._topEnd == _topEnd &&
+        other._bottomStart == _bottomStart &&
+        other._bottomEnd == _bottomEnd;
   }
 
   @override
@@ -290,41 +349,21 @@ abstract class BorderRadiusGeometry {
 /// a [TextDirection] (typically obtained from the ambient [Directionality]).
 class BorderRadius extends BorderRadiusGeometry {
   /// Creates a border radius where all radii are [radius].
-  const BorderRadius.all(Radius radius) : this.only(
-    topLeft: radius,
-    topRight: radius,
-    bottomLeft: radius,
-    bottomRight: radius,
-  );
+  const BorderRadius.all(Radius radius)
+    : this.only(topLeft: radius, topRight: radius, bottomLeft: radius, bottomRight: radius);
 
   /// Creates a border radius where all radii are [Radius.circular(radius)].
-  BorderRadius.circular(double radius) : this.all(
-    Radius.circular(radius),
-  );
+  BorderRadius.circular(double radius) : this.all(Radius.circular(radius));
 
   /// Creates a vertically symmetric border radius where the top and bottom
   /// sides of the rectangle have the same radii.
-  const BorderRadius.vertical({
-    Radius top = Radius.zero,
-    Radius bottom = Radius.zero,
-  }) : this.only(
-    topLeft: top,
-    topRight: top,
-    bottomLeft: bottom,
-    bottomRight: bottom,
-  );
+  const BorderRadius.vertical({Radius top = Radius.zero, Radius bottom = Radius.zero})
+    : this.only(topLeft: top, topRight: top, bottomLeft: bottom, bottomRight: bottom);
 
   /// Creates a horizontally symmetrical border radius where the left and right
   /// sides of the rectangle have the same radii.
-  const BorderRadius.horizontal({
-    Radius left = Radius.zero,
-    Radius right = Radius.zero,
-  }) : this.only(
-    topLeft: left,
-    topRight: right,
-    bottomLeft: left,
-    bottomRight: right,
-  );
+  const BorderRadius.horizontal({Radius left = Radius.zero, Radius right = Radius.zero})
+    : this.only(topLeft: left, topRight: right, bottomLeft: left, bottomRight: right);
 
   /// Creates a border radius with only the given non-zero values. The other
   /// corners will be right angles.
@@ -407,6 +446,23 @@ class BorderRadius extends BorderRadiusGeometry {
     );
   }
 
+  /// Creates an [RSuperellipse] from the current border radius and a [Rect].
+  ///
+  /// If any of the radii have negative values in x or y, those values will be
+  /// clamped to zero in order to produce a valid [RRect].
+  RSuperellipse toRSuperellipse(Rect rect) {
+    // Because the current radii could be negative, we must clamp them before
+    // converting them to an RRect to be rendered, since negative radii on
+    // RRects don't make sense.
+    return RSuperellipse.fromRectAndCorners(
+      rect,
+      topLeft: topLeft.clamp(minimum: Radius.zero),
+      topRight: topRight.clamp(minimum: Radius.zero),
+      bottomLeft: bottomLeft.clamp(minimum: Radius.zero),
+      bottomRight: bottomRight.clamp(minimum: Radius.zero),
+    );
+  }
+
   @override
   BorderRadiusGeometry subtract(BorderRadiusGeometry other) {
     if (other is BorderRadius) {
@@ -541,41 +597,21 @@ class BorderRadius extends BorderRadiusGeometry {
 ///    `topRight` instead of `topStart` and `topEnd`).
 class BorderRadiusDirectional extends BorderRadiusGeometry {
   /// Creates a border radius where all radii are [radius].
-  const BorderRadiusDirectional.all(Radius radius) : this.only(
-    topStart: radius,
-    topEnd: radius,
-    bottomStart: radius,
-    bottomEnd: radius,
-  );
+  const BorderRadiusDirectional.all(Radius radius)
+    : this.only(topStart: radius, topEnd: radius, bottomStart: radius, bottomEnd: radius);
 
   /// Creates a border radius where all radii are [Radius.circular(radius)].
-  BorderRadiusDirectional.circular(double radius) : this.all(
-    Radius.circular(radius),
-  );
+  BorderRadiusDirectional.circular(double radius) : this.all(Radius.circular(radius));
 
   /// Creates a vertically symmetric border radius where the top and bottom
   /// sides of the rectangle have the same radii.
-  const BorderRadiusDirectional.vertical({
-    Radius top = Radius.zero,
-    Radius bottom = Radius.zero,
-  }) : this.only(
-    topStart: top,
-    topEnd: top,
-    bottomStart: bottom,
-    bottomEnd: bottom,
-  );
+  const BorderRadiusDirectional.vertical({Radius top = Radius.zero, Radius bottom = Radius.zero})
+    : this.only(topStart: top, topEnd: top, bottomStart: bottom, bottomEnd: bottom);
 
   /// Creates a horizontally symmetrical border radius where the start and end
   /// sides of the rectangle have the same radii.
-  const BorderRadiusDirectional.horizontal({
-    Radius start = Radius.zero,
-    Radius end = Radius.zero,
-  }) : this.only(
-    topStart: start,
-    topEnd: end,
-    bottomStart: start,
-    bottomEnd: end,
-  );
+  const BorderRadiusDirectional.horizontal({Radius start = Radius.zero, Radius end = Radius.zero})
+    : this.only(topStart: start, topEnd: end, bottomStart: start, bottomEnd: end);
 
   /// Creates a border radius with only the given non-zero values. The other
   /// corners will be right angles.
@@ -726,7 +762,11 @@ class BorderRadiusDirectional extends BorderRadiusGeometry {
   /// If either is null, this function interpolates from [BorderRadiusDirectional.zero].
   ///
   /// {@macro dart.ui.shadow.lerp}
-  static BorderRadiusDirectional? lerp(BorderRadiusDirectional? a, BorderRadiusDirectional? b, double t) {
+  static BorderRadiusDirectional? lerp(
+    BorderRadiusDirectional? a,
+    BorderRadiusDirectional? b,
+    double t,
+  ) {
     if (identical(a, b)) {
       return a;
     }
@@ -746,7 +786,7 @@ class BorderRadiusDirectional extends BorderRadiusGeometry {
 
   @override
   BorderRadius resolve(TextDirection? direction) {
-    assert(direction != null);
+    assert(debugCheckCanResolveTextDirection(direction, '$BorderRadiusDirectional'));
     switch (direction!) {
       case TextDirection.rtl:
         return BorderRadius.only(
