@@ -2,6 +2,18 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'dart:developer';
+///
+/// @docImport 'package:flutter/scheduler.dart';
+/// @docImport 'package:flutter/widgets.dart';
+///
+/// @docImport 'binding.dart';
+/// @docImport 'layer.dart';
+/// @docImport 'proxy_box.dart';
+/// @docImport 'shifted_box.dart';
+/// @docImport 'view.dart';
+library;
+
 import 'box.dart';
 import 'object.dart';
 
@@ -253,8 +265,7 @@ void _debugDrawDoubleRect(Canvas canvas, Rect outerRect, Rect innerRect, Color c
     ..fillType = PathFillType.evenOdd
     ..addRect(outerRect)
     ..addRect(innerRect);
-  final Paint paint = Paint()
-    ..color = color;
+  final Paint paint = Paint()..color = color;
   canvas.drawPath(path, paint);
 }
 
@@ -271,14 +282,23 @@ void _debugDrawDoubleRect(Canvas canvas, Rect outerRect, Rect innerRect, Color c
 ///
 /// This method is used by [RenderPadding.debugPaintSize] when
 /// [debugPaintSizeEnabled] is true.
-void debugPaintPadding(Canvas canvas, Rect outerRect, Rect? innerRect, { double outlineWidth = 2.0 }) {
+void debugPaintPadding(
+  Canvas canvas,
+  Rect outerRect,
+  Rect? innerRect, {
+  double outlineWidth = 2.0,
+}) {
   assert(() {
     if (innerRect != null && !innerRect.isEmpty) {
       _debugDrawDoubleRect(canvas, outerRect, innerRect, const Color(0x900090FF));
-      _debugDrawDoubleRect(canvas, innerRect.inflate(outlineWidth).intersect(outerRect), innerRect, const Color(0xFF0090FF));
+      _debugDrawDoubleRect(
+        canvas,
+        innerRect.inflate(outlineWidth).intersect(outerRect),
+        innerRect,
+        const Color(0xFF0090FF),
+      );
     } else {
-      final Paint paint = Paint()
-        ..color = const Color(0x90909090);
+      final Paint paint = Paint()..color = const Color(0x90909090);
       canvas.drawRect(outerRect, paint);
     }
     return true;
@@ -296,7 +316,7 @@ void debugPaintPadding(Canvas canvas, Rect outerRect, Rect? innerRect, { double
 /// The `debugCheckIntrinsicSizesOverride` argument can be provided to override
 /// the expected value for [debugCheckIntrinsicSizes]. (This exists because the
 /// test framework itself overrides this value in some cases.)
-bool debugAssertAllRenderVarsUnset(String reason, { bool debugCheckIntrinsicSizesOverride = false }) {
+bool debugAssertAllRenderVarsUnset(String reason, {bool debugCheckIntrinsicSizesOverride = false}) {
   assert(() {
     if (debugPaintSizeEnabled ||
         debugPaintBaselinesEnabled ||
