@@ -2,6 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'package:flutter/widgets.dart';
+library;
+
 import 'dart:math' as math;
 
 import 'package:flutter/animation.dart';
@@ -45,7 +48,7 @@ abstract class ListWheelChildManager {
   /// nothing.
   ///
   /// It is possible to create children with negative indices.
-  void createChild(int index, { required RenderBox? after });
+  void createChild(int index, {required RenderBox? after});
 
   /// Removes the child element corresponding with the given RenderBox.
   void removeChild(RenderBox child);
@@ -141,8 +144,7 @@ class ListWheelParentData extends ContainerBoxParentData<RenderBox> {
 ///    plane's viewport painting coordinates** is also done such that the child
 ///    in the center of that plane will be mostly untransformed with children
 ///    above and below it being transformed more as the angle increases.
-class RenderListWheelViewport
-    extends RenderBox
+class RenderListWheelViewport extends RenderBox
     with ContainerRenderObjectMixin<RenderBox, ListWheelParentData>
     implements RenderAbstractViewport {
   /// Creates a [RenderListWheelViewport] which renders children on a wheel.
@@ -194,12 +196,14 @@ class RenderListWheelViewport
   static const double defaultPerspective = 0.003;
 
   /// An error message to show when the provided [diameterRatio] is zero.
-  static const String diameterRatioZeroMessage = "You can't set a diameterRatio "
+  static const String diameterRatioZeroMessage =
+      "You can't set a diameterRatio "
       'of 0 or of a negative number. It would imply a cylinder of 0 in diameter '
       'in which case nothing will be drawn.';
 
   /// An error message to show when the [perspective] value is too high.
-  static const String perspectiveTooHighMessage = 'A perspective too high will '
+  static const String perspectiveTooHighMessage =
+      'A perspective too high will '
       'be clipped in the z-axis and therefore not renderable. Value must be '
       'between 0 and 0.01.';
 
@@ -247,18 +251,18 @@ class RenderListWheelViewport
   /// A value smaller than 1 means items at the edges of the cylinder are
   /// entirely contained inside the viewport.
   ///
-  /// A value larger than 1 means angles less than ±[pi] / 2 from the
+  /// A value larger than 1 means angles less than ±[math.pi] / 2 from the
   /// center of the cylinder are visible.
   ///
   /// The same number of children will be visible in the viewport regardless of
   /// the [diameterRatio]. The number of children visible is based on the
   /// viewport's length along the main axis divided by the children's
   /// [itemExtent]. Then the children are evenly distributed along the visible
-  /// angles up to ±[pi] / 2.
+  /// angles up to ±[math.pi] / 2.
   ///
   /// Just as it's impossible to stretch a paper to cover the an entire
   /// half of a cylinder's surface where the cylinder has the same diameter
-  /// as the paper's length, choosing a [diameterRatio] smaller than [pi]
+  /// as the paper's length, choosing a [diameterRatio] smaller than [math.pi]
   /// will leave same gaps between the children.
   ///
   /// Defaults to an arbitrary but aesthetically reasonable number of 2.0.
@@ -268,10 +272,7 @@ class RenderListWheelViewport
   double get diameterRatio => _diameterRatio;
   double _diameterRatio;
   set diameterRatio(double value) {
-    assert(
-      value > 0,
-      diameterRatioZeroMessage,
-    );
+    assert(value > 0, diameterRatioZeroMessage);
     if (value == _diameterRatio) {
       return;
     }
@@ -298,10 +299,7 @@ class RenderListWheelViewport
   double _perspective;
   set perspective(double value) {
     assert(value > 0);
-    assert(
-      value <= 0.01,
-      perspectiveTooHighMessage,
-    );
+    assert(value <= 0.01, perspectiveTooHighMessage);
     if (value == _perspective) {
       return;
     }
@@ -357,6 +355,7 @@ class RenderListWheelViewport
     _useMagnifier = value;
     markNeedsPaint();
   }
+
   /// {@template flutter.rendering.RenderListWheelViewport.magnification}
   /// The zoomed-in rate of the magnifier, if it is used.
   ///
@@ -414,7 +413,6 @@ class RenderListWheelViewport
     markNeedsLayout();
   }
 
-
   /// {@template flutter.rendering.RenderListWheelViewport.squeeze}
   /// The angular compactness of the children on the wheel.
   ///
@@ -584,16 +582,12 @@ class RenderListWheelViewport
 
   @override
   double computeMinIntrinsicWidth(double height) {
-    return _getIntrinsicCrossAxis(
-      (RenderBox child) => child.getMinIntrinsicWidth(height),
-    );
+    return _getIntrinsicCrossAxis((RenderBox child) => child.getMinIntrinsicWidth(height));
   }
 
   @override
   double computeMaxIntrinsicWidth(double height) {
-    return _getIntrinsicCrossAxis(
-      (RenderBox child) => child.getMaxIntrinsicWidth(height),
-    );
+    return _getIntrinsicCrossAxis((RenderBox child) => child.getMaxIntrinsicWidth(height));
   }
 
   @override
@@ -636,7 +630,7 @@ class RenderListWheelViewport
   /// Returns the scroll offset of the child with the given index.
   double indexToScrollOffset(int index) => index * itemExtent;
 
-  void _createChild(int index, { RenderBox? after }) {
+  void _createChild(int index, {RenderBox? after}) {
     invokeLayoutCallback<BoxConstraints>((BoxConstraints constraints) {
       assert(constraints == this.constraints);
       childManager.createChild(index, after: after);
@@ -688,8 +682,7 @@ class RenderListWheelViewport
       visibleHeight *= 2;
     }
 
-    final double firstVisibleOffset =
-      offset.pixels + _itemExtent / 2 - visibleHeight / 2;
+    final double firstVisibleOffset = offset.pixels + _itemExtent / 2 - visibleHeight / 2;
     final double lastVisibleOffset = firstVisibleOffset + visibleHeight;
 
     // The index range that we want to spawn children. We find indexes that
@@ -736,10 +729,10 @@ class RenderListWheelViewport
     }
 
     final BoxConstraints childConstraints = constraints.copyWith(
-        minHeight: _itemExtent,
-        maxHeight: _itemExtent,
-        minWidth: 0.0,
-      );
+      minHeight: _itemExtent,
+      maxHeight: _itemExtent,
+      minWidth: 0.0,
+    );
     // If there is no child at this stage, we add the first one that is in
     // target range.
     if (childCount == 0) {
@@ -785,19 +778,18 @@ class RenderListWheelViewport
     // estimated value. Otherwise, we set the dimension limited to our target
     // range.
     final double minScrollExtent = childManager.childExistsAt(targetFirstIndex - 1)
-      ? _minEstimatedScrollExtent
-      : indexToScrollOffset(targetFirstIndex);
+        ? _minEstimatedScrollExtent
+        : indexToScrollOffset(targetFirstIndex);
     final double maxScrollExtent = childManager.childExistsAt(targetLastIndex + 1)
-      ? _maxEstimatedScrollExtent
-      : indexToScrollOffset(targetLastIndex);
+        ? _maxEstimatedScrollExtent
+        : indexToScrollOffset(targetLastIndex);
     offset.applyContentDimensions(minScrollExtent, maxScrollExtent);
   }
 
   bool _shouldClipAtCurrentOffset() {
-    final double highestUntransformedPaintY =
-      _getUntransformedPaintingCoordinateY(0.0);
-    return highestUntransformedPaintY < 0.0
-      || size.height < highestUntransformedPaintY + _maxEstimatedScrollExtent + _itemExtent;
+    final double highestUntransformedPaintY = _getUntransformedPaintingCoordinateY(0.0);
+    return highestUntransformedPaintY < 0.0 ||
+        size.height < highestUntransformedPaintY + _maxEstimatedScrollExtent + _itemExtent;
   }
 
   @override
@@ -827,7 +819,9 @@ class RenderListWheelViewport
     _childOpacityLayerHandler.layer = null;
     super.dispose();
   }
+
   final LayerHandle<OpacityLayer> _childOpacityLayerHandler = LayerHandle<OpacityLayer>();
+
   /// Paints all children visible in the current viewport.
   void _paintVisibleChildren(PaintingContext context, Offset offset) {
     // The magnifier cannot be turned off if the opacity is less than 1.0.
@@ -838,13 +832,17 @@ class RenderListWheelViewport
 
     // In order to reduce the number of opacity layers, we first paint all
     // partially opaque children, then finally paint the fully opaque children.
-    _childOpacityLayerHandler.layer = context.pushOpacity(offset, (overAndUnderCenterOpacity * 255).round(), (PaintingContext context, Offset offset) {
-      _paintAllChildren(context, offset, center: false);
-    });
+    _childOpacityLayerHandler.layer = context.pushOpacity(
+      offset,
+      (overAndUnderCenterOpacity * 255).round(),
+      (PaintingContext context, Offset offset) {
+        _paintAllChildren(context, offset, center: false);
+      },
+    );
     _paintAllChildren(context, offset, center: true);
   }
 
-  void _paintAllChildren(PaintingContext context, Offset offset, { bool? center }) {
+  void _paintAllChildren(PaintingContext context, Offset offset, {bool? center}) {
     RenderBox? childToPaint = firstChild;
     while (childToPaint != null) {
       final ListWheelParentData childParentData = childToPaint.parentData! as ListWheelParentData;
@@ -865,11 +863,8 @@ class RenderListWheelViewport
     Offset layoutOffset, {
     required bool? center,
   }) {
-    final Offset untransformedPaintingCoordinates = offset
-        + Offset(
-            layoutOffset.dx,
-            _getUntransformedPaintingCoordinateY(layoutOffset.dy),
-        );
+    final Offset untransformedPaintingCoordinates =
+        offset + Offset(layoutOffset.dx, _getUntransformedPaintingCoordinateY(layoutOffset.dy));
 
     // Get child's center as a fraction of the viewport's height.
     final double fractionalY =
@@ -879,7 +874,7 @@ class RenderListWheelViewport
     // renderChildrenOutsideViewport is true. Otherwise, only children within
     // suitable angles (via _first/lastVisibleLayoutOffset) reach the paint
     // phase.
-    if (angle > math.pi / 2.0 || angle < -math.pi / 2.0) {
+    if (angle > math.pi / 2.0 || angle < -math.pi / 2.0 || angle.isNaN) {
       return;
     }
 
@@ -897,7 +892,15 @@ class RenderListWheelViewport
 
     final bool shouldApplyOffCenterDim = overAndUnderCenterOpacity < 1;
     if (useMagnifier || shouldApplyOffCenterDim) {
-      _paintChildWithMagnifier(context, offset, child, transform, offsetToCenter, untransformedPaintingCoordinates, center: center);
+      _paintChildWithMagnifier(
+        context,
+        offset,
+        child,
+        transform,
+        offsetToCenter,
+        untransformedPaintingCoordinates,
+        center: center,
+      );
     } else {
       assert(center == null);
       _paintChildCylindrically(context, offset, child, transform, offsetToCenter);
@@ -908,10 +911,10 @@ class RenderListWheelViewport
   // differently if it intersects with the magnifier.
   //
   // `center` controls how items that partially intersect the center magnifier
-  // are rendered. If `center` is false, items are only painted cynlindrically.
+  // are rendered. If `center` is false, items are only painted cylindrically.
   // If `center` is true, only the clipped magnifier items are painted.
   // If `center` is null, partially intersecting items are painted both as the
-  // magnifier and cynlidrical item, while non-intersecting items are painted
+  // magnifier and cylindrical item, while non-intersecting items are painted
   // only cylindrically.
   //
   // This property is used to lift the opacity that would be applied to each
@@ -926,15 +929,14 @@ class RenderListWheelViewport
     Offset untransformedPaintingCoordinates, {
     required bool? center,
   }) {
-    final double magnifierTopLinePosition =
-        size.height / 2 - _itemExtent * _magnification / 2;
-    final double magnifierBottomLinePosition =
-        size.height / 2 + _itemExtent * _magnification / 2;
+    final double magnifierTopLinePosition = size.height / 2 - _itemExtent * _magnification / 2;
+    final double magnifierBottomLinePosition = size.height / 2 + _itemExtent * _magnification / 2;
 
-    final bool isAfterMagnifierTopLine = untransformedPaintingCoordinates.dy
-        >= magnifierTopLinePosition - _itemExtent * _magnification;
-    final bool isBeforeMagnifierBottomLine = untransformedPaintingCoordinates.dy
-        <= magnifierBottomLinePosition;
+    final bool isAfterMagnifierTopLine =
+        untransformedPaintingCoordinates.dy >=
+        magnifierTopLinePosition - _itemExtent * _magnification;
+    final bool isBeforeMagnifierBottomLine =
+        untransformedPaintingCoordinates.dy <= magnifierBottomLinePosition;
 
     final Rect centerRect = Rect.fromLTWH(
       0.0,
@@ -942,12 +944,7 @@ class RenderListWheelViewport
       size.width,
       _itemExtent * _magnification,
     );
-    final Rect topHalfRect = Rect.fromLTWH(
-      0.0,
-      0.0,
-      size.width,
-      magnifierTopLinePosition,
-    );
+    final Rect topHalfRect = Rect.fromLTWH(0.0, 0.0, size.width, magnifierTopLinePosition);
     final Rect bottomHalfRect = Rect.fromLTWH(
       0.0,
       magnifierBottomLinePosition,
@@ -959,21 +956,17 @@ class RenderListWheelViewport
 
     if ((center == null || center) && inCenter) {
       // Clipping the part in the center.
-      context.pushClipRect(
-        needsCompositing,
-        offset,
-        centerRect,
-        (PaintingContext context, Offset offset) {
-          context.pushTransform(
-            needsCompositing,
-            offset,
-            _magnifyTransform(),
-            (PaintingContext context, Offset offset) {
-              context.paintChild(child, offset + untransformedPaintingCoordinates);
-            },
-          );
-        },
-      );
+      context.pushClipRect(needsCompositing, offset, centerRect, (
+        PaintingContext context,
+        Offset offset,
+      ) {
+        context.pushTransform(needsCompositing, offset, _magnifyTransform(), (
+          PaintingContext context,
+          Offset offset,
+        ) {
+          context.paintChild(child, offset + untransformedPaintingCoordinates);
+        });
+      });
     }
 
     // Clipping the part in either the top-half or bottom-half of the wheel.
@@ -982,28 +975,16 @@ class RenderListWheelViewport
         needsCompositing,
         offset,
         untransformedPaintingCoordinates.dy <= magnifierTopLinePosition
-          ? topHalfRect
-          : bottomHalfRect,
+            ? topHalfRect
+            : bottomHalfRect,
         (PaintingContext context, Offset offset) {
-            _paintChildCylindrically(
-              context,
-              offset,
-              child,
-              cylindricalTransform,
-              offsetToCenter,
-            );
+          _paintChildCylindrically(context, offset, child, cylindricalTransform, offsetToCenter);
         },
       );
     }
 
     if ((center == null || !center) && !inCenter) {
-      _paintChildCylindrically(
-        context,
-        offset,
-        child,
-        cylindricalTransform,
-        offsetToCenter,
-      );
+      _paintChildCylindrically(context, offset, child, cylindricalTransform, offsetToCenter);
     }
   }
 
@@ -1037,18 +1018,17 @@ class RenderListWheelViewport
     final ListWheelParentData childParentData = child.parentData! as ListWheelParentData;
     // Save the final transform that accounts both for the offset and cylindrical transform.
     final Matrix4 transform = _centerOriginTransform(cylindricalTransform)
-      ..translate(paintOriginOffset.dx, paintOriginOffset.dy);
+      ..translateByDouble(paintOriginOffset.dx, paintOriginOffset.dy, 0, 1);
     childParentData.transform = transform;
   }
 
   /// Return the Matrix4 transformation that would zoom in content in the
   /// magnified area.
   Matrix4 _magnifyTransform() {
-    final Matrix4 magnify = Matrix4.identity();
-    magnify.translate(size.width * (-_offAxisFraction + 0.5), size.height / 2);
-    magnify.scale(_magnification, _magnification, _magnification);
-    magnify.translate(-size.width * (-_offAxisFraction + 0.5), -size.height / 2);
-    return magnify;
+    return Matrix4.identity()
+      ..translateByDouble(size.width * (-_offAxisFraction + 0.5), size.height / 2, 0, 1)
+      ..scaleByDouble(_magnification, _magnification, _magnification, 1.0)
+      ..translateByDouble(-size.width * (-_offAxisFraction + 0.5), -size.height / 2, 0, 1);
   }
 
   /// Apply incoming transformation with the transformation's origin at the
@@ -1056,14 +1036,18 @@ class RenderListWheelViewport
   Matrix4 _centerOriginTransform(Matrix4 originalMatrix) {
     final Matrix4 result = Matrix4.identity();
     final Offset centerOriginTranslation = Alignment.center.alongSize(size);
-    result.translate(
+    result.translateByDouble(
       centerOriginTranslation.dx * (-_offAxisFraction * 2 + 1),
       centerOriginTranslation.dy,
+      0,
+      1,
     );
     result.multiply(originalMatrix);
-    result.translate(
+    result.translateByDouble(
       -centerOriginTranslation.dx * (-_offAxisFraction * 2 + 1),
       -centerOriginTranslation.dy,
+      0,
+      1,
     );
     return result;
   }
@@ -1093,7 +1077,7 @@ class RenderListWheelViewport
   }
 
   @override
-  bool hitTestChildren(BoxHitTestResult result, { required Offset position }) {
+  bool hitTestChildren(BoxHitTestResult result, {required Offset position}) {
     RenderBox? child = lastChild;
     while (child != null) {
       final ListWheelParentData childParentData = child.parentData! as ListWheelParentData;
@@ -1105,11 +1089,21 @@ class RenderListWheelViewport
           position: position,
           hitTest: (BoxHitTestResult result, Offset transformed) {
             assert(() {
-              final Matrix4? inverted = Matrix4.tryInvert(PointerEvent.removePerspectiveTransform(transform));
+              final Matrix4? inverted = Matrix4.tryInvert(
+                PointerEvent.removePerspectiveTransform(transform),
+              );
               if (inverted == null) {
-                return _debugAssertValidHitTestOffsets('Null inverted transform', transformed, position);
+                return _debugAssertValidHitTestOffsets(
+                  'Null inverted transform',
+                  transformed,
+                  position,
+                );
               }
-              return _debugAssertValidHitTestOffsets('MatrixUtils.transformPoint', transformed, MatrixUtils.transformPoint(inverted, position));
+              return _debugAssertValidHitTestOffsets(
+                'MatrixUtils.transformPoint',
+                transformed,
+                MatrixUtils.transformPoint(inverted, position),
+              );
             }());
             return child!.hitTest(result, position: transformed);
           },
@@ -1169,10 +1163,6 @@ class RenderListWheelViewport
       rect = revealedOffset.rect;
     }
 
-    super.showOnScreen(
-      rect: rect,
-      duration: duration,
-      curve: curve,
-    );
+    super.showOnScreen(rect: rect, duration: duration, curve: curve);
   }
 }
