@@ -25,11 +25,7 @@ class SemanticsDebugger extends StatefulWidget {
   const SemanticsDebugger({
     super.key,
     required this.child,
-    this.labelStyle = const TextStyle(
-      color: Color(0xFF000000),
-      fontSize: 10.0,
-      height: 0.8,
-    ),
+    this.labelStyle = const TextStyle(color: Color(0xFF000000), fontSize: 10.0, height: 0.8),
   });
 
   /// The widget below this widget in the tree.
@@ -170,13 +166,12 @@ class _SemanticsDebuggerState extends State<SemanticsDebugger> with WidgetsBindi
         onTap: _handleTap,
         onLongPress: _handleLongPress,
         onPanEnd: _handlePanEnd,
-        excludeFromSemantics: true, // otherwise if you don't hit anything, we end up receiving it, which causes an infinite loop...
+        excludeFromSemantics:
+            true, // otherwise if you don't hit anything, we end up receiving it, which causes an infinite loop...
         child: Listener(
           onPointerDown: _handlePointerDown,
           behavior: HitTestBehavior.opaque,
-          child: _IgnorePointerWithSemantics(
-            child: widget.child,
-          ),
+          child: _IgnorePointerWithSemantics(child: widget.child),
         ),
       ),
     );
@@ -184,7 +179,13 @@ class _SemanticsDebuggerState extends State<SemanticsDebugger> with WidgetsBindi
 }
 
 class _SemanticsDebuggerPainter extends CustomPainter {
-  const _SemanticsDebuggerPainter(this.owner, this.generation, this.pointerPosition, this.devicePixelRatio, this.labelStyle);
+  const _SemanticsDebuggerPainter(
+    this.owner,
+    this.generation,
+    this.pointerPosition,
+    this.devicePixelRatio,
+    this.labelStyle,
+  );
 
   final PipelineOwner owner;
   final int generation;
@@ -202,7 +203,7 @@ class _SemanticsDebuggerPainter extends CustomPainter {
     canvas.save();
     canvas.scale(1.0 / devicePixelRatio, 1.0 / devicePixelRatio);
     if (rootNode != null) {
-      _paint(canvas, rootNode, _findDepth(rootNode));
+      _paint(canvas, rootNode, _findDepth(rootNode), 0, 0);
     }
     if (pointerPosition != null) {
       final Paint paint = Paint();
@@ -214,9 +215,9 @@ class _SemanticsDebuggerPainter extends CustomPainter {
 
   @override
   bool shouldRepaint(_SemanticsDebuggerPainter oldDelegate) {
-    return owner != oldDelegate.owner
-        || generation != oldDelegate.generation
-        || pointerPosition != oldDelegate.pointerPosition;
+    return owner != oldDelegate.owner ||
+        generation != oldDelegate.generation ||
+        pointerPosition != oldDelegate.pointerPosition;
   }
 
   @visibleForTesting
@@ -225,11 +226,11 @@ class _SemanticsDebuggerPainter extends CustomPainter {
     final List<String> annotations = <String>[];
 
     bool wantsTap = false;
-    if (data.hasFlag(SemanticsFlag.hasCheckedState)) {
-      annotations.add(data.hasFlag(SemanticsFlag.isChecked) ? 'checked' : 'unchecked');
+    if (data.flagsCollection.hasCheckedState) {
+      annotations.add(data.flagsCollection.isChecked ? 'checked' : 'unchecked');
       wantsTap = true;
     }
-    if (data.hasFlag(SemanticsFlag.isTextField)) {
+    if (data.flagsCollection.isTextField) {
       annotations.add('textfield');
       wantsTap = true;
     }
@@ -248,13 +249,14 @@ class _SemanticsDebuggerPainter extends CustomPainter {
       annotations.add('long-pressable');
     }
 
-    final bool isScrollable = data.hasAction(SemanticsAction.scrollLeft)
-        || data.hasAction(SemanticsAction.scrollRight)
-        || data.hasAction(SemanticsAction.scrollUp)
-        || data.hasAction(SemanticsAction.scrollDown);
+    final bool isScrollable =
+        data.hasAction(SemanticsAction.scrollLeft) ||
+        data.hasAction(SemanticsAction.scrollRight) ||
+        data.hasAction(SemanticsAction.scrollUp) ||
+        data.hasAction(SemanticsAction.scrollDown);
 
-    final bool isAdjustable = data.hasAction(SemanticsAction.increase)
-        || data.hasAction(SemanticsAction.decrease);
+    final bool isAdjustable =
+        data.hasAction(SemanticsAction.increase) || data.hasAction(SemanticsAction.decrease);
 
     if (isScrollable) {
       annotations.add('scrollable');
@@ -268,30 +270,31 @@ class _SemanticsDebuggerPainter extends CustomPainter {
     // Android will avoid pronouncing duplicating tooltip and label.
     // Therefore, having two identical strings is the same as having a single
     // string.
-    final bool shouldIgnoreDuplicatedLabel = defaultTargetPlatform == TargetPlatform.android && data.attributedLabel.string == data.tooltip;
+    final bool shouldIgnoreDuplicatedLabel =
+        defaultTargetPlatform == TargetPlatform.android &&
+        data.attributedLabel.string == data.tooltip;
     final String tooltipAndLabel = <String>[
-      if (data.tooltip.isNotEmpty)
-        data.tooltip,
+      if (data.tooltip.isNotEmpty) data.tooltip,
       if (data.attributedLabel.string.isNotEmpty && !shouldIgnoreDuplicatedLabel)
         data.attributedLabel.string,
     ].join('\n');
     if (tooltipAndLabel.isEmpty) {
       message = annotations.join('; ');
     } else {
-      final String effectivelabel;
+      final String effectiveLabel;
       if (data.textDirection == null) {
-        effectivelabel = '${Unicode.FSI}$tooltipAndLabel${Unicode.PDI}';
+        effectiveLabel = '${Unicode.FSI}$tooltipAndLabel${Unicode.PDI}';
         annotations.insert(0, 'MISSING TEXT DIRECTION');
       } else {
-        effectivelabel = switch (data.textDirection!) {
+        effectiveLabel = switch (data.textDirection!) {
           TextDirection.rtl => '${Unicode.RLI}$tooltipAndLabel${Unicode.PDI}',
           TextDirection.ltr => tooltipAndLabel,
         };
       }
       if (annotations.isEmpty) {
-        message = effectivelabel;
+        message = effectiveLabel;
       } else {
-        message = '$effectivelabel (${annotations.join('; ')})';
+        message = '$effectiveLabel (${annotations.join('; ')})';
       }
     }
 
@@ -307,11 +310,9 @@ class _SemanticsDebuggerPainter extends CustomPainter {
     canvas.save();
     canvas.clipRect(rect);
     final TextPainter textPainter = TextPainter()
-      ..text = TextSpan(
-        style: labelStyle,
-        text: message,
-      )
-      ..textDirection = TextDirection.ltr // _getMessage always returns LTR text, even if node.label is RTL
+      ..text = TextSpan(style: labelStyle, text: message)
+      ..textDirection = TextDirection
+          .ltr // _getMessage always returns LTR text, even if node.label is RTL
       ..textAlign = TextAlign.center
       ..layout(maxWidth: rect.width);
 
@@ -332,14 +333,14 @@ class _SemanticsDebuggerPainter extends CustomPainter {
     return childrenDepth + 1;
   }
 
-  void _paint(Canvas canvas, SemanticsNode node, int rank) {
+  void _paint(Canvas canvas, SemanticsNode node, int rank, int indexInParent, int level) {
     canvas.save();
     if (node.transform != null) {
       canvas.transform(node.transform!.storage);
     }
     final Rect rect = node.rect;
     if (!rect.isEmpty) {
-      final Color lineColor = Color(0xFF000000 + math.Random(node.id).nextInt(0xFFFFFF));
+      final Color lineColor = _colorForNode(indexInParent, level);
       final Rect innerRect = rect.deflate(rank * 1.0);
       if (innerRect.isEmpty) {
         final Paint fill = Paint()
@@ -361,20 +362,36 @@ class _SemanticsDebuggerPainter extends CustomPainter {
     }
     if (!node.mergeAllDescendantsIntoThisNode) {
       final int childRank = rank - 1;
+      final int childLevel = level + 1;
+      int childIndex = 0;
       node.visitChildren((SemanticsNode child) {
-        _paint(canvas, child, childRank);
+        _paint(canvas, child, childRank, childIndex, childLevel);
+        childIndex += 1;
         return true;
       });
     }
     canvas.restore();
   }
+
+  static Color _colorForNode(int index, int level) {
+    return HSLColor.fromAHSL(
+      1.0,
+      // Use custom hash to ensure stable value regardless of Dart changes
+      360.0 * math.Random(_getColorSeed(index, level)).nextDouble(),
+      1.0,
+      0.7,
+    ).toColor();
+  }
+
+  static int _getColorSeed(int level, int index) {
+    // Should be no collision as long as children number < 10000.
+    return level * 10000 + index;
+  }
 }
 
 /// A widget ignores pointer event but still keeps semantics actions.
 class _IgnorePointerWithSemantics extends SingleChildRenderObjectWidget {
-  const _IgnorePointerWithSemantics({
-    super.child,
-  });
+  const _IgnorePointerWithSemantics({super.child});
 
   @override
   _RenderIgnorePointerWithSemantics createRenderObject(BuildContext context) {
@@ -386,5 +403,5 @@ class _RenderIgnorePointerWithSemantics extends RenderProxyBox {
   _RenderIgnorePointerWithSemantics();
 
   @override
-  bool hitTest(BoxHitTestResult result, { required Offset position }) => false;
+  bool hitTest(BoxHitTestResult result, {required Offset position}) => false;
 }
