@@ -10,11 +10,7 @@ import 'package:leak_tracker_flutter_testing/leak_tracker_flutter_testing.dart';
 void main() {
   testWidgets('Use home', (WidgetTester tester) async {
     await tester.pumpWidget(
-      CupertinoApp(
-        home: CupertinoTabView(
-          builder: (BuildContext context) => const Text('home'),
-        ),
-      ),
+      CupertinoApp(home: CupertinoTabView(builder: (BuildContext context) => const Text('home'))),
     );
 
     expect(find.text('home'), findsOneWidget);
@@ -24,9 +20,7 @@ void main() {
     await tester.pumpWidget(
       CupertinoApp(
         home: CupertinoTabView(
-          routes: <String, WidgetBuilder>{
-            '/': (BuildContext context) => const Text('first route'),
-          },
+          routes: <String, WidgetBuilder>{'/': (BuildContext context) => const Text('first route')},
         ),
       ),
     );
@@ -82,28 +76,31 @@ void main() {
     expect(find.text('generated home'), findsOneWidget);
   });
 
-  testWidgets('Use onUnknownRoute',
-  experimentalLeakTesting: LeakTesting.settings.withIgnoredAll(), // leaking by design because of exception
-  (WidgetTester tester) async {
-    late String unknownForRouteCalled;
-    await tester.pumpWidget(
-      CupertinoApp(
-        home: CupertinoTabView(
-          onUnknownRoute: (RouteSettings settings) {
-            unknownForRouteCalled = settings.name!;
-            return null;
-          },
+  testWidgets(
+    'Use onUnknownRoute',
+    experimentalLeakTesting: LeakTesting.settings
+        .withIgnoredAll(), // leaking by design because of exception
+    (WidgetTester tester) async {
+      late String unknownForRouteCalled;
+      await tester.pumpWidget(
+        CupertinoApp(
+          home: CupertinoTabView(
+            onUnknownRoute: (RouteSettings settings) {
+              unknownForRouteCalled = settings.name!;
+              return null;
+            },
+          ),
         ),
-      ),
-    );
+      );
 
-    expect(tester.takeException(), isFlutterError);
-    expect(unknownForRouteCalled, '/');
+      expect(tester.takeException(), isFlutterError);
+      expect(unknownForRouteCalled, '/');
 
-    // Work-around for https://github.com/flutter/flutter/issues/65655.
-    await tester.pumpWidget(Container());
-    expect(tester.takeException(), isAssertionError);
-  });
+      // Work-around for https://github.com/flutter/flutter/issues/65655.
+      await tester.pumpWidget(Container());
+      expect(tester.takeException(), isAssertionError);
+    },
+  );
 
   testWidgets('Can use navigatorKey to navigate', (WidgetTester tester) async {
     final GlobalKey<NavigatorState> key = GlobalKey();
@@ -256,7 +253,7 @@ void main() {
             },
           ),
           routes: <String, WidgetBuilder>{
-            '/2' : (BuildContext context) => const Text('second route'),
+            '/2': (BuildContext context) => const Text('second route'),
           },
         ),
       ),
@@ -302,7 +299,7 @@ void main() {
           tabBar: CupertinoTabBar(
             items: const <BottomNavigationBarItem>[
               BottomNavigationBarItem(label: '', icon: Text('1')),
-              BottomNavigationBarItem(label: '', icon: Text('2'))
+              BottomNavigationBarItem(label: '', icon: Text('2')),
             ],
           ),
           tabBuilder: (_, int i) => PopScope<Object?>(
@@ -320,7 +317,11 @@ void main() {
 
     // Simulate android back button intent.
     final ByteData message = const JSONMethodCodec().encodeMethodCall(const MethodCall('popRoute'));
-    await tester.binding.defaultBinaryMessenger.handlePlatformMessage('flutter/navigation', message, (_) {});
+    await tester.binding.defaultBinaryMessenger.handlePlatformMessage(
+      'flutter/navigation',
+      message,
+      (_) {},
+    );
     await tester.pumpAndSettle();
 
     // Navigator didn't pop, so first route is still visible
