@@ -277,7 +277,7 @@ void main() {
 
   testGesture('Rejects scale gestures from unallowed device kinds', (GestureTester tester) {
     final ScaleGestureRecognizer scale = ScaleGestureRecognizer(
-      supportedDevices: <PointerDeviceKind>{ PointerDeviceKind.touch },
+      supportedDevices: <PointerDeviceKind>{PointerDeviceKind.touch},
     );
 
     bool didStartScale = false;
@@ -309,70 +309,73 @@ void main() {
     scale.dispose();
   });
 
-  testGesture('Scale gestures starting from allowed device kinds cannot be ended from unallowed devices', (GestureTester tester) {
-    final ScaleGestureRecognizer scale = ScaleGestureRecognizer(
-      supportedDevices: <PointerDeviceKind>{ PointerDeviceKind.touch },
-    );
+  testGesture(
+    'Scale gestures starting from allowed device kinds cannot be ended from unallowed devices',
+    (GestureTester tester) {
+      final ScaleGestureRecognizer scale = ScaleGestureRecognizer(
+        supportedDevices: <PointerDeviceKind>{PointerDeviceKind.touch},
+      );
 
-    bool didStartScale = false;
-    Offset? updatedFocalPoint;
-    scale.onStart = (ScaleStartDetails details) {
-      didStartScale = true;
-      updatedFocalPoint = details.focalPoint;
-    };
+      bool didStartScale = false;
+      Offset? updatedFocalPoint;
+      scale.onStart = (ScaleStartDetails details) {
+        didStartScale = true;
+        updatedFocalPoint = details.focalPoint;
+      };
 
-    double? updatedScale;
-    scale.onUpdate = (ScaleUpdateDetails details) {
-      updatedScale = details.scale;
-      updatedFocalPoint = details.focalPoint;
-    };
+      double? updatedScale;
+      scale.onUpdate = (ScaleUpdateDetails details) {
+        updatedScale = details.scale;
+        updatedFocalPoint = details.focalPoint;
+      };
 
-    bool didEndScale = false;
-    scale.onEnd = (ScaleEndDetails details) {
-      didEndScale = true;
-    };
+      bool didEndScale = false;
+      scale.onEnd = (ScaleEndDetails details) {
+        didEndScale = true;
+      };
 
-    final TestPointer touchPointer = TestPointer();
+      final TestPointer touchPointer = TestPointer();
 
-    final PointerDownEvent down = touchPointer.down(Offset.zero);
-    scale.addPointer(down);
-    tester.closeArena(1);
+      final PointerDownEvent down = touchPointer.down(Offset.zero);
+      scale.addPointer(down);
+      tester.closeArena(1);
 
-    // One-finger panning
-    tester.route(down);
-    expect(didStartScale, isTrue);
-    didStartScale = false;
-    expect(updatedScale, isNull);
-    expect(updatedFocalPoint, Offset.zero);
-    expect(didEndScale, isFalse);
+      // One-finger panning
+      tester.route(down);
+      expect(didStartScale, isTrue);
+      didStartScale = false;
+      expect(updatedScale, isNull);
+      expect(updatedFocalPoint, Offset.zero);
+      expect(didEndScale, isFalse);
 
-    // The gesture can start using one touch finger.
-    tester.route(touchPointer.move(const Offset(20.0, 30.0)));
-    expect(updatedFocalPoint, const Offset(20.0, 30.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 1.0);
-    updatedScale = null;
-    expect(didEndScale, isFalse);
+      // The gesture can start using one touch finger.
+      tester.route(touchPointer.move(const Offset(20.0, 30.0)));
+      expect(updatedFocalPoint, const Offset(20.0, 30.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 1.0);
+      updatedScale = null;
+      expect(didEndScale, isFalse);
 
-    // Two-finger scaling
-    final TestPointer mousePointer = TestPointer(2, PointerDeviceKind.mouse);
-    final PointerDownEvent down2 = mousePointer.down(const Offset(10.0, 20.0));
-    scale.addPointer(down2);
-    tester.closeArena(2);
-    tester.route(down2);
+      // Two-finger scaling
+      final TestPointer mousePointer = TestPointer(2, PointerDeviceKind.mouse);
+      final PointerDownEvent down2 = mousePointer.down(const Offset(10.0, 20.0));
+      scale.addPointer(down2);
+      tester.closeArena(2);
+      tester.route(down2);
 
-    // Mouse-generated events are ignored.
-    expect(didEndScale, isFalse);
-    expect(updatedScale, isNull);
-    expect(didStartScale, isFalse);
+      // Mouse-generated events are ignored.
+      expect(didEndScale, isFalse);
+      expect(updatedScale, isNull);
+      expect(didStartScale, isFalse);
 
-    // Zoom in using a mouse doesn't work either.
-    tester.route(mousePointer.move(const Offset(0.0, 10.0)));
-    expect(updatedScale, isNull);
-    expect(didEndScale, isFalse);
+      // Zoom in using a mouse doesn't work either.
+      tester.route(mousePointer.move(const Offset(0.0, 10.0)));
+      expect(updatedScale, isNull);
+      expect(didEndScale, isFalse);
 
-    scale.dispose();
-  });
+      scale.dispose();
+    },
+  );
 
   testGesture('Scale gesture competes with drag', (GestureTester tester) {
     final ScaleGestureRecognizer scale = ScaleGestureRecognizer();
@@ -380,12 +383,22 @@ void main() {
 
     final List<String> log = <String>[];
 
-    scale.onStart = (ScaleStartDetails details) { log.add('scale-start'); };
-    scale.onUpdate = (ScaleUpdateDetails details) { log.add('scale-update'); };
-    scale.onEnd = (ScaleEndDetails details) { log.add('scale-end'); };
+    scale.onStart = (ScaleStartDetails details) {
+      log.add('scale-start');
+    };
+    scale.onUpdate = (ScaleUpdateDetails details) {
+      log.add('scale-update');
+    };
+    scale.onEnd = (ScaleEndDetails details) {
+      log.add('scale-end');
+    };
 
-    drag.onStart = (DragStartDetails details) { log.add('drag-start'); };
-    drag.onEnd = (DragEndDetails details) { log.add('drag-end'); };
+    drag.onStart = (DragStartDetails details) {
+      log.add('drag-start');
+    };
+    drag.onEnd = (DragEndDetails details) {
+      log.add('drag-end');
+    };
 
     final TestPointer pointer1 = TestPointer();
 
@@ -638,7 +651,7 @@ void main() {
     updatedFocalPoint = null;
     expect(updatedDelta, const Offset(10.0, 10.0));
     updatedDelta = null;
-    expect(updatedRotation, - math.pi);
+    expect(updatedRotation, -math.pi);
     updatedRotation = null;
     expect(updatedPointerCount, 2);
     updatedPointerCount = null;
@@ -758,7 +771,9 @@ void main() {
     scale.dispose();
   });
 
-  testGesture('Should recognize scale gestures from pointer pan/zoom events', (GestureTester tester) {
+  testGesture('Should recognize scale gestures from pointer pan/zoom events', (
+    GestureTester tester,
+  ) {
     final ScaleGestureRecognizer scale = ScaleGestureRecognizer();
     addTearDown(scale.dispose);
     final HorizontalDragGestureRecognizer drag = HorizontalDragGestureRecognizer();
@@ -1000,7 +1015,14 @@ void main() {
     // Change the scale and angle of the pan/zoom to test combining.
     // Scale should be multiplied together.
     // Rotation angle should be added together.
-    tester.route(panZoomPointer.panZoomUpdate(Offset.zero, pan: const Offset(40, 40), scale: math.sqrt(2), rotation: math.pi / 3));
+    tester.route(
+      panZoomPointer.panZoomUpdate(
+        Offset.zero,
+        pan: const Offset(40, 40),
+        scale: math.sqrt(2),
+        rotation: math.pi / 3,
+      ),
+    );
     expect(didStartScale, isFalse);
     expect(updatedFocalPoint, const Offset(30, 30));
     updatedFocalPoint = null;
@@ -1019,7 +1041,14 @@ void main() {
     expect(didEndScale, isFalse);
 
     // Move the pan/zoom origin to test combining.
-    tester.route(panZoomPointer.panZoomUpdate(const Offset(15, 15), pan: const Offset(55, 55), scale: math.sqrt(2), rotation: math.pi / 3));
+    tester.route(
+      panZoomPointer.panZoomUpdate(
+        const Offset(15, 15),
+        pan: const Offset(55, 55),
+        scale: math.sqrt(2),
+        rotation: math.pi / 3,
+      ),
+    );
     expect(didStartScale, isFalse);
     expect(updatedFocalPoint, const Offset(40, 40));
     updatedFocalPoint = null;
@@ -1066,12 +1095,22 @@ void main() {
 
     final List<String> log = <String>[];
 
-    scale.onStart = (ScaleStartDetails details) { log.add('scale-start'); };
-    scale.onUpdate = (ScaleUpdateDetails details) { log.add('scale-update'); };
-    scale.onEnd = (ScaleEndDetails details) { log.add('scale-end'); };
+    scale.onStart = (ScaleStartDetails details) {
+      log.add('scale-start');
+    };
+    scale.onUpdate = (ScaleUpdateDetails details) {
+      log.add('scale-update');
+    };
+    scale.onEnd = (ScaleEndDetails details) {
+      log.add('scale-end');
+    };
 
-    drag.onStart = (DragStartDetails details) { log.add('drag-start'); };
-    drag.onEnd = (DragEndDetails details) { log.add('drag-end'); };
+    drag.onStart = (DragStartDetails details) {
+      log.add('drag-start');
+    };
+    drag.onEnd = (DragEndDetails details) {
+      log.add('drag-end');
+    };
 
     final TestPointer pointer1 = TestPointer(2, PointerDeviceKind.trackpad);
 
@@ -1088,7 +1127,9 @@ void main() {
 
     // Scale will win if focal point delta exceeds 18.0*2.
 
-    tester.route(pointer1.panZoomUpdate(const Offset(10.0, 10.0), pan: const Offset(10.0, 40.0))); // delta of 40.0 exceeds 18.0*2.
+    tester.route(
+      pointer1.panZoomUpdate(const Offset(10.0, 10.0), pan: const Offset(10.0, 40.0)),
+    ); // delta of 40.0 exceeds 18.0*2.
     expect(log, equals(<String>['scale-start', 'scale-update']));
     log.clear();
 
@@ -1142,8 +1183,12 @@ void main() {
     drag.dispose();
   });
 
-  testGesture('Scale gesture from pan/zoom events properly handles DragStartBehavior.start', (GestureTester tester) {
-    final ScaleGestureRecognizer scale = ScaleGestureRecognizer(dragStartBehavior: DragStartBehavior.start);
+  testGesture('Scale gesture from pan/zoom events properly handles DragStartBehavior.start', (
+    GestureTester tester,
+  ) {
+    final ScaleGestureRecognizer scale = ScaleGestureRecognizer(
+      dragStartBehavior: DragStartBehavior.start,
+    );
     addTearDown(scale.dispose);
     final HorizontalDragGestureRecognizer drag = HorizontalDragGestureRecognizer();
     addTearDown(drag.dispose);
@@ -1250,7 +1295,7 @@ void main() {
   testGesture('scale trackpadScrollCausesScale', (GestureTester tester) {
     final ScaleGestureRecognizer scale = ScaleGestureRecognizer(
       dragStartBehavior: DragStartBehavior.start,
-      trackpadScrollCausesScale: true
+      trackpadScrollCausesScale: true,
     );
 
     bool didStartScale = false;
@@ -1337,7 +1382,7 @@ void main() {
     didEndScale = false;
 
     // Try with a different trackpadScrollToScaleFactor
-    scale.trackpadScrollToScaleFactor = const Offset(1/125, 0);
+    scale.trackpadScrollToScaleFactor = const Offset(1 / 125, 0);
 
     final PointerPanZoomStartEvent start2 = pointer1.panZoomStart(Offset.zero);
     scale.addPointerPanZoom(start2);
@@ -1404,7 +1449,7 @@ void main() {
   testGesture('scale ending velocity', (GestureTester tester) {
     final ScaleGestureRecognizer scale = ScaleGestureRecognizer(
       dragStartBehavior: DragStartBehavior.start,
-      trackpadScrollCausesScale: true
+      trackpadScrollCausesScale: true,
     );
 
     bool didStartScale = false;
@@ -1440,11 +1485,13 @@ void main() {
 
     // Zoom in by scrolling up.
     for (int i = 0; i < 100; i++) {
-      tester.route(pointer1.panZoomUpdate(
-        Offset.zero,
-        pan: Offset(0, i * -10),
-        timeStamp: Duration(milliseconds: i * 25)
-      ));
+      tester.route(
+        pointer1.panZoomUpdate(
+          Offset.zero,
+          pan: Offset(0, i * -10),
+          timeStamp: Duration(milliseconds: i * 25),
+        ),
+      );
     }
 
     // End.
@@ -1458,295 +1505,416 @@ void main() {
     scale.dispose();
   });
 
-  testGesture('ScaleStartDetails and ScaleUpdateDetails callbacks should contain their event.timestamp', (GestureTester tester) {
+  testGesture(
+    'ScaleStartDetails and ScaleUpdateDetails callbacks should contain their event.timestamp',
+    (GestureTester tester) {
+      final ScaleGestureRecognizer scale = ScaleGestureRecognizer();
+      final TapGestureRecognizer tap = TapGestureRecognizer();
+
+      bool didStartScale = false;
+      Offset? updatedFocalPoint;
+      Duration? initialSourceTimestamp;
+      scale.onStart = (ScaleStartDetails details) {
+        didStartScale = true;
+        updatedFocalPoint = details.focalPoint;
+        initialSourceTimestamp = details.sourceTimeStamp;
+      };
+
+      double? updatedScale;
+      double? updatedHorizontalScale;
+      double? updatedVerticalScale;
+      Offset? updatedDelta;
+      Duration? updatedSourceTimestamp;
+      scale.onUpdate = (ScaleUpdateDetails details) {
+        updatedScale = details.scale;
+        updatedHorizontalScale = details.horizontalScale;
+        updatedVerticalScale = details.verticalScale;
+        updatedFocalPoint = details.focalPoint;
+        updatedDelta = details.focalPointDelta;
+        updatedSourceTimestamp = details.sourceTimeStamp;
+      };
+
+      bool didEndScale = false;
+      scale.onEnd = (ScaleEndDetails details) {
+        didEndScale = true;
+      };
+
+      bool didTap = false;
+      tap.onTap = () {
+        didTap = true;
+      };
+
+      final TestPointer pointer1 = TestPointer();
+
+      final PointerDownEvent down = pointer1.down(
+        Offset.zero,
+        timeStamp: const Duration(milliseconds: 10),
+      );
+      scale.addPointer(down);
+      tap.addPointer(down);
+
+      tester.closeArena(1);
+      expect(didStartScale, isFalse);
+      expect(updatedScale, isNull);
+      expect(updatedFocalPoint, isNull);
+      expect(updatedDelta, isNull);
+      expect(updatedSourceTimestamp, isNull);
+      expect(didEndScale, isFalse);
+      expect(didTap, isFalse);
+      expect(initialSourceTimestamp, isNull);
+
+      // One-finger panning.
+      tester.route(down);
+      expect(didStartScale, isFalse);
+      expect(updatedScale, isNull);
+      expect(updatedFocalPoint, isNull);
+      expect(updatedDelta, isNull);
+      expect(didEndScale, isFalse);
+      expect(didTap, isFalse);
+      expect(initialSourceTimestamp, isNull);
+
+      tester.route(
+        pointer1.move(const Offset(20.0, 30.0), timeStamp: const Duration(milliseconds: 20)),
+      );
+      expect(didStartScale, isTrue);
+      didStartScale = false;
+      expect(updatedFocalPoint, const Offset(20.0, 30.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 1.0);
+      updatedScale = null;
+      expect(updatedDelta, const Offset(20.0, 30.0));
+      updatedDelta = null;
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 20));
+      updatedSourceTimestamp = null;
+      expect(initialSourceTimestamp, const Duration(milliseconds: 10));
+      initialSourceTimestamp = null;
+      expect(didEndScale, isFalse);
+      expect(didTap, isFalse);
+      expect(scale.pointerCount, 1);
+
+      // Two-finger scaling.
+      final TestPointer pointer2 = TestPointer(2);
+      final PointerDownEvent down2 = pointer2.down(
+        const Offset(10.0, 20.0),
+        timeStamp: const Duration(milliseconds: 30),
+      );
+      scale.addPointer(down2);
+      tap.addPointer(down2);
+      tester.closeArena(2);
+      tester.route(down2);
+      expect(scale.pointerCount, 2);
+
+      expect(didEndScale, isTrue);
+      didEndScale = false;
+      expect(updatedScale, isNull);
+      expect(updatedFocalPoint, isNull);
+      expect(updatedDelta, isNull);
+      expect(updatedSourceTimestamp, isNull);
+      expect(didStartScale, isFalse);
+      expect(initialSourceTimestamp, isNull);
+
+      // Zoom in.
+      tester.route(
+        pointer2.move(const Offset(0.0, 10.0), timeStamp: const Duration(milliseconds: 40)),
+      );
+      expect(didStartScale, isTrue);
+      didStartScale = false;
+      expect(updatedFocalPoint, const Offset(10.0, 20.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 2.0);
+      expect(updatedHorizontalScale, 2.0);
+      expect(updatedVerticalScale, 2.0);
+      expect(updatedDelta, const Offset(-5.0, -5.0));
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 40));
+      expect(initialSourceTimestamp, const Duration(milliseconds: 40));
+      updatedScale = null;
+      updatedHorizontalScale = null;
+      updatedVerticalScale = null;
+      updatedDelta = null;
+      updatedSourceTimestamp = null;
+      initialSourceTimestamp = null;
+      expect(didEndScale, isFalse);
+      expect(didTap, isFalse);
+
+      // Zoom out.
+      tester.route(
+        pointer2.move(const Offset(15.0, 25.0), timeStamp: const Duration(milliseconds: 50)),
+      );
+      expect(updatedFocalPoint, const Offset(17.5, 27.5));
+      expect(updatedScale, 0.5);
+      expect(updatedHorizontalScale, 0.5);
+      expect(updatedVerticalScale, 0.5);
+      expect(updatedDelta, const Offset(7.5, 7.5));
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 50));
+      expect(didTap, isFalse);
+      expect(initialSourceTimestamp, isNull);
+
+      // Horizontal scaling.
+      tester.route(
+        pointer2.move(const Offset(0.0, 20.0), timeStamp: const Duration(milliseconds: 60)),
+      );
+      expect(updatedHorizontalScale, 2.0);
+      expect(updatedVerticalScale, 1.0);
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 60));
+      expect(initialSourceTimestamp, isNull);
+
+      // Vertical scaling.
+      tester.route(
+        pointer2.move(const Offset(10.0, 10.0), timeStamp: const Duration(milliseconds: 70)),
+      );
+      expect(updatedHorizontalScale, 1.0);
+      expect(updatedVerticalScale, 2.0);
+      expect(updatedDelta, const Offset(5.0, -5.0));
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 70));
+      expect(initialSourceTimestamp, isNull);
+      tester.route(pointer2.move(const Offset(15.0, 25.0)));
+      updatedFocalPoint = null;
+      updatedScale = null;
+      updatedDelta = null;
+      updatedSourceTimestamp = null;
+
+      // Three-finger scaling.
+      final TestPointer pointer3 = TestPointer(3);
+      final PointerDownEvent down3 = pointer3.down(
+        const Offset(25.0, 35.0),
+        timeStamp: const Duration(milliseconds: 80),
+      );
+      scale.addPointer(down3);
+      tap.addPointer(down3);
+      tester.closeArena(3);
+      tester.route(down3);
+
+      expect(didEndScale, isTrue);
+      didEndScale = false;
+      expect(updatedScale, isNull);
+      expect(updatedFocalPoint, isNull);
+      expect(updatedDelta, isNull);
+      expect(didStartScale, isFalse);
+      expect(initialSourceTimestamp, isNull);
+
+      // Zoom in.
+      tester.route(
+        pointer3.move(const Offset(55.0, 65.0), timeStamp: const Duration(milliseconds: 90)),
+      );
+      expect(didStartScale, isTrue);
+      didStartScale = false;
+      expect(updatedFocalPoint, const Offset(30.0, 40.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 5.0);
+      updatedScale = null;
+      expect(updatedDelta, const Offset(10.0, 10.0));
+      updatedDelta = null;
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 90));
+      updatedSourceTimestamp = null;
+      expect(initialSourceTimestamp, const Duration(milliseconds: 90));
+      initialSourceTimestamp = null;
+      expect(didEndScale, isFalse);
+      expect(didTap, isFalse);
+
+      // Return to original positions but with different fingers.
+      tester.route(
+        pointer1.move(const Offset(25.0, 35.0), timeStamp: const Duration(milliseconds: 100)),
+      );
+      tester.route(
+        pointer2.move(const Offset(20.0, 30.0), timeStamp: const Duration(milliseconds: 110)),
+      );
+      tester.route(
+        pointer3.move(const Offset(15.0, 25.0), timeStamp: const Duration(milliseconds: 120)),
+      );
+      expect(didStartScale, isFalse);
+      expect(updatedFocalPoint, const Offset(20.0, 30.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 1.0);
+      updatedScale = null;
+      expect(updatedDelta!.dx, closeTo(-13.3, 0.1));
+      expect(updatedDelta!.dy, closeTo(-13.3, 0.1));
+      updatedDelta = null;
+      expect(didEndScale, isFalse);
+      expect(didTap, isFalse);
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 120));
+      updatedSourceTimestamp = null;
+      expect(initialSourceTimestamp, isNull);
+      tester.route(pointer1.up());
+      expect(didStartScale, isFalse);
+      expect(updatedFocalPoint, isNull);
+      expect(updatedScale, isNull);
+      expect(updatedDelta, isNull);
+      expect(didEndScale, isTrue);
+      expect(updatedSourceTimestamp, isNull);
+      expect(initialSourceTimestamp, isNull);
+      didEndScale = false;
+      expect(didTap, isFalse);
+
+      // Continue scaling with two fingers.
+      tester.route(
+        pointer3.move(const Offset(10.0, 20.0), timeStamp: const Duration(milliseconds: 130)),
+      );
+      expect(didStartScale, isTrue);
+      didStartScale = false;
+      expect(updatedFocalPoint, const Offset(15.0, 25.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 2.0);
+      updatedScale = null;
+      expect(updatedDelta, const Offset(-2.5, -2.5));
+      updatedDelta = null;
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 130));
+      updatedSourceTimestamp = null;
+      expect(initialSourceTimestamp, const Duration(milliseconds: 130));
+      initialSourceTimestamp = null;
+
+      // Continue rotating with two fingers.
+      tester.route(
+        pointer3.move(const Offset(30.0, 40.0), timeStamp: const Duration(milliseconds: 140)),
+      );
+      expect(updatedFocalPoint, const Offset(25.0, 35.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 2.0);
+      updatedScale = null;
+      expect(updatedDelta, const Offset(10.0, 10.0));
+      updatedDelta = null;
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 140));
+      updatedSourceTimestamp = null;
+      expect(initialSourceTimestamp, isNull);
+      tester.route(
+        pointer3.move(const Offset(10.0, 20.0), timeStamp: const Duration(milliseconds: 140)),
+      );
+      expect(updatedFocalPoint, const Offset(15.0, 25.0));
+      updatedFocalPoint = null;
+      expect(updatedScale, 2.0);
+      updatedScale = null;
+      expect(updatedDelta, const Offset(-10.0, -10.0));
+      updatedDelta = null;
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 140));
+      updatedSourceTimestamp = null;
+      expect(initialSourceTimestamp, isNull);
+
+      tester.route(pointer2.up());
+      expect(didStartScale, isFalse);
+      expect(updatedFocalPoint, isNull);
+      expect(updatedScale, isNull);
+      expect(updatedDelta, isNull);
+      expect(updatedSourceTimestamp, isNull);
+      expect(initialSourceTimestamp, isNull);
+      expect(didEndScale, isTrue);
+      didEndScale = false;
+      expect(didTap, isFalse);
+
+      // Continue panning with one finger.
+      tester.route(pointer3.move(Offset.zero, timeStamp: const Duration(milliseconds: 150)));
+      expect(didStartScale, isTrue);
+      didStartScale = false;
+      expect(updatedFocalPoint, Offset.zero);
+      updatedFocalPoint = null;
+      expect(updatedScale, 1.0);
+      updatedScale = null;
+      expect(updatedDelta, const Offset(-10.0, -20.0));
+      updatedDelta = null;
+      expect(updatedSourceTimestamp, const Duration(milliseconds: 150));
+      updatedSourceTimestamp = null;
+      expect(initialSourceTimestamp, const Duration(milliseconds: 150));
+      initialSourceTimestamp = null;
+
+      // We are done.
+      tester.route(pointer3.up());
+      expect(didStartScale, isFalse);
+      expect(updatedFocalPoint, isNull);
+      expect(updatedScale, isNull);
+      expect(updatedDelta, isNull);
+      expect(didEndScale, isTrue);
+      expect(updatedSourceTimestamp, isNull);
+      expect(initialSourceTimestamp, isNull);
+      didEndScale = false;
+      expect(didTap, isFalse);
+
+      scale.dispose();
+      tap.dispose();
+    },
+  );
+
+  testGesture('ScaleStartDetails should contain the correct PointerDeviceKind', (
+    GestureTester tester,
+  ) {
     final ScaleGestureRecognizer scale = ScaleGestureRecognizer();
-    final TapGestureRecognizer tap = TapGestureRecognizer();
 
     bool didStartScale = false;
-    Offset? updatedFocalPoint;
-    Duration? initialSourceTimestamp;
+    PointerDeviceKind? updatedKind;
     scale.onStart = (ScaleStartDetails details) {
       didStartScale = true;
-      updatedFocalPoint = details.focalPoint;
-      initialSourceTimestamp = details.sourceTimeStamp;
+      updatedKind = details.kind;
     };
-
-    double? updatedScale;
-    double? updatedHorizontalScale;
-    double? updatedVerticalScale;
-    Offset? updatedDelta;
-    Duration? updatedSourceTimestamp;
-    scale.onUpdate = (ScaleUpdateDetails details) {
-      updatedScale = details.scale;
-      updatedHorizontalScale = details.horizontalScale;
-      updatedVerticalScale = details.verticalScale;
-      updatedFocalPoint = details.focalPoint;
-      updatedDelta = details.focalPointDelta;
-      updatedSourceTimestamp = details.sourceTimeStamp;
-    };
-
-    bool didEndScale = false;
     scale.onEnd = (ScaleEndDetails details) {
-      didEndScale = true;
+      didStartScale = false;
     };
 
-    bool didTap = false;
-    tap.onTap = () {
-      didTap = true;
-    };
-
-    final TestPointer pointer1 = TestPointer();
-
-    final PointerDownEvent down = pointer1.down(Offset.zero, timeStamp: const Duration(milliseconds: 10));
+    // The default kind is touch.
+    // ignore: avoid_redundant_argument_values
+    final TestPointer pointer1 = TestPointer(1, PointerDeviceKind.touch);
+    final PointerDownEvent down = pointer1.down(Offset.zero);
     scale.addPointer(down);
-    tap.addPointer(down);
-
     tester.closeArena(1);
-    expect(didStartScale, isFalse);
-    expect(updatedScale, isNull);
-    expect(updatedFocalPoint, isNull);
-    expect(updatedDelta, isNull);
-    expect(updatedSourceTimestamp, isNull);
-    expect(didEndScale, isFalse);
-    expect(didTap, isFalse);
-    expect(initialSourceTimestamp, isNull);
-
-    // One-finger panning.
+    // One-finger panning
     tester.route(down);
-    expect(didStartScale, isFalse);
-    expect(updatedScale, isNull);
-    expect(updatedFocalPoint, isNull);
-    expect(updatedDelta, isNull);
-    expect(didEndScale, isFalse);
-    expect(didTap, isFalse);
-    expect(initialSourceTimestamp, isNull);
-
-    tester.route(pointer1.move(const Offset(20.0, 30.0), timeStamp: const Duration(milliseconds: 20)));
+    tester.route(pointer1.move(const Offset(20.0, 30.0)));
     expect(didStartScale, isTrue);
-    didStartScale = false;
-    expect(updatedFocalPoint, const Offset(20.0, 30.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 1.0);
-    updatedScale = null;
-    expect(updatedDelta, const Offset(20.0, 30.0));
-    updatedDelta = null;
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 20));
-    updatedSourceTimestamp = null;
-    expect(initialSourceTimestamp, const Duration(milliseconds: 10));
-    initialSourceTimestamp = null;
-    expect(didEndScale, isFalse);
-    expect(didTap, isFalse);
-    expect(scale.pointerCount, 1);
-
-    // Two-finger scaling.
-    final TestPointer pointer2 = TestPointer(2);
-    final PointerDownEvent down2 = pointer2.down(const Offset(10.0, 20.0, ), timeStamp: const Duration(milliseconds: 30));
-    scale.addPointer(down2);
-    tap.addPointer(down2);
-    tester.closeArena(2);
-    tester.route(down2);
-    expect(scale.pointerCount, 2);
-
-    expect(didEndScale, isTrue);
-    didEndScale = false;
-    expect(updatedScale, isNull);
-    expect(updatedFocalPoint, isNull);
-    expect(updatedDelta, isNull);
-    expect(updatedSourceTimestamp, isNull);
-    expect(didStartScale, isFalse);
-    expect(initialSourceTimestamp, isNull);
-
-    // Zoom in.
-    tester.route(pointer2.move(const Offset(0.0, 10.0), timeStamp: const Duration(milliseconds: 40)));
-    expect(didStartScale, isTrue);
-    didStartScale = false;
-    expect(updatedFocalPoint, const Offset(10.0, 20.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 2.0);
-    expect(updatedHorizontalScale, 2.0);
-    expect(updatedVerticalScale, 2.0);
-    expect(updatedDelta, const Offset(-5.0, -5.0));
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 40));
-    expect(initialSourceTimestamp, const Duration(milliseconds: 40));
-    updatedScale = null;
-    updatedHorizontalScale = null;
-    updatedVerticalScale = null;
-    updatedDelta = null;
-    updatedSourceTimestamp = null;
-    initialSourceTimestamp = null;
-    expect(didEndScale, isFalse);
-    expect(didTap, isFalse);
-
-    // Zoom out.
-    tester.route(pointer2.move(const Offset(15.0, 25.0), timeStamp: const Duration(milliseconds: 50)));
-    expect(updatedFocalPoint, const Offset(17.5, 27.5));
-    expect(updatedScale, 0.5);
-    expect(updatedHorizontalScale, 0.5);
-    expect(updatedVerticalScale, 0.5);
-    expect(updatedDelta, const Offset(7.5, 7.5));
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 50));
-    expect(didTap, isFalse);
-    expect(initialSourceTimestamp, isNull);
-
-
-    // Horizontal scaling.
-    tester.route(pointer2.move(const Offset(0.0, 20.0), timeStamp: const Duration(milliseconds: 60)));
-    expect(updatedHorizontalScale, 2.0);
-    expect(updatedVerticalScale, 1.0);
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 60));
-    expect(initialSourceTimestamp, isNull);
-
-    // Vertical scaling.
-    tester.route(pointer2.move(const Offset(10.0, 10.0), timeStamp: const Duration(milliseconds: 70)));
-    expect(updatedHorizontalScale, 1.0);
-    expect(updatedVerticalScale, 2.0);
-    expect(updatedDelta, const Offset(5.0, -5.0));
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 70));
-    expect(initialSourceTimestamp, isNull);
-    tester.route(pointer2.move(const Offset(15.0, 25.0)));
-    updatedFocalPoint = null;
-    updatedScale = null;
-    updatedDelta = null;
-    updatedSourceTimestamp = null;
-
-    // Three-finger scaling.
-    final TestPointer pointer3 = TestPointer(3);
-    final PointerDownEvent down3 = pointer3.down(const Offset(25.0, 35.0), timeStamp: const Duration(milliseconds: 80));
-    scale.addPointer(down3);
-    tap.addPointer(down3);
-    tester.closeArena(3);
-    tester.route(down3);
-
-    expect(didEndScale, isTrue);
-    didEndScale = false;
-    expect(updatedScale, isNull);
-    expect(updatedFocalPoint, isNull);
-    expect(updatedDelta, isNull);
-    expect(didStartScale, isFalse);
-    expect(initialSourceTimestamp, isNull);
-
-
-    // Zoom in.
-    tester.route(pointer3.move(const Offset(55.0, 65.0), timeStamp: const Duration(milliseconds: 90)));
-    expect(didStartScale, isTrue);
-    didStartScale = false;
-    expect(updatedFocalPoint, const Offset(30.0, 40.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 5.0);
-    updatedScale = null;
-    expect(updatedDelta, const Offset(10.0, 10.0));
-    updatedDelta = null;
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 90));
-    updatedSourceTimestamp = null;
-    expect(initialSourceTimestamp, const Duration(milliseconds: 90));
-    initialSourceTimestamp = null;
-    expect(didEndScale, isFalse);
-    expect(didTap, isFalse);
-
-    // Return to original positions but with different fingers.
-    tester.route(pointer1.move(const Offset(25.0, 35.0), timeStamp: const Duration(milliseconds: 100)));
-    tester.route(pointer2.move(const Offset(20.0, 30.0), timeStamp: const Duration(milliseconds: 110)));
-    tester.route(pointer3.move(const Offset(15.0, 25.0), timeStamp: const Duration(milliseconds: 120)));
-    expect(didStartScale, isFalse);
-    expect(updatedFocalPoint, const Offset(20.0, 30.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 1.0);
-    updatedScale = null;
-    expect(updatedDelta!.dx, closeTo(-13.3, 0.1));
-    expect(updatedDelta!.dy, closeTo(-13.3, 0.1));
-    updatedDelta = null;
-    expect(didEndScale, isFalse);
-    expect(didTap, isFalse);
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 120));
-    updatedSourceTimestamp = null;
-    expect(initialSourceTimestamp, isNull);
+    expect(updatedKind, PointerDeviceKind.touch);
     tester.route(pointer1.up());
     expect(didStartScale, isFalse);
-    expect(updatedFocalPoint, isNull);
-    expect(updatedScale, isNull);
-    expect(updatedDelta, isNull);
-    expect(didEndScale, isTrue);
-    expect(updatedSourceTimestamp, isNull);
-    expect(initialSourceTimestamp, isNull);
-    didEndScale = false;
-    expect(didTap, isFalse);
 
-    // Continue scaling with two fingers.
-    tester.route(pointer3.move(const Offset(10.0, 20.0), timeStamp: const Duration(milliseconds: 130)));
+    final TestPointer pointer2 = TestPointer(2, PointerDeviceKind.mouse);
+    final PointerDownEvent down2 = pointer2.down(const Offset(10.0, 20.0));
+    scale.addPointer(down2);
+    tester.closeArena(2);
+    tester.route(down2);
+    tester.route(pointer2.move(const Offset(20.0, 30.0)));
     expect(didStartScale, isTrue);
-    didStartScale = false;
-    expect(updatedFocalPoint, const Offset(15.0, 25.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 2.0);
-    updatedScale = null;
-    expect(updatedDelta, const Offset(-2.5, -2.5));
-    updatedDelta = null;
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 130));
-    updatedSourceTimestamp = null;
-    expect(initialSourceTimestamp, const Duration(milliseconds: 130));
-    initialSourceTimestamp = null;
-
-    // Continue rotating with two fingers.
-    tester.route(pointer3.move(const Offset(30.0, 40.0), timeStamp: const Duration(milliseconds: 140)));
-    expect(updatedFocalPoint, const Offset(25.0, 35.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 2.0);
-    updatedScale = null;
-    expect(updatedDelta, const Offset(10.0, 10.0));
-    updatedDelta = null;
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 140));
-    updatedSourceTimestamp = null;
-    expect(initialSourceTimestamp, isNull);
-    tester.route(pointer3.move(const Offset(10.0, 20.0), timeStamp: const Duration(milliseconds: 140)));
-    expect(updatedFocalPoint, const Offset(15.0, 25.0));
-    updatedFocalPoint = null;
-    expect(updatedScale, 2.0);
-    updatedScale = null;
-    expect(updatedDelta, const Offset(-10.0, -10.0));
-    updatedDelta = null;
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 140));
-    updatedSourceTimestamp = null;
-    expect(initialSourceTimestamp, isNull);
-
+    expect(updatedKind, PointerDeviceKind.mouse);
     tester.route(pointer2.up());
     expect(didStartScale, isFalse);
-    expect(updatedFocalPoint, isNull);
-    expect(updatedScale, isNull);
-    expect(updatedDelta, isNull);
-    expect(updatedSourceTimestamp, isNull);
-    expect(initialSourceTimestamp, isNull);
-    expect(didEndScale, isTrue);
-    didEndScale = false;
-    expect(didTap, isFalse);
 
-    // Continue panning with one finger.
-    tester.route(pointer3.move(Offset.zero, timeStamp: const Duration(milliseconds: 150)));
+    final TestPointer pointer3 = TestPointer(3, PointerDeviceKind.stylus);
+    final PointerDownEvent down3 = pointer3.down(const Offset(10.0, 20.0));
+    scale.addPointer(down3);
+    tester.closeArena(3);
+    tester.route(down3);
+    tester.route(pointer3.move(const Offset(20.0, 30.0)));
     expect(didStartScale, isTrue);
-    didStartScale = false;
-    expect(updatedFocalPoint, Offset.zero);
-    updatedFocalPoint = null;
-    expect(updatedScale, 1.0);
-    updatedScale = null;
-    expect(updatedDelta, const Offset(-10.0, -20.0));
-    updatedDelta = null;
-    expect(updatedSourceTimestamp, const Duration(milliseconds: 150));
-    updatedSourceTimestamp = null;
-    expect(initialSourceTimestamp, const Duration(milliseconds: 150));
-    initialSourceTimestamp = null;
-
-    // We are done.
+    expect(updatedKind, PointerDeviceKind.stylus);
     tester.route(pointer3.up());
     expect(didStartScale, isFalse);
-    expect(updatedFocalPoint, isNull);
-    expect(updatedScale, isNull);
-    expect(updatedDelta, isNull);
-    expect(didEndScale, isTrue);
-    expect(updatedSourceTimestamp, isNull);
-    expect(initialSourceTimestamp, isNull);
-    didEndScale = false;
-    expect(didTap, isFalse);
+
+    final TestPointer pointer4 = TestPointer(4, PointerDeviceKind.invertedStylus);
+    final PointerDownEvent down4 = pointer4.down(const Offset(10.0, 20.0));
+    scale.addPointer(down4);
+    tester.closeArena(4);
+    tester.route(down4);
+    tester.route(pointer4.move(const Offset(20.0, 30.0)));
+    expect(didStartScale, isTrue);
+    expect(updatedKind, PointerDeviceKind.invertedStylus);
+    tester.route(pointer4.up());
+    expect(didStartScale, isFalse);
+
+    final TestPointer pointer5 = TestPointer(5, PointerDeviceKind.unknown);
+    final PointerDownEvent down5 = pointer5.down(const Offset(10.0, 20.0));
+    scale.addPointer(down5);
+    tester.closeArena(5);
+    tester.route(down5);
+    tester.route(pointer5.move(const Offset(20.0, 30.0)));
+    expect(didStartScale, isTrue);
+    expect(updatedKind, PointerDeviceKind.unknown);
+    tester.route(pointer5.up());
+    expect(didStartScale, isFalse);
+
+    final TestPointer pointer6 = TestPointer(6, PointerDeviceKind.trackpad);
+    final PointerPanZoomStartEvent down6 = pointer6.panZoomStart(const Offset(10.0, 20.0));
+    scale.addPointerPanZoom(down6);
+    tester.closeArena(6);
+    tester.route(down6);
+    tester.route(pointer6.panZoomUpdate(const Offset(20.0, 30.0)));
+    expect(didStartScale, isTrue);
+    expect(updatedKind, PointerDeviceKind.trackpad);
+    tester.route(pointer6.panZoomEnd());
+    expect(didStartScale, isFalse);
 
     scale.dispose();
-    tap.dispose();
   });
 }
