@@ -22,7 +22,11 @@ void main() {
 
     expect(color.toColor(), const Color(0xb399816b));
 
-    final HSVColor result = HSVColor.lerp(color, const HSVColor.fromAHSV(0.3, 128.0, 0.7, 0.2), 0.25)!;
+    final HSVColor result = HSVColor.lerp(
+      color,
+      const HSVColor.fromAHSV(0.3, 128.0, 0.7, 0.2),
+      0.25,
+    )!;
     expect(result.alpha, moreOrLessEquals(0.6));
     expect(result.hue, moreOrLessEquals(53.0));
     expect(result.saturation, greaterThan(0.3999));
@@ -224,7 +228,11 @@ void main() {
 
     expect(color.toColor(), const Color(0xb3b8977a));
 
-    final HSLColor result = HSLColor.lerp(color, const HSLColor.fromAHSL(0.3, 128.0, 0.7, 0.2), 0.25)!;
+    final HSLColor result = HSLColor.lerp(
+      color,
+      const HSLColor.fromAHSL(0.3, 128.0, 0.7, 0.2),
+      0.25,
+    )!;
     expect(result.alpha, moreOrLessEquals(0.6));
     expect(result.hue, moreOrLessEquals(53.0));
     expect(result.saturation, greaterThan(0.3999));
@@ -321,6 +329,44 @@ void main() {
     expect(output, equals(expectedColors));
   });
 
+  group('HSLColor.fromColor tests', () {
+    test('Pink', () {
+      const Color color = Color.fromARGB(255, 255, 51, 152);
+      final HSLColor hslColor = HSLColor.fromColor(color);
+      expect(hslColor.alpha, 1.0);
+      expect(hslColor.hue, within<double>(distance: .3, from: 330));
+      expect(hslColor.saturation, 1.0);
+      expect(hslColor.lightness, within<double>(distance: _doubleColorPrecision, from: 0.6));
+    });
+
+    test('White', () {
+      const Color color = Color(0xffffffff);
+      final HSLColor hslColor = HSLColor.fromColor(color);
+      expect(hslColor.alpha, 1.0);
+      expect(hslColor.hue, 0.0);
+      expect(hslColor.saturation, 0.0);
+      expect(hslColor.lightness, 1.0);
+    });
+
+    test('Black', () {
+      const Color color = Color(0xff000000);
+      final HSLColor hslColor = HSLColor.fromColor(color);
+      expect(hslColor.alpha, 1.0);
+      expect(hslColor.hue, 0.0);
+      expect(hslColor.saturation, 0.0);
+      expect(hslColor.lightness, 0.0);
+    });
+
+    test('Gray', () {
+      const Color color = Color(0xff808080);
+      final HSLColor hslColor = HSLColor.fromColor(color);
+      expect(hslColor.alpha, 1.0);
+      expect(hslColor.hue, 0.0);
+      expect(hslColor.saturation, 0.0);
+      expect(hslColor.lightness, within<double>(distance: _doubleColorPrecision, from: 0.5));
+    });
+  });
+
   test('HSLColor.lerp identical a,b', () {
     expect(HSLColor.lerp(null, null, 0), null);
     const HSLColor color = HSLColor.fromAHSL(1.0, 0.0, 0.5, 0.5);
@@ -412,54 +458,135 @@ void main() {
     expect(output, equals(expectedColors));
   });
 
+  // Tests the implementation against these colors from Wikipedia
+  // https://en.wikipedia.org/wiki/HSL_and_HSV#Examples
+  test('Wikipedia Examples Table test', () {
+    // ignore: always_specify_types
+    final colors = <(int, double, double, double, double, double, double, double, double, String)>[
+      // RGB,        r,   g,   b, hue,   v,   l,s(hsv),s(hsl)
+      (0xFFFFFFFF, 1.0, 1.0, 1.0, 0.0, 1.0, 1.0, 0.0, 0.0, 'white'),
+      (0xFF808080, 0.5, 0.5, 0.5, 0.0, 0.5, 0.5, 0.0, 0.0, 'gray'),
+      (0xFF000000, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 'black'),
+      (0xFFFF0000, 1.0, 0.0, 0.0, 0.0, 1.0, 0.5, 1.0, 1.0, 'red'),
+      (0xFFBFBF00, .75, .75, 0.0, 60, .75, .375, 1.0, 1.0, 'lime'),
+      (0xFF008000, 0.0, 0.5, 0.0, 120, 0.5, .25, 1.0, 1.0, 'green'),
+      (0xFF80FFFF, 0.5, 1.0, 1.0, 180, 1.0, 0.75, 0.5, 1, 'cyan'),
+      (0xFF8080FF, 0.5, 0.5, 1.0, 240, 1.0, 0.75, 0.5, 1, 'light purple'),
+      (0xFFBF40BF, 0.75, 0.25, 0.75, 300, .75, .5, 2.0 / 3, .5, 'mute magenta'),
+    ];
+
+    for (final (
+          int rgb,
+          double r,
+          double g,
+          double b,
+          double hue,
+          double v,
+          double l,
+          double sHSV,
+          double sHSL,
+          String name,
+        )
+        in colors) {
+      final Color color = Color.from(alpha: 1.0, red: r, green: g, blue: b);
+      final String debugColorConstructor = 'Color.from(alpha: 1.0, red: $r, green: $g, blue: $b)';
+      final Color intColor = Color(rgb);
+      expect(
+        intColor.r,
+        within<double>(distance: _doubleColorPrecision, from: r),
+        reason: '$name: Color($rgb).r should be $r',
+      );
+      expect(
+        intColor.g,
+        within<double>(distance: _doubleColorPrecision, from: g),
+        reason: '$name: Color($rgb).g should be $g',
+      );
+      expect(
+        intColor.b,
+        within<double>(distance: _doubleColorPrecision, from: b),
+        reason: '$name: Color($rgb).b should be $b',
+      );
+      final HSVColor hsv = HSVColor.fromAHSV(1.0, hue, sHSV, v);
+      final HSLColor hsl = HSLColor.fromAHSL(1.0, hue, sHSL, l);
+      expect(
+        color,
+        within<Color>(distance: _doubleColorPrecision, from: intColor),
+        reason: '$name: $debugColorConstructor should be close to Color($rgb)',
+      );
+      expect(
+        hsv.toColor(),
+        within<Color>(distance: _doubleColorPrecision, from: color),
+        reason:
+            '$name: HSVColor.fromAHSV(1.0, $hue, $sHSV, $v).hsv should be close to $debugColorConstructor',
+      );
+      expect(
+        hsl.toColor(),
+        within<Color>(distance: _doubleColorPrecision, from: color),
+        reason:
+            '$name: HSLColor.fromAHSL(1.0, $hue, $sHSL, $l).hsl should be close to $debugColorConstructor',
+      );
+      expect(
+        HSVColor.fromColor(color),
+        within<HSVColor>(distance: _doubleColorPrecision, from: hsv),
+        reason:
+            '$name: HSVColor.fromColor($debugColorConstructor) should be close to HSVColor.fromAHSV(1.0, $hue, $sHSV, $v)',
+      );
+      expect(
+        HSLColor.fromColor(color),
+        within<HSLColor>(distance: _doubleColorPrecision, from: hsl),
+        reason:
+            '$name: HSLColor.fromColor($debugColorConstructor) should be close to HSLColor.fromAHSL(1.0, $hue, $sHSL, $l)',
+      );
+    }
+  });
+
   test('ColorSwatch test', () {
     final int color = nonconst(0xFF027223);
-    final ColorSwatch<String> greens1 = ColorSwatch<String>(
-      color,
-      const <String, Color>{
-        '2259 C': Color(0xFF027223),
-        '2273 C': Color(0xFF257226),
-        '2426 XGC': Color(0xFF00932F),
-        '7732 XGC': Color(0xFF007940),
-      },
-    );
-    final ColorSwatch<String> greens2 = ColorSwatch<String>(
-      color,
-      const <String, Color>{
-        '2259 C': Color(0xFF027223),
-        '2273 C': Color(0xFF257226),
-        '2426 XGC': Color(0xFF00932F),
-        '7732 XGC': Color(0xFF007940),
-      },
-    );
+    final ColorSwatch<String> greens1 = ColorSwatch<String>(color, const <String, Color>{
+      '2259 C': Color(0xFF027223),
+      '2273 C': Color(0xFF257226),
+      '2426 XGC': Color(0xFF00932F),
+      '7732 XGC': Color(0xFF007940),
+    });
+    final ColorSwatch<String> greens2 = ColorSwatch<String>(color, const <String, Color>{
+      '2259 C': Color(0xFF027223),
+      '2273 C': Color(0xFF257226),
+      '2426 XGC': Color(0xFF00932F),
+      '7732 XGC': Color(0xFF007940),
+    });
     expect(greens1, greens2);
     expect(greens1.hashCode, greens2.hashCode);
     expect(greens1['2259 C'], const Color(0xFF027223));
     expect(greens1.value, 0xFF027223);
+    expect(listEquals(greens1.keys.toList(), greens2.keys.toList()), isTrue);
   });
 
   test('ColorSwatch.lerp', () {
-    const ColorSwatch<int> swatchA = ColorSwatch<int>(0x00000000, <int, Color>{1: Color(0x00000000)});
-    const ColorSwatch<int> swatchB = ColorSwatch<int>(0xFFFFFFFF, <int, Color>{1: Color(0xFFFFFFFF)});
+    const ColorSwatch<int> swatchA = ColorSwatch<int>(0x00000000, <int, Color>{
+      1: Color(0x00000000),
+    });
+    const ColorSwatch<int> swatchB = ColorSwatch<int>(0xFFFFFFFF, <int, Color>{
+      1: Color(0xFFFFFFFF),
+    });
     expect(
       ColorSwatch.lerp(swatchA, swatchB, 0.0),
-      const ColorSwatch<int>(0x00000000, <int, Color>{1: Color(0x00000000)}),
+      isSameColorAs(const ColorSwatch<int>(0x00000000, <int, Color>{1: Color(0x00000000)})),
     );
     expect(
       ColorSwatch.lerp(swatchA, swatchB, 0.5),
-      const ColorSwatch<int>(0x7F7F7F7F, <int, Color>{1: Color(0x7F7F7F7F)}),
+      isSameColorAs(const ColorSwatch<int>(0x7F7F7F7F, <int, Color>{1: Color(0x7F7F7F7F)})),
     );
     expect(
       ColorSwatch.lerp(swatchA, swatchB, 1.0),
-      const ColorSwatch<int>(0xFFFFFFFF, <int, Color>{1: Color(0xFFFFFFFF)}),
+      isSameColorAs(const ColorSwatch<int>(0xFFFFFFFF, <int, Color>{1: Color(0xFFFFFFFF)})),
     );
     expect(
       ColorSwatch.lerp(swatchA, swatchB, -0.1),
-      const ColorSwatch<int>(0x00000000, <int, Color>{1: Color(0x00000000)}),
+      isSameColorAs(const ColorSwatch<int>(0x00000000, <int, Color>{1: Color(0x00000000)})),
     );
     expect(
       ColorSwatch.lerp(swatchA, swatchB, 1.1),
-      const ColorSwatch<int>(0xFFFFFFFF, <int, Color>{1: Color(0xFFFFFFFF)}),
+      isSameColorAs(const ColorSwatch<int>(0xFFFFFFFF, <int, Color>{1: Color(0xFFFFFFFF)})),
     );
   });
 
@@ -471,7 +598,9 @@ void main() {
 
   test('ColorDiagnosticsProperty includes valueProperties in JSON', () {
     ColorProperty property = ColorProperty('foo', const Color.fromARGB(10, 20, 30, 40));
-    final Map<String, Object> valueProperties = property.toJsonMap(const DiagnosticsSerializationDelegate())['valueProperties']! as Map<String, Object>;
+    final Map<String, Object> valueProperties =
+        property.toJsonMap(const DiagnosticsSerializationDelegate())['valueProperties']!
+            as Map<String, Object>;
     expect(valueProperties['alpha'], 10);
     expect(valueProperties['red'], 20);
     expect(valueProperties['green'], 30);
