@@ -2,6 +2,9 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+/// @docImport 'flutter_application_package.dart';
+library;
+
 import 'base/context.dart';
 import 'base/file_system.dart';
 import 'build_info.dart';
@@ -18,8 +21,7 @@ abstract class ApplicationPackageFactory {
 }
 
 abstract class ApplicationPackage {
-  ApplicationPackage({ required this.id })
-    : assert(id != null);
+  ApplicationPackage({required this.id});
 
   /// Package ID from the Android Manifest or equivalent.
   final String id;
