@@ -6,6 +6,7 @@ import 'dart:math';
 
 import 'package:crypto/crypto.dart';
 import 'package:package_config/package_config.dart';
+import 'package:unified_analytics/unified_analytics.dart';
 
 import '../../artifacts.dart';
 import '../../base/file_system.dart';
@@ -46,18 +47,16 @@ class WebEntrypointTarget extends Target {
   ];
 
   @override
-  List<Source> get outputs => const <Source>[
-    Source.pattern('{BUILD_DIR}/main.dart'),
-  ];
+  List<Source> get outputs => const <Source>[Source.pattern('{BUILD_DIR}/main.dart')];
 
   @override
   Future<void> build(Environment environment) async {
     final String? targetFile = environment.defines[kTargetFile];
     final Uri importUri = environment.fileSystem.file(targetFile).absolute.uri;
-    // TODO(zanderso): support configuration of this file.
-    const String packageFile = '.packages';
+    final File packageConfigFile = findPackageConfigFileOrDefault(environment.projectDir);
+
     final PackageConfig packageConfig = await loadPackageConfigWithLogging(
-      environment.fileSystem.file(packageFile),
+      packageConfigFile,
       logger: environment.logger,
     );
     final FlutterProject flutterProject = FlutterProject.current();
@@ -76,15 +75,19 @@ class WebEntrypointTarget extends Target {
     // By construction, this will only be null if the .packages file does not
     // have an entry for the user's application or if the main file is
     // outside of the lib/ directory.
-    final String importedEntrypoint = packageConfig.toPackageUri(importUri)?.toString()
-      ?? importUri.toString();
+    final String importedEntrypoint =
+        packageConfig.toPackageUri(importUri)?.toString() ?? importUri.toString();
 
-    await injectBuildTimePluginFiles(flutterProject, webPlatform: true, destination: environment.buildDir);
+    await injectBuildTimePluginFilesForWebPlatform(
+      flutterProject,
+      destination: environment.buildDir,
+    );
     // The below works because `injectBuildTimePluginFiles` is configured to write
     // the web_plugin_registrant.dart file alongside the generated main.dart
-    const String generatedImport = 'web_plugin_registrant.dart';
+    const generatedImport = 'web_plugin_registrant.dart';
 
-    final String contents = main_dart.generateMainDartFile(importedEntrypoint,
+    final String contents = main_dart.generateMainDartFile(
+      importedEntrypoint,
       languageVersion: languageVersion,
       pluginRegistrantEntrypoint: generatedImport,
     );
@@ -96,8 +99,6 @@ class WebEntrypointTarget extends Target {
 abstract class Dart2WebTarget extends Target {
   const Dart2WebTarget();
 
-  Source get compilerSnapshot;
-
   WebCompilerConfig get compilerConfig;
 
   Map<String, Object?> get buildConfig;
@@ -109,9 +110,13 @@ abstract class Dart2WebTarget extends Target {
       decodeDartDefines(environment.defines, kDartDefines),
     );
     if (environment.defines[kUseLocalCanvasKitFlag] != 'true') {
-      final bool canvasKitUrlAlreadySet = dartDefines.any((String define) => define.startsWith('FLUTTER_WEB_CANVASKIT_URL='));
+      final bool canvasKitUrlAlreadySet = dartDefines.any(
+        (String define) => define.startsWith('FLUTTER_WEB_CANVASKIT_URL='),
+      );
       if (!canvasKitUrlAlreadySet) {
-        dartDefines.add('FLUTTER_WEB_CANVASKIT_URL=https://www.gstatic.com/flutter-canvaskit/${globals.flutterVersion.engineRevision}/');
+        dartDefines.add(
+          'FLUTTER_WEB_CANVASKIT_URL=https://www.gstatic.com/flutter-canvaskit/${globals.flutterVersion.engineRevision}/',
+        );
       }
     }
     return dartDefines;
@@ -126,10 +131,9 @@ abstract class Dart2WebTarget extends Target {
   @override
   List<Source> get inputs => <Source>[
     const Source.hostArtifact(HostArtifact.flutterWebSdk),
-    compilerSnapshot,
     const Source.artifact(Artifact.engineDartBinary),
     const Source.pattern('{BUILD_DIR}/main.dart'),
-    const Source.pattern('{PROJECT_DIR}/.dart_tool/package_config_subset'),
+    const Source.pattern('{WORKSPACE_DIR}/.dart_tool/package_config.json'),
   ];
 
   @override
@@ -152,12 +156,7 @@ class Dart2JSTarget extends Dart2WebTarget {
   String get name => 'dart2js';
 
   @override
-  Source get compilerSnapshot => const Source.artifact(Artifact.dart2jsSnapshot);
-
-  @override
-  List<String> get depfiles => const <String>[
-    'dart2js.d',
-  ];
+  List<String> get depfiles => const <String>['dart2js.d'];
 
   @override
   Future<void> build(Environment environment) async {
@@ -165,55 +164,54 @@ class Dart2JSTarget extends Dart2WebTarget {
     if (buildModeEnvironment == null) {
       throw MissingDefineException(kBuildMode, name);
     }
-    final BuildMode buildMode = BuildMode.fromCliName(buildModeEnvironment);
+    final buildMode = BuildMode.fromCliName(buildModeEnvironment);
     final Artifacts artifacts = environment.artifacts;
-    final String platformBinariesPath = artifacts.getHostArtifact(HostArtifact.webPlatformKernelFolder).path;
-    final List<String> sharedCommandOptions = <String>[
+    final String platformBinariesPath = artifacts
+        .getHostArtifact(HostArtifact.webPlatformKernelFolder)
+        .path;
+    final sharedCommandOptions = <String>[
       artifacts.getArtifactPath(Artifact.engineDartBinary, platform: TargetPlatform.web_javascript),
-      '--disable-dart-dev',
-      artifacts.getArtifactPath(Artifact.dart2jsSnapshot, platform: TargetPlatform.web_javascript),
+      'compile',
+      'js',
       '--platform-binaries=$platformBinariesPath',
       '--invoker=flutter_tool',
       ...decodeCommaSeparated(environment.defines, kExtraFrontEndOptions),
       if (buildMode == BuildMode.profile)
         '-Ddart.vm.profile=true'
-      else
+      else if (buildMode == BuildMode.release)
         '-Ddart.vm.product=true',
-      for (final String dartDefine in computeDartDefines(environment))
-        '-D$dartDefine',
+      for (final String dartDefine in computeDartDefines(environment)) '-D$dartDefine',
     ];
 
-    final List<String> compilationArgs = <String>[
+    // NOTE: most args should be populated in [toSharedCommandOptions].
+    final cfeCompilationArgs = <String>[
       ...sharedCommandOptions,
-      ...compilerConfig.toSharedCommandOptions(),
+      ...compilerConfig.toSharedCommandOptions(buildMode),
       '-o',
       environment.buildDir.childFile('app.dill').path,
-      '--packages=.dart_tool/package_config.json',
+      '--packages=${findPackageConfigFileOrDefault(environment.projectDir).path}',
       '--cfe-only',
       environment.buildDir.childFile('main.dart').path, // dartfile
     ];
 
-    final ProcessUtils processUtils = ProcessUtils(
+    final processUtils = ProcessUtils(
       logger: environment.logger,
       processManager: environment.processManager,
     );
 
     // Run the dart2js compilation in two stages, so that icon tree shaking can
     // parse the kernel file for web builds.
-    await processUtils.run(compilationArgs, throwOnError: true);
+    await processUtils.run(cfeCompilationArgs, throwOnError: true);
 
     final File outputJSFile = environment.buildDir.childFile('main.dart.js');
 
-    await processUtils.run(
-      throwOnError: true,
-      <String>[
-        ...sharedCommandOptions,
-        ...compilerConfig.toCommandOptions(buildMode),
-        '-o',
-        outputJSFile.path,
-        environment.buildDir.childFile('app.dill').path, // dartfile
-      ],
-    );
+    await processUtils.run(throwOnError: true, <String>[
+      ...sharedCommandOptions,
+      ...compilerConfig.toCommandOptions(buildMode),
+      '-o',
+      outputJSFile.path,
+      environment.buildDir.childFile('app.dill').path, // dartfile
+    ]);
     final File dart2jsDeps = environment.buildDir.childFile('app.dill.deps');
     if (!dart2jsDeps.existsSync()) {
       environment.logger.printWarning(
@@ -227,10 +225,7 @@ class Dart2JSTarget extends Dart2WebTarget {
       environment.buildDir.childFile('app.dill.deps'),
       outputJSFile,
     );
-    depFileService.writeToFile(
-      depFile,
-      environment.buildDir.childFile('dart2js.d'),
-    );
+    depFileService.writeToFile(depFile, environment.buildDir.childFile('dart2js.d'));
   }
 
   @override
@@ -241,28 +236,31 @@ class Dart2JSTarget extends Dart2WebTarget {
   };
 
   @override
-  Iterable<File> buildFiles(Environment environment)
-    => environment.buildDir
-      .listSync(recursive: true)
-      .whereType<File>()
-      .where((File file) {
+  Iterable<File> buildFiles(Environment environment) =>
+      environment.buildDir.listSync(recursive: true).whereType<File>().where((File file) {
         if (file.basename == 'main.dart.js') {
           return true;
         }
         if (file.basename == 'main.dart.js.map') {
           return compilerConfig.sourceMaps;
         }
-        final RegExp partFileRegex = RegExp(r'main\.dart\.js_[0-9].*\.part\.js');
+        final partFileRegex = RegExp(r'main\.dart\.js_[0-9].*\.part\.js');
         if (partFileRegex.hasMatch(file.basename)) {
           return true;
         }
 
         if (compilerConfig.sourceMaps) {
-          final RegExp partFileSourceMapRegex = RegExp(r'main\.dart\.js_[0-9].*.part\.js\.map');
+          final partFileSourceMapRegex = RegExp(r'main\.dart\.js_[0-9].*.part\.js\.map');
           if (partFileSourceMapRegex.hasMatch(file.basename)) {
             return true;
           }
         }
+
+        if (compilerConfig.dumpInfo) {
+          if (file.basename == 'main.dart.js.info.json') {
+            return true;
+          }
+        }
         return false;
       });
 
@@ -270,128 +268,207 @@ class Dart2JSTarget extends Dart2WebTarget {
   Iterable<String> get buildPatternStems => <String>[
     'main.dart.js',
     'main.dart.js_*.part.js',
-    if (compilerConfig.sourceMaps) ...<String>[
-      'main.dart.js.map',
-      'main.dart.js_*.part.js.map',
-    ],
+    if (compilerConfig.sourceMaps) ...<String>['main.dart.js.map', 'main.dart.js_*.part.js.map'],
   ];
 }
 
 /// Compiles a web entry point with dart2wasm.
 class Dart2WasmTarget extends Dart2WebTarget {
-  Dart2WasmTarget(this.compilerConfig);
+  Dart2WasmTarget(this.compilerConfig, this._analytics);
 
   @override
   final WasmCompilerConfig compilerConfig;
 
+  final Analytics _analytics;
+
+  /// List the preconfigured build options for a given build mode.
+  List<String> buildModeOptions(BuildMode mode, List<String> dartDefines) => switch (mode) {
+    BuildMode.debug => <String>[
+      // These checks allow the CLI to override the value of this define for unit
+      // testing the framework.
+      if (!dartDefines.any((String define) => define.startsWith('dart.vm.profile')))
+        '-Ddart.vm.profile=false',
+      if (!dartDefines.any((String define) => define.startsWith('dart.vm.product')))
+        '-Ddart.vm.product=false',
+    ],
+    BuildMode.profile => <String>[
+      // These checks allow the CLI to override the value of this define for
+      // benchmarks with most timeline traces disabled.
+      if (!dartDefines.any((String define) => define.startsWith('dart.vm.profile')))
+        '-Ddart.vm.profile=true',
+      if (!dartDefines.any((String define) => define.startsWith('dart.vm.product')))
+        '-Ddart.vm.product=false',
+      '--extra-compiler-option=--delete-tostring-package-uri=dart:ui',
+      '--extra-compiler-option=--delete-tostring-package-uri=package:flutter',
+    ],
+    BuildMode.release => <String>[
+      '-Ddart.vm.profile=false',
+      '-Ddart.vm.product=true',
+      '--extra-compiler-option=--delete-tostring-package-uri=dart:ui',
+      '--extra-compiler-option=--delete-tostring-package-uri=package:flutter',
+    ],
+    _ => throw Exception('Unknown BuildMode: $mode'),
+  };
+
   @override
   Future<void> build(Environment environment) async {
     final String? buildModeEnvironment = environment.defines[kBuildMode];
     if (buildModeEnvironment == null) {
       throw MissingDefineException(kBuildMode, name);
     }
-    final BuildMode buildMode = BuildMode.fromCliName(buildModeEnvironment);
+    final buildMode = BuildMode.fromCliName(buildModeEnvironment);
     final Artifacts artifacts = environment.artifacts;
-    final File outputWasmFile =
-        environment.buildDir.childFile('main.dart.wasm');
+    final File outputWasmFile = environment.buildDir.childFile('main.dart.wasm');
     final File depFile = environment.buildDir.childFile('dart2wasm.d');
-    final String platformBinariesPath = artifacts.getHostArtifact(HostArtifact.webPlatformKernelFolder).path;
-    final String platformFilePath = environment.fileSystem.path.join(platformBinariesPath, 'dart2wasm_platform.dill');
+    final String platformBinariesPath = artifacts
+        .getHostArtifact(HostArtifact.webPlatformKernelFolder)
+        .path;
+    final String platformFilePath = environment.fileSystem.path.join(
+      platformBinariesPath,
+      'dart2wasm_platform.dill',
+    );
+    final List<String> dartDefines = computeDartDefines(environment);
 
-    assert(buildMode == BuildMode.release || buildMode == BuildMode.profile);
-    final List<String> compilationArgs = <String>[
+    final compilationArgs = <String>[
       artifacts.getArtifactPath(Artifact.engineDartBinary, platform: TargetPlatform.web_javascript),
       'compile',
       'wasm',
-      '--packages=.dart_tool/package_config.json',
+      '--packages=${findPackageConfigFileOrDefault(environment.projectDir).path}',
       '--extra-compiler-option=--platform=$platformFilePath',
-      '--extra-compiler-option=--delete-tostring-package-uri=dart:ui',
-      '--extra-compiler-option=--delete-tostring-package-uri=package:flutter',
+      ...buildModeOptions(buildMode, dartDefines),
       if (compilerConfig.renderer == WebRendererMode.skwasm) ...<String>[
         '--extra-compiler-option=--import-shared-memory',
         '--extra-compiler-option=--shared-memory-max-pages=32768',
       ],
-      if (buildMode == BuildMode.profile)
-        '-Ddart.vm.profile=true'
-      else
-        '-Ddart.vm.product=true',
       ...decodeCommaSeparated(environment.defines, kExtraFrontEndOptions),
-      for (final String dartDefine in computeDartDefines(environment))
-        '-D$dartDefine',
+      for (final String dartDefine in dartDefines) '-D$dartDefine',
       '--extra-compiler-option=--depfile=${depFile.path}',
-
       ...compilerConfig.toCommandOptions(buildMode),
       '-o',
       outputWasmFile.path,
       environment.buildDir.childFile('main.dart').path, // dartfile
     ];
 
-    final ProcessUtils processUtils = ProcessUtils(
+    final processUtils = ProcessUtils(
       logger: environment.logger,
       processManager: environment.processManager,
     );
 
-    await processUtils.run(
-      throwOnError: true,
+    final RunResult runResult = await processUtils.run(
+      throwOnError: !compilerConfig.dryRun,
       compilationArgs,
     );
+    if (compilerConfig.dryRun) {
+      _handleDryRunResult(environment, runResult);
+    }
   }
 
-  @override
-  Source get compilerSnapshot => const Source.artifact(Artifact.dart2wasmSnapshot);
-
   @override
   String get name => 'dart2wasm';
 
   @override
-  List<String> get depfiles => const <String>[
-    'dart2wasm.d',
-  ];
+  List<String> get depfiles => const <String>['dart2wasm.d'];
 
   @override
-  Map<String, Object?> get buildConfig => <String, Object?>{
-    'compileTarget': 'dart2wasm',
-    'renderer': compilerConfig.renderer.name,
-    'mainWasmPath': 'main.dart.wasm',
-    'jsSupportRuntimePath': 'main.dart.mjs',
-  };
+  Map<String, Object?> get buildConfig => compilerConfig.dryRun
+      ? const <String, Object?>{}
+      : <String, Object?>{
+          'compileTarget': 'dart2wasm',
+          'renderer': compilerConfig.renderer.name,
+          'mainWasmPath': 'main.dart.wasm',
+          'jsSupportRuntimePath': 'main.dart.mjs',
+        };
 
   @override
-  Iterable<File> buildFiles(Environment environment)
-    => environment.buildDir
-      .listSync(recursive: true)
-      .whereType<File>()
-      .where((File file) => switch (file.basename) {
-        'main.dart.wasm' || 'main.dart.mjs' => true,
-        'main.dart.wasm.map' => compilerConfig.sourceMaps,
-        _ => false,
-      });
+  Iterable<File> buildFiles(Environment environment) => compilerConfig.dryRun
+      ? const <File>[]
+      : environment.buildDir
+            .listSync(recursive: true)
+            .whereType<File>()
+            .where(
+              (File file) => switch (file.basename) {
+                'main.dart.wasm' || 'main.dart.mjs' => true,
+                'main.dart.wasm.map' => compilerConfig.sourceMaps,
+                _ => false,
+              },
+            );
 
   @override
-  Iterable<String> get buildPatternStems => <String>[
-    'main.dart.wasm',
-    'main.dart.mjs',
-    if (compilerConfig.sourceMaps) 'main.dart.wasm.map',
-  ];
+  Iterable<String> get buildPatternStems => compilerConfig.dryRun
+      ? const <String>[]
+      : <String>[
+          'main.dart.wasm',
+          'main.dart.mjs',
+          if (compilerConfig.sourceMaps) 'main.dart.wasm.map',
+        ];
+
+  void _handleDryRunResult(Environment environment, RunResult runResult) {
+    final int exitCode = runResult.exitCode;
+    final String stdout = runResult.stdout;
+    final String stderr = runResult.stderr;
+    final String result;
+    String? findingsSummary;
+
+    if (exitCode != 0 && exitCode != 254) {
+      environment.logger.printWarning('Unexpected wasm dry run failure ($exitCode):');
+      if (stderr.isNotEmpty) {
+        environment.logger.printWarning(stdout);
+        environment.logger.printWarning(stderr);
+      }
+      result = 'crash';
+    } else if (exitCode == 0) {
+      environment.logger.printWarning(
+        'Wasm dry run succeeded. Consider building and testing your application with the '
+        '`--wasm` flag. See docs for more info: '
+        'https://docs.flutter.dev/platform-integration/web/wasm',
+      );
+      result = 'success';
+    } else if (stderr.isNotEmpty) {
+      environment.logger.printWarning('Wasm dry run failed:');
+      environment.logger.printWarning(stdout);
+      environment.logger.printWarning(stderr);
+      result = 'failure';
+    } else if (stdout.isNotEmpty) {
+      environment.logger.printWarning('Wasm dry run findings:');
+      environment.logger.printWarning(stdout);
+      environment.logger.printWarning(
+        'Consider addressing these issues to enable wasm builds. See docs for more info: '
+        'https://docs.flutter.dev/platform-integration/web/wasm\n',
+      );
+      result = 'findings';
+      findingsSummary = RegExp(
+        r'\(([0-9]+)\)',
+      ).allMatches(stdout).map((RegExpMatch f) => f.group(1)).join(',');
+    } else {
+      result = 'unknown';
+    }
+    environment.logger.printWarning('Use --no-wasm-dry-run to disable these warnings.');
+
+    _analytics.send(
+      Event.flutterWasmDryRun(result: result, exitCode: exitCode, findingsSummary: findingsSummary),
+    );
+  }
 }
 
 /// Unpacks the dart2js or dart2wasm compilation and resources to a given
 /// output directory.
 class WebReleaseBundle extends Target {
-  WebReleaseBundle(List<WebCompilerConfig> configs) : this._(
-    compileTargets: configs.map((WebCompilerConfig config) =>
-      switch (config) {
-        WasmCompilerConfig() => Dart2WasmTarget(config),
-        JsCompilerConfig() => Dart2JSTarget(config),
-      }
-    ).toList(),
-  );
+  WebReleaseBundle(List<WebCompilerConfig> configs, Analytics analytics)
+    : this._(
+        compileTargets: configs
+            .map(
+              (WebCompilerConfig config) => switch (config) {
+                WasmCompilerConfig() => Dart2WasmTarget(config, analytics),
+                JsCompilerConfig() => Dart2JSTarget(config),
+              },
+            )
+            .toList(),
+      );
 
-  WebReleaseBundle._({
-    required this.compileTargets,
-  }) : templatedFilesTarget = WebTemplatedFiles(
-    compileTargets.map((Dart2WebTarget target) => target.buildConfig).toList()
-  );
+  WebReleaseBundle._({required this.compileTargets})
+    : templatedFilesTarget = WebTemplatedFiles(
+        compileTargets.map((Dart2WebTarget target) => target.buildConfig).toList(),
+      );
 
   final List<Dart2WebTarget> compileTargets;
   final WebTemplatedFiles templatedFilesTarget;
@@ -400,31 +477,24 @@ class WebReleaseBundle extends Target {
   String get name => 'web_release_bundle';
 
   @override
-  List<Target> get dependencies => <Target>[
-    ...compileTargets,
-    templatedFilesTarget,
-  ];
+  List<Target> get dependencies => <Target>[...compileTargets, templatedFilesTarget];
 
-  Iterable<String> get buildPatternStems => compileTargets.expand(
-    (Dart2WebTarget target) => target.buildPatternStems,
-  );
+  Iterable<String> get buildPatternStems =>
+      compileTargets.expand((Dart2WebTarget target) => target.buildPatternStems);
 
   @override
   List<Source> get inputs => <Source>[
     const Source.pattern('{PROJECT_DIR}/pubspec.yaml'),
-    ...buildPatternStems.map((String file) => Source.pattern('{BUILD_DIR}/$file'))
+    ...buildPatternStems.map((String file) => Source.pattern('{BUILD_DIR}/$file')),
   ];
 
   @override
   List<Source> get outputs => <Source>[
-    ...buildPatternStems.map((String file) => Source.pattern('{OUTPUT_DIR}/$file'))
+    ...buildPatternStems.map((String file) => Source.pattern('{OUTPUT_DIR}/$file')),
   ];
 
   @override
-  List<String> get depfiles => const <String>[
-    'flutter_assets.d',
-    'web_resources.d',
-  ];
+  List<String> get depfiles => const <String>['flutter_assets.d', 'web_resources.d'];
 
   @override
   Future<void> build(Environment environment) async {
@@ -432,7 +502,7 @@ class WebReleaseBundle extends Target {
     for (final Dart2WebTarget target in compileTargets) {
       for (final File outputFile in target.buildFiles(environment)) {
         outputFile.copySync(
-          environment.outputDir.childFile(fileSystem.path.basename(outputFile.path)).path
+          environment.outputDir.childFile(fileSystem.path.basename(outputFile.path)).path,
         );
       }
     }
@@ -441,7 +511,7 @@ class WebReleaseBundle extends Target {
     if (buildModeEnvironment == null) {
       throw MissingDefineException(kBuildMode, name);
     }
-    final BuildMode buildMode = BuildMode.fromCliName(buildModeEnvironment);
+    final buildMode = BuildMode.fromCliName(buildModeEnvironment);
 
     createVersionFile(environment, environment.defines);
     final Directory outputDirectory = environment.outputDir.childDirectory('assets');
@@ -454,47 +524,39 @@ class WebReleaseBundle extends Target {
       buildMode: buildMode,
     );
     final DepfileService depfileService = environment.depFileService;
-    depfileService.writeToFile(
-      depfile,
-      environment.buildDir.childFile('flutter_assets.d'),
-    );
+    depfileService.writeToFile(depfile, environment.buildDir.childFile('flutter_assets.d'));
 
-    final Directory webResources = environment.projectDir
-      .childDirectory('web');
+    final Directory webResources = environment.projectDir.childDirectory('web');
     final List<File> inputResourceFiles = webResources
-      .listSync(recursive: true)
-      .whereType<File>()
-      .toList();
+        .listSync(recursive: true)
+        .whereType<File>()
+        .toList();
 
     // Copy other resource files out of web/ directory.
-    final List<File> outputResourcesFiles = <File>[];
-    for (final File inputFile in inputResourceFiles) {
+    final outputResourcesFiles = <File>[];
+    for (final inputFile in inputResourceFiles) {
       final String relativePath = fileSystem.path.relative(inputFile.path, from: webResources.path);
       if (relativePath == 'index.html' || relativePath == 'flutter_bootstrap.js') {
         // Skip these, these are handled by the templated file target.
         continue;
       }
-      final File outputFile = fileSystem.file(fileSystem.path.join(
-        environment.outputDir.path,
-        relativePath));
+      final File outputFile = fileSystem.file(
+        fileSystem.path.join(environment.outputDir.path, relativePath),
+      );
       if (!outputFile.parent.existsSync()) {
         outputFile.parent.createSync(recursive: true);
       }
       outputResourcesFiles.add(outputFile);
       inputFile.copySync(outputFile.path);
     }
-    final Depfile resourceFile = Depfile(inputResourceFiles, outputResourcesFiles);
-    depfileService.writeToFile(
-      resourceFile,
-      environment.buildDir.childFile('web_resources.d'),
-    );
+    final resourceFile = Depfile(inputResourceFiles, outputResourcesFiles);
+    depfileService.writeToFile(resourceFile, environment.buildDir.childFile('web_resources.d'));
   }
 
   /// Create version.json file that contains data about version for package_info
   void createVersionFile(Environment environment, Map<String, String> defines) {
-    final Map<String, dynamic> versionInfo =
-        jsonDecode(FlutterProject.current().getVersionInfo())
-            as Map<String, dynamic>;
+    final versionInfo =
+        jsonDecode(FlutterProject.current().getVersionInfo()) as Map<String, dynamic>;
 
     if (defines.containsKey(kBuildNumber)) {
       versionInfo['build_number'] = defines[kBuildNumber];
@@ -504,9 +566,7 @@ class WebReleaseBundle extends Target {
       versionInfo['version'] = defines[kBuildName];
     }
 
-    environment.outputDir
-        .childFile('version.json')
-        .writeAsStringSync(jsonEncode(versionInfo));
+    environment.outputDir.childFile('version.json').writeAsStringSync(jsonEncode(versionInfo));
   }
 }
 
@@ -521,19 +581,18 @@ class WebTemplatedFiles extends Target {
   void _emitWebTemplateWarning(
     Environment environment,
     String filePath,
-    WebTemplateWarning warning
+    WebTemplateWarning warning,
   ) {
     environment.logger.printWarning(
-      'Warning: In $filePath:${warning.lineNumber}: ${warning.warningText}'
+      'Warning: In $filePath:${warning.lineNumber}: ${warning.warningText}',
     );
   }
 
   String buildConfigString(Environment environment) {
-    final Map<String, Object> buildConfig = <String, Object>{
+    final buildConfig = <String, Object>{
       'engineRevision': globals.flutterVersion.engineRevision,
       'builds': buildDescriptions,
-      if (environment.defines[kUseLocalCanvasKitFlag] == 'true')
-        'useLocalCanvasKit': true,
+      if (environment.defines[kUseLocalCanvasKitFlag] == 'true') 'useLocalCanvasKit': true,
     };
     return '''
 if (!window._flutter) {
@@ -545,72 +604,76 @@ _flutter.buildConfig = ${jsonEncode(buildConfig)};
 
   @override
   Future<void> build(Environment environment) async {
-    final Directory webResources = environment.projectDir
-      .childDirectory('web');
+    final Directory webResources = environment.projectDir.childDirectory('web');
+    final includeServiceWorkerSettings =
+        environment.serviceWorkerStrategy == ServiceWorkerStrategy.offlineFirst;
     final File inputFlutterBootstrapJs = webResources.childFile('flutter_bootstrap.js');
     final String inputBootstrapContent;
     if (await inputFlutterBootstrapJs.exists()) {
       inputBootstrapContent = await inputFlutterBootstrapJs.readAsString();
     } else {
-      inputBootstrapContent = generateDefaultFlutterBootstrapScript();
+      inputBootstrapContent = generateDefaultFlutterBootstrapScript(
+        includeServiceWorkerSettings: includeServiceWorkerSettings,
+      );
     }
-    final WebTemplate bootstrapTemplate = WebTemplate(inputBootstrapContent);
+    final bootstrapTemplate = WebTemplate(inputBootstrapContent);
     for (final WebTemplateWarning warning in bootstrapTemplate.getWarnings()) {
       _emitWebTemplateWarning(environment, 'flutter_bootstrap.js', warning);
     }
 
     final FileSystem fileSystem = environment.fileSystem;
-    final File flutterJsFile = fileSystem.file(fileSystem.path.join(
-      globals.artifacts!.getHostArtifact(HostArtifact.flutterJsDirectory).path,
-      'flutter.js',
-    ));
+    final File flutterJsFile = fileSystem.file(
+      fileSystem.path.join(
+        globals.artifacts!.getHostArtifact(HostArtifact.flutterJsDirectory).path,
+        'flutter.js',
+      ),
+    );
 
     final String buildConfig = buildConfigString(environment);
 
     // Insert a random hash into the requests for service_worker.js. This is not a content hash,
     // because it would need to be the hash for the entire bundle and not just the resource
     // in question.
-    final String serviceWorkerVersion = Random().nextInt(4294967296).toString();
-    bootstrapTemplate.applySubstitutions(
+    final String? serviceWorkerVersion = includeServiceWorkerSettings
+        ? Random().nextInt(1 << 32).toString()
+        : null;
+    final String bootstrapContent = bootstrapTemplate.withSubstitutions(
       baseHref: '',
       serviceWorkerVersion: serviceWorkerVersion,
       flutterJsFile: flutterJsFile,
       buildConfig: buildConfig,
     );
 
-    final File outputFlutterBootstrapJs = fileSystem.file(fileSystem.path.join(
-        environment.outputDir.path,
-        'flutter_bootstrap.js'
-    ));
-    await outputFlutterBootstrapJs.writeAsString(bootstrapTemplate.content);
+    final File outputFlutterBootstrapJs = fileSystem.file(
+      fileSystem.path.join(environment.outputDir.path, 'flutter_bootstrap.js'),
+    );
+    await outputFlutterBootstrapJs.writeAsString(bootstrapContent);
 
     await for (final FileSystemEntity file in webResources.list(recursive: true)) {
       if (file is File && file.basename == 'index.html') {
-        final WebTemplate indexHtmlTemplate = WebTemplate(file.readAsStringSync());
+        final indexHtmlTemplate = WebTemplate(file.readAsStringSync());
         final String relativePath = fileSystem.path.relative(file.path, from: webResources.path);
 
         for (final WebTemplateWarning warning in indexHtmlTemplate.getWarnings()) {
           _emitWebTemplateWarning(environment, relativePath, warning);
         }
 
-        indexHtmlTemplate.applySubstitutions(
+        final String indexHtmlContent = indexHtmlTemplate.withSubstitutions(
           baseHref: environment.defines[kBaseHref] ?? '/',
           serviceWorkerVersion: serviceWorkerVersion,
           flutterJsFile: flutterJsFile,
           buildConfig: buildConfig,
-          flutterBootstrapJs: bootstrapTemplate.content,
+          flutterBootstrapJs: bootstrapContent,
+        );
+        final File outputIndexHtml = fileSystem.file(
+          fileSystem.path.join(environment.outputDir.path, relativePath),
         );
-        final File outputIndexHtml = fileSystem.file(fileSystem.path.join(
-          environment.outputDir.path,
-          relativePath,
-        ));
         await outputIndexHtml.create(recursive: true);
-        await outputIndexHtml.writeAsString(indexHtmlTemplate.content);
+        await outputIndexHtml.writeAsString(indexHtmlContent);
       }
     }
   }
 
-
   @override
   List<Target> get dependencies => <Target>[];
 
@@ -651,22 +714,20 @@ class WebBuiltInAssets extends Target {
   List<String> get depfiles => const <String>[];
 
   @override
-  List<Source> get inputs => const <Source>[
-    Source.hostArtifact(HostArtifact.flutterWebSdk),
-  ];
+  List<Source> get inputs => const <Source>[Source.hostArtifact(HostArtifact.flutterWebSdk)];
 
-  Directory get _canvasKitDirectory =>
-    globals.fs.directory(
-      fileSystem.path.join(
-        globals.artifacts!.getHostArtifact(HostArtifact.flutterWebSdk).path,
-        'canvaskit',
-      )
-    );
+  Directory get _canvasKitDirectory => globals.fs.directory(
+    fileSystem.path.join(
+      globals.artifacts!.getHostArtifact(HostArtifact.flutterWebSdk).path,
+      'canvaskit',
+    ),
+  );
 
-  List<File> get _canvasKitFiles => _canvasKitDirectory.listSync(recursive: true).whereType<File>().toList();
+  List<File> get _canvasKitFiles =>
+      _canvasKitDirectory.listSync(recursive: true).whereType<File>().toList();
 
   String _filePathRelativeToCanvasKitDirectory(File file) =>
-    fileSystem.path.relative(file.path, from: _canvasKitDirectory.path);
+      fileSystem.path.relative(file.path, from: _canvasKitDirectory.path);
 
   @override
   List<Source> get outputs => <Source>[
@@ -679,40 +740,45 @@ class WebBuiltInAssets extends Target {
   Future<void> build(Environment environment) async {
     for (final File file in _canvasKitFiles) {
       final String relativePath = _filePathRelativeToCanvasKitDirectory(file);
-      final String targetPath = fileSystem.path.join(environment.outputDir.path, 'canvaskit', relativePath);
+      final String targetPath = fileSystem.path.join(
+        environment.outputDir.path,
+        'canvaskit',
+        relativePath,
+      );
       file.copySync(targetPath);
     }
 
     // Write the flutter.js file
     final String flutterJsOut = fileSystem.path.join(environment.outputDir.path, 'flutter.js');
-    final File flutterJsFile = fileSystem.file(fileSystem.path.join(
-      globals.artifacts!.getHostArtifact(HostArtifact.flutterJsDirectory).path,
-      'flutter.js',
-    ));
+    final File flutterJsFile = fileSystem.file(
+      fileSystem.path.join(
+        globals.artifacts!.getHostArtifact(HostArtifact.flutterJsDirectory).path,
+        'flutter.js',
+      ),
+    );
     flutterJsFile.copySync(flutterJsOut);
   }
 }
 
 /// Generate a service worker for a web target.
 class WebServiceWorker extends Target {
-  const WebServiceWorker(this.fileSystem, this.compileConfigs);
+  const WebServiceWorker(this.fileSystem, this.compileConfigs, this.analytics);
 
   final FileSystem fileSystem;
   final List<WebCompilerConfig> compileConfigs;
+  final Analytics analytics;
 
   @override
   String get name => 'web_service_worker';
 
   @override
   List<Target> get dependencies => <Target>[
-    WebReleaseBundle(compileConfigs),
+    WebReleaseBundle(compileConfigs, analytics),
     WebBuiltInAssets(fileSystem),
   ];
 
   @override
-  List<String> get depfiles => const <String>[
-    'service_worker.d',
-  ];
+  List<String> get depfiles => const <String>['service_worker.d'];
 
   @override
   List<Source> get inputs => const <Source>[];
@@ -723,25 +789,25 @@ class WebServiceWorker extends Target {
   @override
   Future<void> build(Environment environment) async {
     final List<File> contents = environment.outputDir
-      .listSync(recursive: true)
-      .whereType<File>()
-      .where((File file) => !file.path.endsWith('flutter_service_worker.js')
-        && !environment.fileSystem.path.basename(file.path).startsWith('.'))
-      .toList();
+        .listSync(recursive: true)
+        .whereType<File>()
+        .where(
+          (File file) =>
+              !file.path.endsWith('flutter_service_worker.js') &&
+              !environment.fileSystem.path.basename(file.path).startsWith('.'),
+        )
+        .toList();
 
-    final Map<String, String> urlToHash = <String, String>{};
-    for (final File file in contents) {
+    final urlToHash = <String, String>{};
+    for (final file in contents) {
       // Do not force caching of source maps.
-      if (file.path.endsWith('main.dart.js.map') ||
-        file.path.endsWith('.part.js.map')) {
+      if (file.path.endsWith('main.dart.js.map') || file.path.endsWith('.part.js.map')) {
         continue;
       }
-      final String url = environment.fileSystem.path.toUri(
-        environment.fileSystem.path.relative(
-          file.path,
-          from: environment.outputDir.path),
-        ).toString();
-      final String hash = md5.convert(await file.readAsBytes()).toString();
+      final url = environment.fileSystem.path
+          .toUri(environment.fileSystem.path.relative(file.path, from: environment.outputDir.path))
+          .toString();
+      final hash = md5.convert(await file.readAsBytes()).toString();
       urlToHash[url] = hash;
       // Add an additional entry for the base URL.
       if (url == 'index.html') {
@@ -749,36 +815,30 @@ class WebServiceWorker extends Target {
       }
     }
 
-    final File serviceWorkerFile = environment.outputDir
-      .childFile('flutter_service_worker.js');
-    final Depfile depfile = Depfile(contents, <File>[serviceWorkerFile]);
-    final ServiceWorkerStrategy serviceWorkerStrategy =
-        ServiceWorkerStrategy.fromCliName(environment.defines[kServiceWorkerStrategy]);
-    final String fileGeneratorsPath =
-        environment.artifacts.getArtifactPath(Artifact.flutterToolsFileGenerators);
-    final String serviceWorker = generateServiceWorker(
-      fileGeneratorsPath,
-      urlToHash,
-      <String>[
-        'main.dart.js',
-        if (compileConfigs.any((WebCompilerConfig config) => config is WasmCompilerConfig)) ...<String>[
-          'main.dart.wasm',
-          'main.dart.mjs',
-        ],
-        'index.html',
-        'flutter_bootstrap.js',
-        if (urlToHash.containsKey('assets/AssetManifest.bin.json'))
-          'assets/AssetManifest.bin.json',
-        if (urlToHash.containsKey('assets/FontManifest.json'))
-          'assets/FontManifest.json',
-      ],
-      serviceWorkerStrategy: serviceWorkerStrategy,
+    final File serviceWorkerFile = environment.outputDir.childFile('flutter_service_worker.js');
+    final depfile = Depfile(contents, <File>[serviceWorkerFile]);
+    final String fileGeneratorsPath = environment.artifacts.getArtifactPath(
+      Artifact.flutterToolsFileGenerators,
     );
-    serviceWorkerFile
-      .writeAsStringSync(serviceWorker);
+    final String serviceWorker = generateServiceWorker(fileGeneratorsPath, urlToHash, <String>[
+      'main.dart.js',
+      if (compileConfigs.any(
+        (WebCompilerConfig config) => config is WasmCompilerConfig && !config.dryRun,
+      )) ...<String>['main.dart.wasm', 'main.dart.mjs'],
+      'index.html',
+      'flutter_bootstrap.js',
+      if (urlToHash.containsKey('assets/AssetManifest.bin.json')) 'assets/AssetManifest.bin.json',
+      if (urlToHash.containsKey('assets/FontManifest.json')) 'assets/FontManifest.json',
+    ], serviceWorkerStrategy: environment.serviceWorkerStrategy);
+    serviceWorkerFile.writeAsStringSync(serviceWorker);
     environment.depFileService.writeToFile(
       depfile,
       environment.buildDir.childFile('service_worker.d'),
     );
   }
 }
+
+extension on Environment {
+  ServiceWorkerStrategy get serviceWorkerStrategy =>
+      ServiceWorkerStrategy.fromCliName(defines[kServiceWorkerStrategy]);
+}
