@@ -22,26 +22,18 @@ import '../../src/common.dart';
 import '../../src/context.dart';
 import '../../src/test_flutter_command_runner.dart';
 
-const String _kFlutterRoot = '/data/flutter';
-const int SIGABRT = -6;
+const _kFlutterRoot = '/data/flutter';
+const SIGABRT = -6;
 
 void main() {
   testWithoutContext('analyze generate correct errors message', () async {
     expect(
-      AnalyzeBase.generateErrorsMessage(
-        issueCount: 0,
-        seconds: '0.1',
-      ),
+      AnalyzeBase.generateErrorsMessage(issueCount: 0, seconds: '0.1'),
       'No issues found! (ran in 0.1s)',
     );
 
     expect(
-      AnalyzeBase.generateErrorsMessage(
-        issueCount: 3,
-        issueDiff: 2,
-        files: 1,
-        seconds: '0.1',
-      ),
+      AnalyzeBase.generateErrorsMessage(issueCount: 3, issueDiff: 2, files: 1, seconds: '0.1'),
       '3 issues found. (2 new) • analyzed 1 file (ran in 0.1s)',
     );
   });
@@ -78,22 +70,22 @@ void main() {
       runner = createTestCommandRunner(command);
 
       // Setup repo roots
-      const String homePath = '/home/user/flutter';
+      const homePath = '/home/user/flutter';
       Cache.flutterRoot = homePath;
-      for (final String dir in <String>['dev', 'examples', 'packages']) {
+      for (final dir in <String>['dev', 'examples', 'packages']) {
         fileSystem.directory(homePath).childDirectory(dir).createSync(recursive: true);
       }
     });
 
-    testUsingContext('SIGABRT throws Exception', () async {
-      const String stderr = 'Something bad happened!';
-      processManager.addCommands(
-        <FakeCommand>[
+    testUsingContext(
+      'SIGABRT throws Exception',
+      () async {
+        const stderr = 'Something bad happened!';
+        processManager.addCommands(<FakeCommand>[
           const FakeCommand(
             // artifact paths are from Artifacts.test() and stable
             command: <String>[
               'Artifact.engineDartSdkPath/bin/dart',
-              '--disable-dart-dev',
               'Artifact.engineDartSdkPath/bin/snapshots/analysis_server.dart.snapshot',
               '--disable-server-feature-completion',
               '--disable-server-feature-search',
@@ -104,34 +96,34 @@ void main() {
             exitCode: SIGABRT,
             stderr: stderr,
           ),
-        ],
-      );
-      await expectLater(
-        runner.run(<String>['analyze']),
-        throwsA(
-          isA<Exception>().having(
-            (Exception e) => e.toString(),
-            'description',
-            contains('analysis server exited with code $SIGABRT and output:\n[stderr] $stderr'),
+        ]);
+        await expectLater(
+          runner.run(<String>['analyze']),
+          throwsA(
+            isA<Exception>().having(
+              (Exception e) => e.toString(),
+              'description',
+              contains('analysis server exited with code $SIGABRT and output:\n[stderr] $stderr'),
+            ),
           ),
-        ),
-      );
-    },
-    overrides: <Type, Generator>{
-      FileSystem: () => fileSystem,
-      ProcessManager: () => processManager,
-    });
+        );
+      },
+      overrides: <Type, Generator>{
+        FileSystem: () => fileSystem,
+        ProcessManager: () => processManager,
+      },
+    );
 
-    testUsingContext('--flutter-repo analyzes everything in the flutterRoot', () async {
-      final StreamController<List<int>> streamController = StreamController<List<int>>();
-      final IOSink sink = IOSink(streamController.sink);
-      processManager.addCommands(
-        <FakeCommand>[
+    testUsingContext(
+      '--flutter-repo analyzes everything in the flutterRoot',
+      () async {
+        final streamController = StreamController<List<int>>();
+        final sink = IOSink(streamController.sink);
+        processManager.addCommands(<FakeCommand>[
           FakeCommand(
             // artifact paths are from Artifacts.test() and stable
             command: const <String>[
               'Artifact.engineDartSdkPath/bin/dart',
-              '--disable-dart-dev',
               'Artifact.engineDartSdkPath/bin/snapshots/analysis_server.dart.snapshot',
               '--disable-server-feature-completion',
               '--disable-server-feature-search',
@@ -142,26 +134,34 @@ void main() {
             stdin: sink,
             stdout: '{"event":"server.status","params":{"analysis":{"isAnalyzing":false}}}',
           ),
-        ],
-      );
-      await runner.run(<String>['analyze', '--flutter-repo']);
-      final Map<String, Object?> setAnalysisRootsCommand = jsonDecode(await streamController.stream.transform(utf8.decoder).elementAt(2)) as Map<String, Object?>;
-      expect(setAnalysisRootsCommand['method'], 'analysis.setAnalysisRoots');
-      final Map<String, Object?> params = setAnalysisRootsCommand['params']! as Map<String, Object?>;
-      expect(params['included'], <String?>[Cache.flutterRoot]);
-      expect(params['excluded'], isEmpty);
-    },
-    overrides: <Type, Generator>{
-      FileSystem: () => fileSystem,
-      ProcessManager: () => processManager,
-    });
+        ]);
+        await runner.run(<String>['analyze', '--flutter-repo']);
+        final setAnalysisRootsCommand =
+            jsonDecode(
+                  await streamController.stream
+                      .transform(utf8.decoder)
+                      .transform(const LineSplitter())
+                      .elementAt(1),
+                )
+                as Map<String, Object?>;
+        expect(setAnalysisRootsCommand['method'], 'analysis.setAnalysisRoots');
+        final params = setAnalysisRootsCommand['params']! as Map<String, Object?>;
+        expect(params['included'], <String?>[Cache.flutterRoot]);
+        expect(params['excluded'], isEmpty);
+      },
+      overrides: <Type, Generator>{
+        FileSystem: () => fileSystem,
+        ProcessManager: () => processManager,
+      },
+    );
   });
 
   testWithoutContext('analyze inRepo', () {
     final FileSystem fileSystem = MemoryFileSystem.test();
     fileSystem.directory(_kFlutterRoot).createSync(recursive: true);
-    final Directory tempDir = fileSystem.systemTempDirectory
-      .createTempSync('flutter_analysis_test.');
+    final Directory tempDir = fileSystem.systemTempDirectory.createTempSync(
+      'flutter_analysis_test.',
+    );
     Cache.flutterRoot = _kFlutterRoot;
 
     // Absolute paths
@@ -184,7 +184,7 @@ void main() {
   });
 
   testWithoutContext('AnalysisError from json write correct', () {
-    final Map<String, dynamic> json = <String, dynamic>{
+    final json = <String, dynamic>{
       'severity': 'INFO',
       'type': 'TODO',
       'location': <String, dynamic>{
@@ -198,8 +198,10 @@ void main() {
       'code': 'var foo = 123;',
       'hasFix': false,
     };
-    expect(WrittenError.fromJson(json).toString(),
-        '[info] Prefer final for variable declarations if they are not reassigned (/Users/.../lib/test.dart:15:4)');
+    expect(
+      WrittenError.fromJson(json).toString(),
+      '[info] Prefer final for variable declarations if they are not reassigned (/Users/.../lib/test.dart:15:4)',
+    );
   });
 }
 
