@@ -56,7 +56,7 @@ void main() {
 
     testWithoutContext('Install and uninstall are no-ops that report success', () async {
       final FakeDesktopDevice device = setUpDesktopDevice();
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
 
       expect(await device.uninstallApp(package), true);
       expect(await device.isAppInstalled(package), true);
@@ -72,15 +72,15 @@ void main() {
   group('Starting and stopping application', () {
     testWithoutContext('Stop without start is a successful no-op', () async {
       final FakeDesktopDevice device = setUpDesktopDevice();
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
 
       expect(await device.stopApp(package), true);
     });
 
     testWithoutContext('Can run from prebuilt application', () async {
       final FileSystem fileSystem = MemoryFileSystem.test();
-      final Completer<void> completer = Completer<void>();
-      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+      final completer = Completer<void>();
+      final processManager = FakeProcessManager.list(<FakeCommand>[
         FakeCommand(
           command: const <String>['debug'],
           stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
@@ -96,7 +96,7 @@ void main() {
         BuildInfo.debug,
       );
       fileSystem.file(executableName).writeAsStringSync('\n');
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
       final LaunchResult result = await device.startApp(
         package,
         prebuiltApplication: true,
@@ -108,12 +108,12 @@ void main() {
     });
 
     testWithoutContext('Null executable path fails gracefully', () async {
-      final BufferLogger logger = BufferLogger.test();
+      final logger = BufferLogger.test();
       final DesktopDevice device = setUpDesktopDevice(
         nullExecutablePathForDevice: true,
         logger: logger,
       );
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
       final LaunchResult result = await device.startApp(
         package,
         prebuiltApplication: true,
@@ -125,8 +125,8 @@ void main() {
     });
 
     testWithoutContext('stopApp kills process started by startApp', () async {
-      final Completer<void> completer = Completer<void>();
-      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+      final completer = Completer<void>();
+      final processManager = FakeProcessManager.list(<FakeCommand>[
         FakeCommand(
           command: const <String>['debug'],
           stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
@@ -134,7 +134,7 @@ void main() {
         ),
       ]);
       final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
       final LaunchResult result = await device.startApp(
         package,
         prebuiltApplication: true,
@@ -149,8 +149,8 @@ void main() {
   testWithoutContext(
     'startApp supports DebuggingOptions through FLUTTER_ENGINE_SWITCH environment variables',
     () async {
-      final Completer<void> completer = Completer<void>();
-      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+      final completer = Completer<void>();
+      final processManager = FakeProcessManager.list(<FakeCommand>[
         FakeCommand(
           command: const <String>['debug'],
           stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
@@ -166,23 +166,21 @@ void main() {
             'FLUTTER_ENGINE_SWITCH_8': 'trace-systrace=true',
             'FLUTTER_ENGINE_SWITCH_9': 'trace-to-file=path/to/trace.binpb',
             'FLUTTER_ENGINE_SWITCH_10': 'endless-trace-buffer=true',
-            'FLUTTER_ENGINE_SWITCH_11': 'dump-skp-on-shader-compilation=true',
-            'FLUTTER_ENGINE_SWITCH_12': 'cache-sksl=true',
-            'FLUTTER_ENGINE_SWITCH_13': 'purge-persistent-cache=true',
-            'FLUTTER_ENGINE_SWITCH_14': 'enable-impeller=false',
-            'FLUTTER_ENGINE_SWITCH_15': 'enable-checked-mode=true',
-            'FLUTTER_ENGINE_SWITCH_16': 'verify-entry-points=true',
-            'FLUTTER_ENGINE_SWITCH_17': 'start-paused=true',
-            'FLUTTER_ENGINE_SWITCH_18': 'disable-service-auth-codes=true',
-            'FLUTTER_ENGINE_SWITCH_19': 'dart-flags=--null_assertions',
-            'FLUTTER_ENGINE_SWITCH_20': 'use-test-fonts=true',
-            'FLUTTER_ENGINE_SWITCH_21': 'verbose-logging=true',
-            'FLUTTER_ENGINE_SWITCHES': '21',
+            'FLUTTER_ENGINE_SWITCH_11': 'profile-microtasks=true',
+            'FLUTTER_ENGINE_SWITCH_12': 'purge-persistent-cache=true',
+            'FLUTTER_ENGINE_SWITCH_13': 'enable-impeller=false',
+            'FLUTTER_ENGINE_SWITCH_14': 'enable-checked-mode=true',
+            'FLUTTER_ENGINE_SWITCH_15': 'verify-entry-points=true',
+            'FLUTTER_ENGINE_SWITCH_16': 'start-paused=true',
+            'FLUTTER_ENGINE_SWITCH_17': 'disable-service-auth-codes=true',
+            'FLUTTER_ENGINE_SWITCH_18': 'use-test-fonts=true',
+            'FLUTTER_ENGINE_SWITCH_19': 'verbose-logging=true',
+            'FLUTTER_ENGINE_SWITCHES': '19',
           },
         ),
       ]);
       final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
       final LaunchResult result = await device.startApp(
         package,
         prebuiltApplication: true,
@@ -199,12 +197,10 @@ void main() {
           traceSystrace: true,
           traceToFile: 'path/to/trace.binpb',
           endlessTraceBuffer: true,
-          dumpSkpOnShaderCompilation: true,
-          cacheSkSL: true,
+          profileMicrotasks: true,
           purgePersistentCache: true,
           useTestFonts: true,
           verboseSystemLogs: true,
-          nullAssertions: true,
         ),
       );
 
@@ -215,8 +211,8 @@ void main() {
   testWithoutContext(
     'startApp supports DebuggingOptions through FLUTTER_ENGINE_SWITCH environment variables when debugging is disabled',
     () async {
-      final Completer<void> completer = Completer<void>();
-      final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+      final completer = Completer<void>();
+      final processManager = FakeProcessManager.list(<FakeCommand>[
         FakeCommand(
           command: const <String>['debug'],
           stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
@@ -225,23 +221,18 @@ void main() {
             'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
             'FLUTTER_ENGINE_SWITCH_2': 'trace-startup=true',
             'FLUTTER_ENGINE_SWITCH_3': 'trace-allowlist=foo,bar',
-            'FLUTTER_ENGINE_SWITCH_4': 'cache-sksl=true',
-            'FLUTTER_ENGINE_SWITCH_5': 'enable-impeller=false',
-            'FLUTTER_ENGINE_SWITCHES': '5',
+            'FLUTTER_ENGINE_SWITCH_4': 'enable-impeller=false',
+            'FLUTTER_ENGINE_SWITCHES': '4',
           },
         ),
       ]);
       final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
       final LaunchResult result = await device.startApp(
         package,
         prebuiltApplication: true,
         platformArgs: <String, Object>{'trace-startup': true},
-        debuggingOptions: DebuggingOptions.disabled(
-          BuildInfo.debug,
-          traceAllowlist: 'foo,bar',
-          cacheSkSL: true,
-        ),
+        debuggingOptions: DebuggingOptions.disabled(BuildInfo.debug, traceAllowlist: 'foo,bar'),
       );
 
       expect(result.started, true);
@@ -264,8 +255,8 @@ void main() {
   });
 
   testWithoutContext('startApp supports dartEntrypointArgs', () async {
-    final Completer<void> completer = Completer<void>();
-    final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+    final completer = Completer<void>();
+    final processManager = FakeProcessManager.list(<FakeCommand>[
       FakeCommand(
         command: const <String>['debug', 'arg1', 'arg2'],
         stdout: 'The Dart VM service is listening on http://127.0.0.1/0\n',
@@ -273,7 +264,7 @@ void main() {
       ),
     ]);
     final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
-    final FakeApplicationPackage package = FakeApplicationPackage();
+    final package = FakeApplicationPackage();
     final LaunchResult result = await device.startApp(
       package,
       prebuiltApplication: true,
@@ -287,8 +278,8 @@ void main() {
   });
 
   testWithoutContext('Device logger captures all output', () async {
-    final Completer<void> exitCompleter = Completer<void>();
-    final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+    final exitCompleter = Completer<void>();
+    final processManager = FakeProcessManager.list(<FakeCommand>[
       FakeCommand(
         command: const <String>['debug', 'arg1', 'arg2'],
         exitCode: -1,
@@ -307,7 +298,7 @@ void main() {
     // Start looking for 'Oops' in the stream before starting the app.
     expect(device.getLogReader().logLines, emits('Oops'));
 
-    final FakeApplicationPackage package = FakeApplicationPackage();
+    final package = FakeApplicationPackage();
     await device.startApp(
       package,
       prebuiltApplication: true,
@@ -319,7 +310,7 @@ void main() {
   });
 
   testWithoutContext('Desktop devices pass through the enable-impeller flag', () async {
-    final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+    final processManager = FakeProcessManager.list(<FakeCommand>[
       const FakeCommand(
         command: <String>['debug'],
         exitCode: -1,
@@ -334,7 +325,7 @@ void main() {
     ]);
     final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
 
-    final FakeApplicationPackage package = FakeApplicationPackage();
+    final package = FakeApplicationPackage();
     await device.startApp(
       package,
       prebuiltApplication: true,
@@ -347,7 +338,7 @@ void main() {
   });
 
   testWithoutContext('Desktop devices pass through the --no-enable-impeller flag', () async {
-    final FakeProcessManager processManager = FakeProcessManager.list(<FakeCommand>[
+    final processManager = FakeProcessManager.list(<FakeCommand>[
       const FakeCommand(
         command: <String>['debug'],
         exitCode: -1,
@@ -362,7 +353,7 @@ void main() {
     ]);
     final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
 
-    final FakeApplicationPackage package = FakeApplicationPackage();
+    final package = FakeApplicationPackage();
     await device.startApp(
       package,
       prebuiltApplication: true,
@@ -374,18 +365,48 @@ void main() {
     );
   });
 
+  testWithoutContext('Desktop devices pass through the enable-flutter-gpu flag', () async {
+    final processManager = FakeProcessManager.list(<FakeCommand>[
+      const FakeCommand(
+        command: <String>['debug'],
+        exitCode: -1,
+        environment: <String, String>{
+          'FLUTTER_ENGINE_SWITCH_1': 'enable-dart-profiling=true',
+          'FLUTTER_ENGINE_SWITCH_2': 'enable-impeller=true',
+          'FLUTTER_ENGINE_SWITCH_3': 'enable-flutter-gpu=true',
+          'FLUTTER_ENGINE_SWITCH_4': 'enable-checked-mode=true',
+          'FLUTTER_ENGINE_SWITCH_5': 'verify-entry-points=true',
+          'FLUTTER_ENGINE_SWITCHES': '5',
+        },
+      ),
+    ]);
+    final FakeDesktopDevice device = setUpDesktopDevice(processManager: processManager);
+
+    final package = FakeApplicationPackage();
+    await device.startApp(
+      package,
+      prebuiltApplication: true,
+      debuggingOptions: DebuggingOptions.enabled(
+        BuildInfo.debug,
+        enableImpeller: ImpellerStatus.enabled,
+        enableFlutterGpu: true,
+        dartEntrypointArgs: <String>[],
+      ),
+    );
+  });
+
   testUsingContext(
     'macOS devices print warning if Dart VM not found within timeframe in CI',
     () async {
-      final BufferLogger logger = BufferLogger.test();
-      final FakeMacOSDevice device = FakeMacOSDevice(
+      final logger = BufferLogger.test();
+      final device = FakeMacOSDevice(
         fileSystem: MemoryFileSystem.test(),
         processManager: FakeProcessManager.any(),
         operatingSystemUtils: FakeOperatingSystemUtils(),
         logger: logger,
       );
 
-      final FakeApplicationPackage package = FakeApplicationPackage();
+      final package = FakeApplicationPackage();
 
       FakeAsync().run((FakeAsync fakeAsync) {
         device.startApp(
@@ -442,10 +463,10 @@ class FakeDesktopDevice extends DesktopDevice {
          operatingSystemUtils: operatingSystemUtils,
        );
 
-  /// The [mainPath] last passed to [buildForDevice].
+  /// The `mainPath` last passed to [buildForDevice].
   String? lastBuiltMainPath;
 
-  /// The [buildInfo] last passed to [buildForDevice].
+  /// The `buildInfo` last passed to [buildForDevice].
   BuildInfo? lastBuildInfo;
 
   final bool nullExecutablePathForDevice;
@@ -457,7 +478,7 @@ class FakeDesktopDevice extends DesktopDevice {
   Future<TargetPlatform> get targetPlatform async => TargetPlatform.tester;
 
   @override
-  bool isSupported() => true;
+  Future<bool> isSupported() async => true;
 
   @override
   bool isSupportedForProject(FlutterProject flutterProject) => true;
@@ -504,7 +525,7 @@ class FakeMacOSDevice extends MacOSDevice {
   Future<TargetPlatform> get targetPlatform async => TargetPlatform.tester;
 
   @override
-  bool isSupported() => true;
+  Future<bool> isSupported() async => true;
 
   @override
   bool isSupportedForProject(FlutterProject flutterProject) => true;
