@@ -55,7 +55,7 @@ void main() {
     testUsingContext(
       'dispose() does not throw an exception',
       () async {
-        final IOSSimulator simulator = IOSSimulator(
+        final simulator = IOSSimulator(
           '123',
           name: 'iPhone 11',
           simControl: simControl,
@@ -86,7 +86,7 @@ void main() {
   testUsingContext(
     'simulators only support debug mode',
     () async {
-      final IOSSimulator simulator = IOSSimulator(
+      final simulator = IOSSimulator(
         '123',
         name: 'iPhone 11',
         simControl: FakeSimControl(),
@@ -117,7 +117,7 @@ void main() {
       'defaults to rooted from HOME',
       () {
         osx.environment['HOME'] = '/foo/bar';
-        final IOSSimulator simulator = IOSSimulator(
+        final simulator = IOSSimulator(
           '123',
           name: 'iPhone 11',
           simControl: simControl,
@@ -140,7 +140,7 @@ void main() {
       () {
         osx.environment['HOME'] = '/foo/bar';
         osx.environment['IOS_SIMULATOR_LOG_FILE_PATH'] = '/baz/qux/%{id}/system.log';
-        final IOSSimulator simulator = IOSSimulator(
+        final simulator = IOSSimulator(
           '456',
           name: 'iPhone 11',
           simControl: simControl,
@@ -167,7 +167,7 @@ void main() {
 
     // This new version string appears in SimulatorApp-850 CoreSimulator-518.16 beta.
     testWithoutContext('can be parsed from iOS-11-3', () async {
-      final IOSSimulator device = IOSSimulator(
+      final device = IOSSimulator(
         'x',
         name: 'iPhone SE',
         simulatorCategory: 'com.apple.CoreSimulator.SimRuntime.iOS-11-3',
@@ -179,7 +179,7 @@ void main() {
     });
 
     testWithoutContext('can be parsed from iOS 11.2', () async {
-      final IOSSimulator device = IOSSimulator(
+      final device = IOSSimulator(
         'x',
         name: 'iPhone SE',
         simulatorCategory: 'iOS 11.2',
@@ -191,7 +191,7 @@ void main() {
     });
 
     testWithoutContext('Has a simulator category', () async {
-      final IOSSimulator device = IOSSimulator(
+      final device = IOSSimulator(
         'x',
         name: 'iPhone SE',
         simulatorCategory: 'iOS 11.2',
@@ -212,15 +212,15 @@ void main() {
 
     testUsingContext(
       'Apple TV is unsupported',
-      () {
-        final IOSSimulator simulator = IOSSimulator(
+      () async {
+        final simulator = IOSSimulator(
           'x',
           name: 'Apple TV',
           simControl: simControl,
           simulatorCategory: 'com.apple.CoreSimulator.SimRuntime.tvOS-14-5',
           logger: logger,
         );
-        expect(simulator.isSupported(), false);
+        expect(await simulator.isSupported(), false);
       },
       overrides: <Type, Generator>{
         Platform: () => osx,
@@ -231,9 +231,9 @@ void main() {
 
     testUsingContext(
       'Apple Watch is unsupported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'Apple Watch',
             simControl: simControl,
@@ -252,9 +252,9 @@ void main() {
 
     testUsingContext(
       'iPad 2 is supported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'iPad 2',
             simControl: simControl,
@@ -273,9 +273,9 @@ void main() {
 
     testUsingContext(
       'iPad Retina is supported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'iPad Retina',
             simControl: simControl,
@@ -294,9 +294,9 @@ void main() {
 
     testUsingContext(
       'iPhone 5 is supported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'iPhone 5',
             simControl: simControl,
@@ -315,9 +315,9 @@ void main() {
 
     testUsingContext(
       'iPhone 5s is supported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'iPhone 5s',
             simControl: simControl,
@@ -336,9 +336,9 @@ void main() {
 
     testUsingContext(
       'iPhone SE is supported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'iPhone SE',
             simControl: simControl,
@@ -357,9 +357,9 @@ void main() {
 
     testUsingContext(
       'iPhone 7 Plus is supported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'iPhone 7 Plus',
             simControl: simControl,
@@ -378,9 +378,9 @@ void main() {
 
     testUsingContext(
       'iPhone X is supported',
-      () {
+      () async {
         expect(
-          IOSSimulator(
+          await IOSSimulator(
             'x',
             name: 'iPhone X',
             simControl: simControl,
@@ -400,22 +400,22 @@ void main() {
 
   group('Simulator screenshot', () {
     testWithoutContext('supports screenshots', () async {
-      final Xcode xcode = Xcode.test(processManager: FakeProcessManager.any());
+      final xcode = Xcode.test(processManager: FakeProcessManager.any());
       final Logger logger = BufferLogger.test();
-      final FakeProcessManager fakeProcessManager = FakeProcessManager.list(<FakeCommand>[
+      final fakeProcessManager = FakeProcessManager.list(<FakeCommand>[
         const FakeCommand(
           command: <String>['xcrun', 'simctl', 'io', 'x', 'screenshot', 'screenshot.png'],
         ),
       ]);
 
       // Test a real one. Screenshot doesn't require instance states.
-      final SimControl simControl = SimControl(
+      final simControl = SimControl(
         processManager: fakeProcessManager,
         logger: logger,
         xcode: xcode,
       );
       // Doesn't matter what the device is.
-      final IOSSimulator deviceUnderTest = IOSSimulator(
+      final deviceUnderTest = IOSSimulator(
         'x',
         name: 'iPhone SE',
         simControl: simControl,
@@ -441,7 +441,7 @@ void main() {
     testUsingContext(
       'syslog uses tail',
       () async {
-        final IOSSimulator device = IOSSimulator(
+        final device = IOSSimulator(
           'x',
           name: 'iPhone SE',
           simulatorCategory: 'iOS 9.3',
@@ -467,14 +467,14 @@ void main() {
     testUsingContext(
       'unified logging with app name',
       () async {
-        final IOSSimulator device = IOSSimulator(
+        final device = IOSSimulator(
           'x',
           name: 'iPhone SE',
           simulatorCategory: 'iOS 11.0',
           simControl: simControl,
           logger: logger,
         );
-        const String expectedPredicate =
+        const expectedPredicate =
             'eventType = logEvent AND '
             'processImagePath ENDSWITH "My Super Awesome App" AND '
             '(senderImagePath ENDSWITH "/Flutter" OR senderImagePath ENDSWITH "/libswiftCore.dylib" OR processImageUUID == senderImageUUID) AND '
@@ -510,14 +510,14 @@ void main() {
     testUsingContext(
       'unified logging without app name',
       () async {
-        final IOSSimulator device = IOSSimulator(
+        final device = IOSSimulator(
           'x',
           name: 'iPhone SE',
           simulatorCategory: 'iOS 11.0',
           simControl: simControl,
           logger: logger,
         );
-        const String expectedPredicate =
+        const expectedPredicate =
             'eventType = logEvent AND '
             '(senderImagePath ENDSWITH "/Flutter" OR senderImagePath ENDSWITH "/libswiftCore.dylib" OR processImageUUID == senderImageUUID) AND '
             'NOT(eventMessage CONTAINS ": could not find icon for representation -> com.apple.") AND '
@@ -587,7 +587,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
               ),
             );
 
-          final IOSSimulator device = IOSSimulator(
+          final device = IOSSimulator(
             '123456',
             name: 'iPhone 11',
             simulatorCategory: 'iOS 10.0',
@@ -631,7 +631,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
               ),
             );
 
-          final IOSSimulator device = IOSSimulator(
+          final device = IOSSimulator(
             '123456',
             name: 'iPhone 11',
             simulatorCategory: 'iOS 10.3',
@@ -688,7 +688,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
               ),
             );
 
-          final IOSSimulator device = IOSSimulator(
+          final device = IOSSimulator(
             '123456',
             name: 'iPhone 11',
             simulatorCategory: 'iOS 10.3',
@@ -731,7 +731,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
       testUsingContext(
         'log reader handles escaped multiline messages',
         () async {
-          const String logPredicate =
+          const logPredicate =
               'eventType = logEvent AND processImagePath ENDSWITH "My Super Awesome App" '
               'AND (senderImagePath ENDSWITH "/Flutter" OR senderImagePath ENDSWITH "/libswiftCore.dylib" '
               'OR processImageUUID == senderImageUUID) AND NOT(eventMessage CONTAINS ": could not find icon '
@@ -768,7 +768,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
             ),
           );
 
-          final IOSSimulator device = IOSSimulator(
+          final device = IOSSimulator(
             '123456',
             name: 'iPhone 11',
             simulatorCategory: 'iOS 11.0',
@@ -796,7 +796,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
       testUsingContext(
         'log reader handles bad output',
         () async {
-          const String logPredicate =
+          const logPredicate =
               'eventType = logEvent AND processImagePath ENDSWITH "My Super Awesome App" '
               'AND (senderImagePath ENDSWITH "/Flutter" OR senderImagePath ENDSWITH "/libswiftCore.dylib" '
               'OR processImageUUID == senderImageUUID) AND NOT(eventMessage CONTAINS ": could not find icon '
@@ -820,7 +820,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
             ),
           );
 
-          final IOSSimulator device = IOSSimulator(
+          final device = IOSSimulator(
             '123456',
             name: 'iPhone 11',
             simulatorCategory: 'iOS 11.0',
@@ -846,7 +846,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
   });
 
   group('SimControl', () {
-    const String validSimControlOutput = '''
+    const validSimControlOutput = '''
 {
   "devices" : {
     "com.apple.CoreSimulator.SimRuntime.iOS-14-0" : [
@@ -899,14 +899,14 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     late IOSSimulatorUtils simulatorUtils;
     late IOSSimulatorUtils simulatorUtilsBadSimctl;
     late BufferLogger logger;
-    const String deviceId = 'smart-phone';
-    const String appId = 'flutterApp';
+    const deviceId = 'smart-phone';
+    const appId = 'flutterApp';
 
     setUp(() {
       fakeProcessManager = FakeProcessManager.empty();
       xcode = Xcode.test(processManager: FakeProcessManager.any());
 
-      final FakeProcessManager fakeProcessManagerBadSimctl = FakeProcessManager.list(<FakeCommand>[
+      final fakeProcessManagerBadSimctl = FakeProcessManager.list(<FakeCommand>[
         const FakeCommand(command: <String>['which', 'sysctl']),
         const FakeCommand(
           command: <String>['sysctl', 'hw.optional.arm64'],
@@ -1012,7 +1012,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     );
 
     testWithoutContext('sdkMajorVersion defaults to 11 when sdkNameAndVersion is junk', () async {
-      final IOSSimulator iosSimulatorA = IOSSimulator(
+      final iosSimulatorA = IOSSimulator(
         'x',
         name: 'Testo',
         simulatorCategory: 'NaN',
@@ -1081,7 +1081,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     });
 
     testWithoutContext('simulator stopApp handles null app package', () async {
-      final IOSSimulator iosSimulator = IOSSimulator(
+      final iosSimulator = IOSSimulator(
         'x',
         name: 'Testo',
         simulatorCategory: 'NaN',
@@ -1093,7 +1093,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     });
 
     testWithoutContext('listAvailableIOSRuntimes succeeds', () async {
-      const String validRuntimesOutput = '''
+      const validRuntimesOutput = '''
 {
   "runtimes" : [
     {
@@ -1254,8 +1254,8 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     testWithoutContext(
       'IOSSimulatorUtils.getAvailableIOSRuntimes handles simctl not properly installed',
       () async {
-        final List<IOSSimulatorRuntime> runtimes =
-            await simulatorUtilsBadSimctl.getAvailableIOSRuntimes();
+        final List<IOSSimulatorRuntime> runtimes = await simulatorUtilsBadSimctl
+            .getAvailableIOSRuntimes();
 
         expect(runtimes, isEmpty);
         expect(fakeProcessManager, hasNoRemainingExpectations);
@@ -1279,7 +1279,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     testUsingContext(
       "startApp uses compiled app's Info.plist to find CFBundleIdentifier",
       () async {
-        final IOSSimulator device = IOSSimulator(
+        final device = IOSSimulator(
           'x',
           name: 'iPhone SE',
           simulatorCategory: 'iOS 11.2',
@@ -1296,13 +1296,13 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
           applicationPackage: mockDir,
         );
 
-        const BuildInfo mockInfo = BuildInfo(
+        const mockInfo = BuildInfo(
           BuildMode.debug,
           'flavor',
           treeShakeIcons: false,
           packageConfigPath: '.dart_tool/package_config.json',
         );
-        final DebuggingOptions mockOptions = DebuggingOptions.disabled(mockInfo);
+        final mockOptions = DebuggingOptions.disabled(mockInfo);
         await device.startApp(package, prebuiltApplication: true, debuggingOptions: mockOptions);
 
         expect(simControl.requests.single.appIdentifier, 'correct');
@@ -1318,7 +1318,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     testUsingContext(
       'startApp fails when cannot find CFBundleIdentifier',
       () async {
-        final IOSSimulator device = IOSSimulator(
+        final device = IOSSimulator(
           'x',
           name: 'iPhone SE',
           simulatorCategory: 'iOS 11.2',
@@ -1334,13 +1334,13 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
           applicationPackage: mockDir,
         );
 
-        const BuildInfo mockInfo = BuildInfo(
+        const mockInfo = BuildInfo(
           BuildMode.debug,
           'flavor',
           treeShakeIcons: false,
           packageConfigPath: '.dart_tool/package_config.json',
         );
-        final DebuggingOptions mockOptions = DebuggingOptions.disabled(mockInfo);
+        final mockOptions = DebuggingOptions.disabled(mockInfo);
         final LaunchResult result = await device.startApp(
           package,
           prebuiltApplication: true,
@@ -1366,7 +1366,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     testUsingContext(
       'startApp forwards all supported debugging options',
       () async {
-        final IOSSimulator device = IOSSimulator(
+        final device = IOSSimulator(
           'x',
           name: 'iPhone SE',
           simulatorCategory: 'iOS 11.2',
@@ -1383,13 +1383,13 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
           applicationPackage: mockDir,
         );
 
-        const BuildInfo mockInfo = BuildInfo(
+        const mockInfo = BuildInfo(
           BuildMode.debug,
           'flavor',
           treeShakeIcons: false,
           packageConfigPath: '.dart_tool/package_config.json',
         );
-        final DebuggingOptions mockOptions = DebuggingOptions.enabled(
+        final mockOptions = DebuggingOptions.enabled(
           mockInfo,
           enableSoftwareRendering: true,
           traceSystrace: true,
@@ -1402,6 +1402,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
           traceAllowlist: 'foo,bar',
           traceSkiaAllowlist: 'skia.a,skia.b',
           endlessTraceBuffer: true,
+          profileMicrotasks: true,
           verboseSystemLogs: true,
           purgePersistentCache: true,
           dartFlags: '--baz',
@@ -1427,6 +1428,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
             '--trace-allowlist="foo,bar"',
             '--trace-skia-allowlist="skia.a,skia.b"',
             '--endless-trace-buffer',
+            '--profile-microtasks',
             '--verbose-logging',
             '--purge-persistent-cache',
             '--enable-impeller=false',
@@ -1446,7 +1448,7 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
     testUsingContext(
       'startApp using route',
       () async {
-        final IOSSimulator device = IOSSimulator(
+        final device = IOSSimulator(
           'x',
           name: 'iPhone SE',
           simulatorCategory: 'iOS 11.2',
@@ -1463,16 +1465,13 @@ Dec 20 17:04:32 md32-11-vm1 Another App[88374]: Ignore this text''',
           applicationPackage: mockDir,
         );
 
-        const BuildInfo mockInfo = BuildInfo(
+        const mockInfo = BuildInfo(
           BuildMode.debug,
           'flavor',
           treeShakeIcons: false,
           packageConfigPath: '.dart_tool/package_config.json',
         );
-        final DebuggingOptions mockOptions = DebuggingOptions.enabled(
-          mockInfo,
-          enableSoftwareRendering: true,
-        );
+        final mockOptions = DebuggingOptions.enabled(mockInfo, enableSoftwareRendering: true);
         await device.startApp(
           package,
           prebuiltApplication: true,
@@ -1515,7 +1514,7 @@ flutter:
           globals.fs.currentDirectory,
         );
 
-        final IOSSimulator simulator = IOSSimulator(
+        final simulator = IOSSimulator(
           'test',
           name: 'iPhone 11',
           simControl: simControl,
@@ -1540,7 +1539,7 @@ flutter:
           globals.fs.currentDirectory,
         );
 
-        final IOSSimulator simulator = IOSSimulator(
+        final simulator = IOSSimulator(
           'test',
           name: 'iPhone 11',
           simControl: simControl,
@@ -1564,7 +1563,7 @@ flutter:
           globals.fs.currentDirectory,
         );
 
-        final IOSSimulator simulator = IOSSimulator(
+        final simulator = IOSSimulator(
           'test',
           name: 'iPhone 11',
           simControl: simControl,
@@ -1581,7 +1580,7 @@ flutter:
     );
 
     testUsingContext('createDevFSWriter returns a LocalDevFSWriter', () {
-      final IOSSimulator simulator = IOSSimulator(
+      final simulator = IOSSimulator(
         'test',
         name: 'iPhone 11',
         simControl: simControl,
@@ -1603,7 +1602,7 @@ class FakeIosProject extends Fake implements IosProject {
 }
 
 class FakeSimControl extends Fake implements SimControl {
-  final List<LaunchRequest> requests = <LaunchRequest>[];
+  final requests = <LaunchRequest>[];
 
   @override
   Future<RunResult> launch(
