@@ -95,8 +95,8 @@ void main() {
       stdoutMessages,
       containsAll([
         {
-          'stream': CoreDtdServiceConstants.servicesStreamId,
-          'kind': CoreDtdServiceConstants.serviceRegisteredKind,
+          'stream': 'Service',
+          'kind': 'ServiceRegistered',
           'data': {
             'service': 'ExampleServer',
             'method': 'getServerState',
@@ -109,8 +109,8 @@ void main() {
           'uptime': const Duration(minutes: 45).inMilliseconds,
         },
         {
-          'stream': CoreDtdServiceConstants.servicesStreamId,
-          'kind': CoreDtdServiceConstants.serviceUnregisteredKind,
+          'stream': 'Service',
+          'kind': 'ServiceUnregistered',
           'data': {
             'service': 'ExampleServer',
             'method': 'getServerState',
