@@ -6,14 +6,13 @@ import 'dart:async';
 import 'dart:ffi';
 import 'dart:io';
 
+import 'package:code_assets/code_assets.dart';
 import 'package:logging/logging.dart';
-import 'package:native_assets_cli/code_assets_builder.dart';
 import 'package:native_toolchain_c/src/native_toolchain/apple_clang.dart';
+import 'package:native_toolchain_c/src/native_toolchain/msvc.dart';
 import 'package:native_toolchain_c/src/utils/run_process.dart';
 import 'package:test/test.dart';
 
-export 'package:native_assets_cli/code_assets_builder.dart';
-
 /// Returns a suffix for a test that is parameterized.
 ///
 /// [tags] represent the current configuration of the test. Each element
@@ -45,8 +44,9 @@ const keepTempKey = 'KEEP_TEMPORARY_DIRECTORIES';
 Future<Uri> tempDirForTest({String? prefix, bool keepTemp = false}) async {
   final tempDir = await Directory.systemTemp.createTemp(prefix);
   // Deal with Windows temp folder aliases.
-  final tempUri =
-      Directory(await tempDir.resolveSymbolicLinks()).uri.normalizePath();
+  final tempUri = Directory(
+    await tempDir.resolveSymbolicLinks(),
+  ).uri.normalizePath();
   if ((!Platform.environment.containsKey(keepTempKey) ||
           Platform.environment[keepTempKey]!.isEmpty) &&
       !keepTemp) {
@@ -58,13 +58,12 @@ Future<Uri> tempDirForTest({String? prefix, bool keepTemp = false}) async {
 }
 
 /// Logger that outputs the full trace when a test fails.
-Logger get logger =>
-    _logger ??= () {
-      // A new logger is lazily created for each test so that the messages
-      // captured by printOnFailure are scoped to the correct test.
-      addTearDown(() => _logger = null);
-      return _createTestLogger();
-    }();
+Logger get logger => _logger ??= () {
+  // A new logger is lazily created for each test so that the messages
+  // captured by printOnFailure are scoped to the correct test.
+  addTearDown(() => _logger = null);
+  return _createTestLogger();
+}();
 
 Logger? _logger;
 
@@ -93,8 +92,8 @@ Logger _createTestLogger({List<String>? capturedMessages}) =>
 Uri findPackageRoot(String packageName) {
   final script = Platform.script;
   final fileName = script.name;
-  if (fileName.endsWith('_test.dart')) {
-    // We're likely running from source.
+  if (fileName.endsWith('.dart')) {
+    // We're likely running from source in the package somewhere.
     var directory = script.resolve('.');
     while (true) {
       final dirName = directory.name;
@@ -106,12 +105,19 @@ Uri findPackageRoot(String packageName) {
       directory = parent;
     }
   } else if (fileName.endsWith('.dill')) {
+    // Probably from the package root.
     final cwd = Directory.current.uri;
     final dirName = cwd.name;
     if (dirName == packageName) {
       return cwd;
     }
   }
+  // Or the workspace root.
+  final cwd = Directory.current.uri;
+  final candidate = cwd.resolve('pkgs/$packageName/');
+  if (Directory.fromUri(candidate).existsSync()) {
+    return candidate;
+  }
   throw StateError(
     "Could not find package root for package '$packageName'. "
     'Tried finding the package root via Platform.script '
@@ -129,27 +135,27 @@ extension on Uri {
 /// Archiver provided by the environment.
 ///
 /// Provided on Dart CI.
-final Uri? _ar =
-    Platform.environment['DART_HOOK_TESTING_C_COMPILER__AR']?.asFileUri();
+final Uri? _ar = Platform.environment['DART_HOOK_TESTING_C_COMPILER__AR']
+    ?.asFileUri();
 
 /// Compiler provided by the environment.
 ///
 /// Provided on Dart CI.
-final Uri? _cc =
-    Platform.environment['DART_HOOK_TESTING_C_COMPILER__CC']?.asFileUri();
+final Uri? _cc = Platform.environment['DART_HOOK_TESTING_C_COMPILER__CC']
+    ?.asFileUri();
 
 /// Linker provided by the environment.
 ///
 /// Provided on Dart CI.
-final Uri? _ld =
-    Platform.environment['DART_HOOK_TESTING_C_COMPILER__LD']?.asFileUri();
+final Uri? _ld = Platform.environment['DART_HOOK_TESTING_C_COMPILER__LD']
+    ?.asFileUri();
 
 /// Path to script that sets environment variables for [_cc], [_ld], and [_ar].
 ///
 /// Provided on Dart CI.
-final Uri? _envScript =
-    Platform.environment['DART_HOOK_TESTING_C_COMPILER__ENV_SCRIPT']
-        ?.asFileUri();
+final Uri? _envScript = Platform
+    .environment['DART_HOOK_TESTING_C_COMPILER__ENV_SCRIPT']
+    ?.asFileUri();
 
 /// Arguments for [_envScript] provided by environment.
 ///
@@ -161,23 +167,21 @@ final List<String>? _envScriptArgs = Platform
 /// Configuration for the native toolchain.
 ///
 /// Provided on Dart CI.
-final cCompiler =
-    (_cc == null || _ar == null || _ld == null)
-        ? null
-        : CCompilerConfig(
-          compiler: _cc!,
-          archiver: _ar!,
-          linker: _ld!,
-          windows: WindowsCCompilerConfig(
-            developerCommandPrompt:
-                _envScript == null
-                    ? null
-                    : DeveloperCommandPrompt(
-                      script: _envScript!,
-                      arguments: _envScriptArgs ?? [],
-                    ),
-          ),
-        );
+final cCompiler = (_cc == null || _ar == null || _ld == null)
+    ? null
+    : CCompilerConfig(
+        compiler: _cc!,
+        archiver: _ar!,
+        linker: _ld!,
+        windows: WindowsCCompilerConfig(
+          developerCommandPrompt: _envScript == null
+              ? null
+              : DeveloperCommandPrompt(
+                  script: _envScript!,
+                  arguments: _envScriptArgs ?? [],
+                ),
+        ),
+      );
 
 extension on String {
   Uri asFileUri() => Uri.file(this);
@@ -187,8 +191,9 @@ extension on String {
 ///
 /// Because `otool` output multiple names, [libraryName] as search parameter.
 Future<String> runOtoolInstallName(Uri libraryUri, String libraryName) async {
-  final otoolUri =
-      (await otool.defaultResolver!.resolve(logger: logger)).first.uri;
+  final otoolUri = (await otool.defaultResolver!.resolve(
+    logger: logger,
+  )).first.uri;
   final otoolResult = await runProcess(
     executable: otoolUri,
     arguments: ['-l', libraryUri.path],
@@ -197,14 +202,11 @@ Future<String> runOtoolInstallName(Uri libraryUri, String libraryName) async {
   expect(otoolResult.exitCode, 0);
   // Leading space on purpose to differentiate from other types of names.
   const installNameName = ' name ';
-  final installName =
-      otoolResult.stdout
-          .split('\n')
-          .firstWhere(
-            (e) => e.contains(installNameName) && e.contains(libraryName),
-          )
-          .trim()
-          .split(' ')[1];
+  final installName = otoolResult.stdout
+      .split('\n')
+      .firstWhere((e) => e.contains(installNameName) && e.contains(libraryName))
+      .trim()
+      .split(' ')[1];
   return installName;
 }
 
@@ -244,29 +246,38 @@ Future<String> readelf(String filePath, String flags) async {
   return result.stdout;
 }
 
-Future<String> nmReadSymbols(CodeAsset asset) async {
-  final assetUri = asset.file!;
-  final result = await runProcess(
-    executable: Uri(path: 'nm'),
-    arguments: ['-D', assetUri.toFilePath()],
-    logger: logger,
-  );
+List<String> nmParameterFor(OS targetOS) => switch (targetOS) {
+  OS.macOS || OS.iOS => const [],
+  OS() => ['-D'],
+};
 
-  expect(result.exitCode, 0);
-  return result.stdout;
+Future<String> readSymbols(CodeAsset asset, OS targetOS) async {
+  final assetUri = asset.file!;
+  switch (targetOS) {
+    case OS.windows:
+      final result = await _runDumpbin(['/EXPORTS'], asset.file!);
+      expect(result.exitCode, 0);
+      return result.stdout;
+    case OS():
+      final result = await runProcess(
+        executable: Uri(path: 'nm'),
+        arguments: [...nmParameterFor(targetOS), assetUri.toFilePath()],
+        logger: logger,
+      );
+      expect(result.exitCode, 0);
+      return result.stdout;
+  }
 }
 
-Future<void> expectSymbols({
-  required CodeAsset asset,
-  required List<String> symbols,
-}) async {
-  if (Platform.isLinux) {
-    final nmOutput = await nmReadSymbols(asset);
-
-    expect(nmOutput, stringContainsInOrder(symbols));
-  } else {
-    throw UnimplementedError();
-  }
+Future<RunProcessResult> _runDumpbin(List<String> arguments, Uri libUri) async {
+  final dumpbinUri = (await dumpbin.defaultResolver!.resolve(
+    logger: logger,
+  )).first.uri;
+  return await runProcess(
+    executable: dumpbinUri,
+    arguments: [...arguments, libUri.toFilePath()],
+    logger: logger,
+  );
 }
 
 Future<int> textSectionAddress(Uri dylib) async {
@@ -314,3 +325,108 @@ Future<void> expectPageSize(Uri dylib, int pageSize) async {
 }
 
 int defaultMacOSVersion = 13;
+
+/// From https://docs.flutter.dev/reference/supported-platforms.
+const flutterAndroidNdkVersionLowestSupported = 21;
+
+/// From https://docs.flutter.dev/reference/supported-platforms.
+const flutterAndroidNdkVersionHighestSupported = 34;
+
+/// File-format strings used by the `objdump` tool for Android binaries that
+/// run on a given architecture.
+const objdumpFileFormatAndroid = {
+  Architecture.arm: 'elf32-littlearm',
+  Architecture.arm64: 'elf64-littleaarch64',
+  Architecture.ia32: 'elf32-i386',
+  Architecture.x64: 'elf64-x86-64',
+  Architecture.riscv64: 'elf64-littleriscv',
+};
+
+const objdumpFileFormatMacOS = {
+  Architecture.arm64: 'mach-o arm64',
+  Architecture.x64: 'mach-o 64-bit x86-64',
+};
+
+// Don't include 'mach-o' or 'Mach-O', different spelling is used.
+const objdumpFileFormatIOS = {
+  Architecture.arm64: 'arm64',
+  Architecture.x64: '64-bit x86-64',
+};
+
+const targetOSToObjdumpFileFormat = {
+  OS.android: objdumpFileFormatAndroid,
+  OS.macOS: objdumpFileFormatMacOS,
+  OS.iOS: objdumpFileFormatMacOS,
+};
+
+const dumpbinFileFormat = {
+  Architecture.arm64: 'ARM64',
+  Architecture.ia32: 'x86',
+  Architecture.x64: 'x64',
+};
+
+/// Checks that the provided [libUri] binary has the correct format to be
+/// executed on the provided [targetArch] architecture.
+///
+/// On Linux, the format of the binary is determined by `readelf`. On MacOS,
+/// the `objsdump` tool is used. On Windows, `dumpbin` is used.
+Future<void> expectMachineArchitecture(
+  Uri libUri,
+  Architecture targetArch,
+  OS targetOS,
+) async {
+  if (Platform.isLinux) {
+    final machine = await readelfMachine(libUri.path);
+    expect(machine, contains(readElfMachine[targetArch]));
+  } else if (Platform.isMacOS) {
+    final result = await runProcess(
+      executable: Uri.file('objdump'),
+      arguments: ['-T', libUri.path],
+      logger: logger,
+    );
+    expect(result.exitCode, 0);
+    final machine = result.stdout
+        .split('\n')
+        .firstWhere((e) => e.contains('file format'));
+    expect(
+      machine,
+      contains(targetOSToObjdumpFileFormat[targetOS]![targetArch]),
+    );
+  } else if (Platform.isWindows && targetOS == OS.windows) {
+    final result = await _runDumpbin(['/HEADERS'], libUri);
+    expect(result.exitCode, 0);
+    final machine = result.stdout
+        .split('\n')
+        .firstWhere((e) => e.contains('machine'));
+    expect(machine, contains(dumpbinFileFormat[targetArch]));
+  }
+}
+
+List<Architecture> supportedArchitecturesFor(OS targetOS) => switch (targetOS) {
+  OS.macOS || OS.iOS => [Architecture.arm64, Architecture.x64],
+  OS.windows => [
+    // TODO(https://github.com/dart-lang/native/issues/170): Support arm64.
+    // Architecture.arm64,
+    Architecture.ia32,
+    Architecture.x64,
+  ],
+  OS() => [
+    Architecture.arm,
+    Architecture.arm64,
+    Architecture.ia32,
+    Architecture.x64,
+    Architecture.riscv64,
+  ],
+};
+
+List<Architecture> iOSSupportedArchitecturesFor(IOSSdk iosSdk) =>
+    switch (iosSdk) {
+      IOSSdk.iPhoneOS => supportedArchitecturesFor(
+        OS.iOS,
+      )..remove(Architecture.x64),
+      IOSSdk.iPhoneSimulator => supportedArchitecturesFor(OS.iOS),
+      IOSSdk() => throw UnimplementedError(),
+    };
+
+const flutteriOSHighestBestEffort = 16;
+const flutteriOSHighestSupported = 17;
