@@ -1,20 +1,18 @@
-// ignore_for_file: avoid_returning_null
 // ignore_for_file: camel_case_types
-// ignore_for_file: cascade_invocations
 // ignore_for_file: comment_references
-// ignore_for_file: file_names
-// ignore_for_file: library_names
+// ignore_for_file: deprecated_member_use_from_same_package
 // ignore_for_file: lines_longer_than_80_chars
 // ignore_for_file: non_constant_identifier_names
+// ignore_for_file: prefer_const_declarations
 // ignore_for_file: prefer_expression_function_bodies
 // ignore_for_file: prefer_final_locals
 // ignore_for_file: prefer_interpolation_to_compose_strings
-// ignore_for_file: prefer_single_quotes
 // ignore_for_file: unnecessary_brace_in_string_interps
 // ignore_for_file: unnecessary_cast
 // ignore_for_file: unnecessary_lambdas
-// ignore_for_file: unnecessary_parenthesis
+// ignore_for_file: unnecessary_library_directive
 // ignore_for_file: unnecessary_string_interpolations
+// ignore_for_file: unreachable_from_main
 // ignore_for_file: unused_local_variable
 
 import 'dart:async' as async;
@@ -27,14 +25,12 @@ import 'package:test/test.dart' as unittest;
 
 import '../test_shared.dart';
 
-core.List<core.String> buildUnnamed6416() {
-  var o = <core.String>[];
-  o.add('foo');
-  o.add('foo');
-  return o;
-}
+core.List<core.String> buildUnnamed0() => [
+      'foo',
+      'foo',
+    ];
 
-void checkUnnamed6416(core.List<core.String> o) {
+void checkUnnamed0(core.List<core.String> o) {
   unittest.expect(o, unittest.hasLength(2));
   unittest.expect(
     o[0],
@@ -46,14 +42,12 @@ void checkUnnamed6416(core.List<core.String> o) {
   );
 }
 
-core.List<core.String> buildUnnamed6417() {
-  var o = <core.String>[];
-  o.add('foo');
-  o.add('foo');
-  return o;
-}
+core.List<core.String> buildUnnamed1() => [
+      'foo',
+      'foo',
+    ];
 
-void checkUnnamed6417(core.List<core.String> o) {
+void checkUnnamed1(core.List<core.String> o) {
   unittest.expect(o, unittest.hasLength(2));
   unittest.expect(
     o[0],
@@ -67,12 +61,12 @@ void checkUnnamed6417(core.List<core.String> o) {
 
 core.int buildCounterGenerateAccessTokenRequest = 0;
 api.GenerateAccessTokenRequest buildGenerateAccessTokenRequest() {
-  var o = api.GenerateAccessTokenRequest();
+  final o = api.GenerateAccessTokenRequest();
   buildCounterGenerateAccessTokenRequest++;
   if (buildCounterGenerateAccessTokenRequest < 3) {
-    o.delegates = buildUnnamed6416();
+    o.delegates = buildUnnamed0();
     o.lifetime = 'foo';
-    o.scope = buildUnnamed6417();
+    o.scope = buildUnnamed1();
   }
   buildCounterGenerateAccessTokenRequest--;
   return o;
@@ -81,19 +75,19 @@ api.GenerateAccessTokenRequest buildGenerateAccessTokenRequest() {
 void checkGenerateAccessTokenRequest(api.GenerateAccessTokenRequest o) {
   buildCounterGenerateAccessTokenRequest++;
   if (buildCounterGenerateAccessTokenRequest < 3) {
-    checkUnnamed6416(o.delegates!);
+    checkUnnamed0(o.delegates!);
     unittest.expect(
       o.lifetime!,
       unittest.equals('foo'),
     );
-    checkUnnamed6417(o.scope!);
+    checkUnnamed1(o.scope!);
   }
   buildCounterGenerateAccessTokenRequest--;
 }
 
 core.int buildCounterGenerateAccessTokenResponse = 0;
 api.GenerateAccessTokenResponse buildGenerateAccessTokenResponse() {
-  var o = api.GenerateAccessTokenResponse();
+  final o = api.GenerateAccessTokenResponse();
   buildCounterGenerateAccessTokenResponse++;
   if (buildCounterGenerateAccessTokenResponse < 3) {
     o.accessToken = 'foo';
@@ -118,14 +112,12 @@ void checkGenerateAccessTokenResponse(api.GenerateAccessTokenResponse o) {
   buildCounterGenerateAccessTokenResponse--;
 }
 
-core.List<core.String> buildUnnamed6418() {
-  var o = <core.String>[];
-  o.add('foo');
-  o.add('foo');
-  return o;
-}
+core.List<core.String> buildUnnamed2() => [
+      'foo',
+      'foo',
+    ];
 
-void checkUnnamed6418(core.List<core.String> o) {
+void checkUnnamed2(core.List<core.String> o) {
   unittest.expect(o, unittest.hasLength(2));
   unittest.expect(
     o[0],
@@ -139,11 +131,11 @@ void checkUnnamed6418(core.List<core.String> o) {
 
 core.int buildCounterGenerateIdTokenRequest = 0;
 api.GenerateIdTokenRequest buildGenerateIdTokenRequest() {
-  var o = api.GenerateIdTokenRequest();
+  final o = api.GenerateIdTokenRequest();
   buildCounterGenerateIdTokenRequest++;
   if (buildCounterGenerateIdTokenRequest < 3) {
     o.audience = 'foo';
-    o.delegates = buildUnnamed6418();
+    o.delegates = buildUnnamed2();
     o.includeEmail = true;
   }
   buildCounterGenerateIdTokenRequest--;
@@ -157,7 +149,7 @@ void checkGenerateIdTokenRequest(api.GenerateIdTokenRequest o) {
       o.audience!,
       unittest.equals('foo'),
     );
-    checkUnnamed6418(o.delegates!);
+    checkUnnamed2(o.delegates!);
     unittest.expect(o.includeEmail!, unittest.isTrue);
   }
   buildCounterGenerateIdTokenRequest--;
@@ -165,7 +157,7 @@ void checkGenerateIdTokenRequest(api.GenerateIdTokenRequest o) {
 
 core.int buildCounterGenerateIdTokenResponse = 0;
 api.GenerateIdTokenResponse buildGenerateIdTokenResponse() {
-  var o = api.GenerateIdTokenResponse();
+  final o = api.GenerateIdTokenResponse();
   buildCounterGenerateIdTokenResponse++;
   if (buildCounterGenerateIdTokenResponse < 3) {
     o.token = 'foo';
@@ -185,14 +177,12 @@ void checkGenerateIdTokenResponse(api.GenerateIdTokenResponse o) {
   buildCounterGenerateIdTokenResponse--;
 }
 
-core.List<core.String> buildUnnamed6419() {
-  var o = <core.String>[];
-  o.add('foo');
-  o.add('foo');
-  return o;
-}
+core.List<core.String> buildUnnamed3() => [
+      'foo',
+      'foo',
+    ];
 
-void checkUnnamed6419(core.List<core.String> o) {
+void checkUnnamed3(core.List<core.String> o) {
   unittest.expect(o, unittest.hasLength(2));
   unittest.expect(
     o[0],
@@ -206,10 +196,10 @@ void checkUnnamed6419(core.List<core.String> o) {
 
 core.int buildCounterSignBlobRequest = 0;
 api.SignBlobRequest buildSignBlobRequest() {
-  var o = api.SignBlobRequest();
+  final o = api.SignBlobRequest();
   buildCounterSignBlobRequest++;
   if (buildCounterSignBlobRequest < 3) {
-    o.delegates = buildUnnamed6419();
+    o.delegates = buildUnnamed3();
     o.payload = 'foo';
   }
   buildCounterSignBlobRequest--;
@@ -219,7 +209,7 @@ api.SignBlobRequest buildSignBlobRequest() {
 void checkSignBlobRequest(api.SignBlobRequest o) {
   buildCounterSignBlobRequest++;
   if (buildCounterSignBlobRequest < 3) {
-    checkUnnamed6419(o.delegates!);
+    checkUnnamed3(o.delegates!);
     unittest.expect(
       o.payload!,
       unittest.equals('foo'),
@@ -230,7 +220,7 @@ void checkSignBlobRequest(api.SignBlobRequest o) {
 
 core.int buildCounterSignBlobResponse = 0;
 api.SignBlobResponse buildSignBlobResponse() {
-  var o = api.SignBlobResponse();
+  final o = api.SignBlobResponse();
   buildCounterSignBlobResponse++;
   if (buildCounterSignBlobResponse < 3) {
     o.keyId = 'foo';
@@ -255,14 +245,12 @@ void checkSignBlobResponse(api.SignBlobResponse o) {
   buildCounterSignBlobResponse--;
 }
 
-core.List<core.String> buildUnnamed6420() {
-  var o = <core.String>[];
-  o.add('foo');
-  o.add('foo');
-  return o;
-}
+core.List<core.String> buildUnnamed4() => [
+      'foo',
+      'foo',
+    ];
 
-void checkUnnamed6420(core.List<core.String> o) {
+void checkUnnamed4(core.List<core.String> o) {
   unittest.expect(o, unittest.hasLength(2));
   unittest.expect(
     o[0],
@@ -276,10 +264,10 @@ void checkUnnamed6420(core.List<core.String> o) {
 
 core.int buildCounterSignJwtRequest = 0;
 api.SignJwtRequest buildSignJwtRequest() {
-  var o = api.SignJwtRequest();
+  final o = api.SignJwtRequest();
   buildCounterSignJwtRequest++;
   if (buildCounterSignJwtRequest < 3) {
-    o.delegates = buildUnnamed6420();
+    o.delegates = buildUnnamed4();
     o.payload = 'foo';
   }
   buildCounterSignJwtRequest--;
@@ -289,7 +277,7 @@ api.SignJwtRequest buildSignJwtRequest() {
 void checkSignJwtRequest(api.SignJwtRequest o) {
   buildCounterSignJwtRequest++;
   if (buildCounterSignJwtRequest < 3) {
-    checkUnnamed6420(o.delegates!);
+    checkUnnamed4(o.delegates!);
     unittest.expect(
       o.payload!,
       unittest.equals('foo'),
@@ -300,7 +288,7 @@ void checkSignJwtRequest(api.SignJwtRequest o) {
 
 core.int buildCounterSignJwtResponse = 0;
 api.SignJwtResponse buildSignJwtResponse() {
-  var o = api.SignJwtResponse();
+  final o = api.SignJwtResponse();
   buildCounterSignJwtResponse++;
   if (buildCounterSignJwtResponse < 3) {
     o.keyId = 'foo';
@@ -328,121 +316,121 @@ void checkSignJwtResponse(api.SignJwtResponse o) {
 void main() {
   unittest.group('obj-schema-GenerateAccessTokenRequest', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildGenerateAccessTokenRequest();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.GenerateAccessTokenRequest.fromJson(
+      final o = buildGenerateAccessTokenRequest();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.GenerateAccessTokenRequest.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkGenerateAccessTokenRequest(od as api.GenerateAccessTokenRequest);
+      checkGenerateAccessTokenRequest(od);
     });
   });
 
   unittest.group('obj-schema-GenerateAccessTokenResponse', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildGenerateAccessTokenResponse();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.GenerateAccessTokenResponse.fromJson(
+      final o = buildGenerateAccessTokenResponse();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.GenerateAccessTokenResponse.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkGenerateAccessTokenResponse(od as api.GenerateAccessTokenResponse);
+      checkGenerateAccessTokenResponse(od);
     });
   });
 
   unittest.group('obj-schema-GenerateIdTokenRequest', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildGenerateIdTokenRequest();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.GenerateIdTokenRequest.fromJson(
+      final o = buildGenerateIdTokenRequest();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.GenerateIdTokenRequest.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkGenerateIdTokenRequest(od as api.GenerateIdTokenRequest);
+      checkGenerateIdTokenRequest(od);
     });
   });
 
   unittest.group('obj-schema-GenerateIdTokenResponse', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildGenerateIdTokenResponse();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.GenerateIdTokenResponse.fromJson(
+      final o = buildGenerateIdTokenResponse();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.GenerateIdTokenResponse.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkGenerateIdTokenResponse(od as api.GenerateIdTokenResponse);
+      checkGenerateIdTokenResponse(od);
     });
   });
 
   unittest.group('obj-schema-SignBlobRequest', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildSignBlobRequest();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.SignBlobRequest.fromJson(
+      final o = buildSignBlobRequest();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.SignBlobRequest.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkSignBlobRequest(od as api.SignBlobRequest);
+      checkSignBlobRequest(od);
     });
   });
 
   unittest.group('obj-schema-SignBlobResponse', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildSignBlobResponse();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.SignBlobResponse.fromJson(
+      final o = buildSignBlobResponse();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.SignBlobResponse.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkSignBlobResponse(od as api.SignBlobResponse);
+      checkSignBlobResponse(od);
     });
   });
 
   unittest.group('obj-schema-SignJwtRequest', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildSignJwtRequest();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.SignJwtRequest.fromJson(
+      final o = buildSignJwtRequest();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.SignJwtRequest.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkSignJwtRequest(od as api.SignJwtRequest);
+      checkSignJwtRequest(od);
     });
   });
 
   unittest.group('obj-schema-SignJwtResponse', () {
     unittest.test('to-json--from-json', () async {
-      var o = buildSignJwtResponse();
-      var oJson = convert.jsonDecode(convert.jsonEncode(o));
-      var od = api.SignJwtResponse.fromJson(
+      final o = buildSignJwtResponse();
+      final oJson = convert.jsonDecode(convert.jsonEncode(o));
+      final od = api.SignJwtResponse.fromJson(
           oJson as core.Map<core.String, core.dynamic>);
-      checkSignJwtResponse(od as api.SignJwtResponse);
+      checkSignJwtResponse(od);
     });
   });
 
   unittest.group('resource-ProjectsServiceAccountsResource', () {
     unittest.test('method--generateAccessToken', () async {
-      var mock = HttpServerMock();
-      var res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
-      var arg_request = buildGenerateAccessTokenRequest();
-      var arg_name = 'foo';
-      var arg_$fields = 'foo';
+      final mock = HttpServerMock();
+      final res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
+      final arg_request = buildGenerateAccessTokenRequest();
+      final arg_name = 'foo';
+      final arg_$fields = 'foo';
       mock.register(unittest.expectAsync2((http.BaseRequest req, json) {
-        var obj = api.GenerateAccessTokenRequest.fromJson(
+        final obj = api.GenerateAccessTokenRequest.fromJson(
             json as core.Map<core.String, core.dynamic>);
-        checkGenerateAccessTokenRequest(obj as api.GenerateAccessTokenRequest);
+        checkGenerateAccessTokenRequest(obj);
 
-        var path = (req.url).path;
+        final path = req.url.path;
         var pathOffset = 0;
         core.int index;
         core.String subPart;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 1),
-          unittest.equals("/"),
+          unittest.equals('/'),
         );
         pathOffset += 1;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 3),
-          unittest.equals("v1/"),
+          unittest.equals('v1/'),
         );
         pathOffset += 3;
         // NOTE: We cannot test reserved expansions due to the inability to reverse the operation;
 
-        var query = (req.url).query;
+        final query = req.url.query;
         var queryOffset = 0;
-        var queryMap = <core.String, core.List<core.String>>{};
+        final queryMap = <core.String, core.List<core.String>>{};
         void addQueryParam(core.String n, core.String v) =>
             queryMap.putIfAbsent(n, () => []).add(v);
 
         if (query.isNotEmpty) {
           for (var part in query.split('&')) {
-            var keyValue = part.split('=');
+            final keyValue = part.split('=');
             addQueryParam(
               core.Uri.decodeQueryComponent(keyValue[0]),
               core.Uri.decodeQueryComponent(keyValue[1]),
@@ -450,14 +438,14 @@ void main() {
           }
         }
         unittest.expect(
-          queryMap["fields"]!.first,
+          queryMap['fields']!.first,
           unittest.equals(arg_$fields),
         );
 
-        var h = {
+        final h = {
           'content-type': 'application/json; charset=utf-8',
         };
-        var resp = convert.json.encode(buildGenerateAccessTokenResponse());
+        final resp = convert.json.encode(buildGenerateAccessTokenResponse());
         return async.Future.value(stringResponse(200, h, resp));
       }), true);
       final response = await res.generateAccessToken(arg_request, arg_name,
@@ -467,41 +455,41 @@ void main() {
     });
 
     unittest.test('method--generateIdToken', () async {
-      var mock = HttpServerMock();
-      var res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
-      var arg_request = buildGenerateIdTokenRequest();
-      var arg_name = 'foo';
-      var arg_$fields = 'foo';
+      final mock = HttpServerMock();
+      final res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
+      final arg_request = buildGenerateIdTokenRequest();
+      final arg_name = 'foo';
+      final arg_$fields = 'foo';
       mock.register(unittest.expectAsync2((http.BaseRequest req, json) {
-        var obj = api.GenerateIdTokenRequest.fromJson(
+        final obj = api.GenerateIdTokenRequest.fromJson(
             json as core.Map<core.String, core.dynamic>);
-        checkGenerateIdTokenRequest(obj as api.GenerateIdTokenRequest);
+        checkGenerateIdTokenRequest(obj);
 
-        var path = (req.url).path;
+        final path = req.url.path;
         var pathOffset = 0;
         core.int index;
         core.String subPart;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 1),
-          unittest.equals("/"),
+          unittest.equals('/'),
         );
         pathOffset += 1;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 3),
-          unittest.equals("v1/"),
+          unittest.equals('v1/'),
         );
         pathOffset += 3;
         // NOTE: We cannot test reserved expansions due to the inability to reverse the operation;
 
-        var query = (req.url).query;
+        final query = req.url.query;
         var queryOffset = 0;
-        var queryMap = <core.String, core.List<core.String>>{};
+        final queryMap = <core.String, core.List<core.String>>{};
         void addQueryParam(core.String n, core.String v) =>
             queryMap.putIfAbsent(n, () => []).add(v);
 
         if (query.isNotEmpty) {
           for (var part in query.split('&')) {
-            var keyValue = part.split('=');
+            final keyValue = part.split('=');
             addQueryParam(
               core.Uri.decodeQueryComponent(keyValue[0]),
               core.Uri.decodeQueryComponent(keyValue[1]),
@@ -509,14 +497,14 @@ void main() {
           }
         }
         unittest.expect(
-          queryMap["fields"]!.first,
+          queryMap['fields']!.first,
           unittest.equals(arg_$fields),
         );
 
-        var h = {
+        final h = {
           'content-type': 'application/json; charset=utf-8',
         };
-        var resp = convert.json.encode(buildGenerateIdTokenResponse());
+        final resp = convert.json.encode(buildGenerateIdTokenResponse());
         return async.Future.value(stringResponse(200, h, resp));
       }), true);
       final response = await res.generateIdToken(arg_request, arg_name,
@@ -525,41 +513,41 @@ void main() {
     });
 
     unittest.test('method--signBlob', () async {
-      var mock = HttpServerMock();
-      var res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
-      var arg_request = buildSignBlobRequest();
-      var arg_name = 'foo';
-      var arg_$fields = 'foo';
+      final mock = HttpServerMock();
+      final res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
+      final arg_request = buildSignBlobRequest();
+      final arg_name = 'foo';
+      final arg_$fields = 'foo';
       mock.register(unittest.expectAsync2((http.BaseRequest req, json) {
-        var obj = api.SignBlobRequest.fromJson(
+        final obj = api.SignBlobRequest.fromJson(
             json as core.Map<core.String, core.dynamic>);
-        checkSignBlobRequest(obj as api.SignBlobRequest);
+        checkSignBlobRequest(obj);
 
-        var path = (req.url).path;
+        final path = req.url.path;
         var pathOffset = 0;
         core.int index;
         core.String subPart;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 1),
-          unittest.equals("/"),
+          unittest.equals('/'),
         );
         pathOffset += 1;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 3),
-          unittest.equals("v1/"),
+          unittest.equals('v1/'),
         );
         pathOffset += 3;
         // NOTE: We cannot test reserved expansions due to the inability to reverse the operation;
 
-        var query = (req.url).query;
+        final query = req.url.query;
         var queryOffset = 0;
-        var queryMap = <core.String, core.List<core.String>>{};
+        final queryMap = <core.String, core.List<core.String>>{};
         void addQueryParam(core.String n, core.String v) =>
             queryMap.putIfAbsent(n, () => []).add(v);
 
         if (query.isNotEmpty) {
           for (var part in query.split('&')) {
-            var keyValue = part.split('=');
+            final keyValue = part.split('=');
             addQueryParam(
               core.Uri.decodeQueryComponent(keyValue[0]),
               core.Uri.decodeQueryComponent(keyValue[1]),
@@ -567,14 +555,14 @@ void main() {
           }
         }
         unittest.expect(
-          queryMap["fields"]!.first,
+          queryMap['fields']!.first,
           unittest.equals(arg_$fields),
         );
 
-        var h = {
+        final h = {
           'content-type': 'application/json; charset=utf-8',
         };
-        var resp = convert.json.encode(buildSignBlobResponse());
+        final resp = convert.json.encode(buildSignBlobResponse());
         return async.Future.value(stringResponse(200, h, resp));
       }), true);
       final response =
@@ -583,41 +571,41 @@ void main() {
     });
 
     unittest.test('method--signJwt', () async {
-      var mock = HttpServerMock();
-      var res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
-      var arg_request = buildSignJwtRequest();
-      var arg_name = 'foo';
-      var arg_$fields = 'foo';
+      final mock = HttpServerMock();
+      final res = api.IAMCredentialsApi(mock).projects.serviceAccounts;
+      final arg_request = buildSignJwtRequest();
+      final arg_name = 'foo';
+      final arg_$fields = 'foo';
       mock.register(unittest.expectAsync2((http.BaseRequest req, json) {
-        var obj = api.SignJwtRequest.fromJson(
+        final obj = api.SignJwtRequest.fromJson(
             json as core.Map<core.String, core.dynamic>);
-        checkSignJwtRequest(obj as api.SignJwtRequest);
+        checkSignJwtRequest(obj);
 
-        var path = (req.url).path;
+        final path = req.url.path;
         var pathOffset = 0;
         core.int index;
         core.String subPart;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 1),
-          unittest.equals("/"),
+          unittest.equals('/'),
         );
         pathOffset += 1;
         unittest.expect(
           path.substring(pathOffset, pathOffset + 3),
-          unittest.equals("v1/"),
+          unittest.equals('v1/'),
         );
         pathOffset += 3;
         // NOTE: We cannot test reserved expansions due to the inability to reverse the operation;
 
-        var query = (req.url).query;
+        final query = req.url.query;
         var queryOffset = 0;
-        var queryMap = <core.String, core.List<core.String>>{};
+        final queryMap = <core.String, core.List<core.String>>{};
         void addQueryParam(core.String n, core.String v) =>
             queryMap.putIfAbsent(n, () => []).add(v);
 
         if (query.isNotEmpty) {
           for (var part in query.split('&')) {
-            var keyValue = part.split('=');
+            final keyValue = part.split('=');
             addQueryParam(
               core.Uri.decodeQueryComponent(keyValue[0]),
               core.Uri.decodeQueryComponent(keyValue[1]),
@@ -625,14 +613,14 @@ void main() {
           }
         }
         unittest.expect(
-          queryMap["fields"]!.first,
+          queryMap['fields']!.first,
           unittest.equals(arg_$fields),
         );
 
-        var h = {
+        final h = {
           'content-type': 'application/json; charset=utf-8',
         };
-        var resp = convert.json.encode(buildSignJwtResponse());
+        final resp = convert.json.encode(buildSignJwtResponse());
         return async.Future.value(stringResponse(200, h, resp));
       }), true);
       final response =
