@@ -22,7 +22,7 @@ main() {
   });
 }
 
-/// TODO(scheglov) Move other for-in tests here.
+// TODO(scheglov): Move other for-in tests here.
 @reflectiveTest
 class ForStatementResolutionTest_ForEachPartsWithDeclaration
     extends PubPackageResolutionTest {
@@ -45,7 +45,7 @@ ForStatement
     loopVariable: DeclaredIdentifier
       type: NamedType
         name: int
-        element: dart:core::@class::int
+        element2: dart:core::@class::int
         type: int
       name: v
       declaredElement: v@56
@@ -54,7 +54,7 @@ ForStatement
     iterable: MethodInvocation
       methodName: SimpleIdentifier
         token: g
-        staticElement: self::@function::g
+        element: <testLibrary>::@function::g
         staticType: T Function<T>()
       argumentList: ArgumentList
         leftParenthesis: (
@@ -79,7 +79,7 @@ void f(dynamic values) {
       error(WarningCode.UNUSED_LOCAL_VARIABLE, 36, 1),
     ]);
 
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -93,7 +93,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: values
-      staticElement: self::@function::f::@parameter::values
+      element: <testLibraryFragment>::@function::f::@parameter::values#element
       staticType: dynamic
   rightParenthesis: )
   body: Block
@@ -127,7 +127,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: <empty> <synthetic>
-      staticElement: <null>
+      element: <null>
       staticType: InvalidType
   rightParenthesis: )
   body: Block
@@ -136,7 +136,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: v
-          staticElement: v@22
+          element: v@22
           staticType: InvalidType
         semicolon: ;
     rightBracket: }
@@ -155,7 +155,7 @@ abstract class A implements Iterable<int> {
       error(ParserErrorCode.MISSING_ASSIGNABLE_SELECTOR, 75, 5),
     ]);
 
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -193,7 +193,7 @@ ForStatement
     loopVariable: DeclaredIdentifier
       type: NamedType
         name: dynamic
-        element: dynamic@-1
+        element2: dynamic
         type: dynamic
       name: v
       declaredElement: v@42
@@ -201,7 +201,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: values
-      staticElement: self::@function::f::@parameter::values
+      element: <testLibraryFragment>::@function::f::@parameter::values#element
       staticType: List<int>
   rightParenthesis: )
   body: Block
@@ -210,7 +210,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: v
-          staticElement: v@42
+          element: v@42
           staticType: dynamic
         semicolon: ;
     rightBracket: }
@@ -242,7 +242,7 @@ ForStatement
     iterable: MethodInvocation
       methodName: SimpleIdentifier
         token: g
-        staticElement: self::@function::g
+        element: <testLibrary>::@function::g
         staticType: T Function<T>()
       argumentList: ArgumentList
         leftParenthesis: (
@@ -280,7 +280,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: values
-      staticElement: self::@function::f::@parameter::values
+      element: <testLibraryFragment>::@function::f::@parameter::values#element
       staticType: Iterable<int>
   rightParenthesis: )
   body: Block
@@ -289,7 +289,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: v
-          staticElement: v@42
+          element: v@42
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -318,7 +318,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: values
-      staticElement: self::@function::f::@parameter::values
+      element: <testLibraryFragment>::@function::f::@parameter::values#element
       staticType: List<int>
   rightParenthesis: )
   body: Block
@@ -327,7 +327,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: v
-          staticElement: v@38
+          element: v@38
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -356,7 +356,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: values
-      staticElement: self::@function::f::@parameter::values
+      element: <testLibraryFragment>::@function::f::@parameter::values#element
       staticType: Stream<int>
   rightParenthesis: )
   body: Block
@@ -365,7 +365,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: v
-          staticElement: v@52
+          element: v@52
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -397,18 +397,18 @@ ForStatement
     iterable: PrefixedIdentifier
       prefix: SimpleIdentifier
         token: x
-        staticElement: self::@function::f::@parameter::x
+        element: <testLibraryFragment>::@function::f::@parameter::x#element
         staticType: List<List<int>>
       period: .
       identifier: SimpleIdentifier
         token: first
-        staticElement: PropertyAccessorMember
-          base: dart:core::@class::Iterable::@getter::first
-          substitution: {E: List<int>, E: List<int>}
+        element: GetterMember
+          baseElement: dart:core::<fragment>::@class::Iterable::@getter::first#element
+          substitution: {E: List<int>}
         staticType: List<int>
-      staticElement: PropertyAccessorMember
-        base: dart:core::@class::Iterable::@getter::first
-        substitution: {E: List<int>, E: List<int>}
+      element: GetterMember
+        baseElement: dart:core::<fragment>::@class::Iterable::@getter::first#element
+        substitution: {E: List<int>}
       staticType: List<int>
   rightParenthesis: )
   body: Block
@@ -417,7 +417,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: x
-          staticElement: x@39
+          element: x@39
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -454,12 +454,12 @@ ForStatement
   forLoopParts: ForEachPartsWithIdentifier
     identifier: SimpleIdentifier
       token: v
-      staticElement: self::@function::f::@parameter::v
+      element: <testLibraryFragment>::@function::f::@parameter::v#element
       staticType: dynamic
     inKeyword: in
     iterable: SimpleIdentifier
       token: values
-      staticElement: self::@function::f::@parameter::values
+      element: <testLibraryFragment>::@function::f::@parameter::values#element
       staticType: List<int>
   rightParenthesis: )
   body: Block
@@ -468,7 +468,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: v
-          staticElement: self::@function::f::@parameter::v
+          element: <testLibraryFragment>::@function::f::@parameter::v#element
           staticType: dynamic
         semicolon: ;
     rightBracket: }
@@ -485,7 +485,7 @@ abstract class A implements Iterable<int> {
 ''', [
       error(ParserErrorCode.MISSING_ASSIGNABLE_SELECTOR, 76, 5),
     ]);
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -493,7 +493,7 @@ ForStatement
   forLoopParts: ForEachPartsWithIdentifier
     identifier: SimpleIdentifier
       token: v
-      staticElement: self::@class::A::@method::f::@parameter::v
+      element: <testLibraryFragment>::@class::A::@method::f::@parameter::v#element
       staticType: dynamic
     inKeyword: in
     iterable: SuperExpression
@@ -537,7 +537,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: dynamic
   rightParenthesis: )
   body: Block
@@ -546,7 +546,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@24
+          element: a@24
           staticType: dynamic
         semicolon: ;
     rightBracket: }
@@ -580,7 +580,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: List<int>
   rightParenthesis: )
   body: Block
@@ -589,7 +589,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@34
+          element: a@34
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -625,7 +625,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: Object
   rightParenthesis: )
   body: Block
@@ -634,7 +634,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@31
+          element: a@31
           staticType: InvalidType
         semicolon: ;
     rightBracket: }
@@ -652,7 +652,7 @@ abstract class A implements Iterable<int> {
       error(WarningCode.UNUSED_LOCAL_VARIABLE, 71, 1),
       error(ParserErrorCode.MISSING_ASSIGNABLE_SELECTOR, 77, 5),
     ]);
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -687,7 +687,7 @@ void f() {
 
 T g<T>() => throw 0;
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 27, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 27, 1),
     ]);
     var node = findNode.forStatement('for');
     assertResolvedNodeText(node, r'''
@@ -701,7 +701,7 @@ ForStatement
       pattern: DeclaredVariablePattern
         type: NamedType
           name: int
-          element: dart:core::@class::int
+          element2: dart:core::@class::int
           type: int
         name: a
         declaredElement: a@27
@@ -713,7 +713,7 @@ ForStatement
     iterable: MethodInvocation
       methodName: SimpleIdentifier
         token: g
-        staticElement: self::@function::g
+        element: <testLibrary>::@function::g
         staticType: T Function<T>()
       argumentList: ArgumentList
         leftParenthesis: (
@@ -737,7 +737,7 @@ void f() {
 
 T g<T>() => throw 0;
 ''', [
-      error(HintCode.UNUSED_LOCAL_VARIABLE, 23, 1),
+      error(WarningCode.UNUSED_LOCAL_VARIABLE, 23, 1),
     ]);
     var node = findNode.forStatement('for');
     assertResolvedNodeText(node, r'''
@@ -759,7 +759,7 @@ ForStatement
     iterable: MethodInvocation
       methodName: SimpleIdentifier
         token: g
-        staticElement: self::@function::g
+        element: <testLibrary>::@function::g
         staticType: T Function<T>()
       argumentList: ArgumentList
         leftParenthesis: (
@@ -802,7 +802,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: List<int>
   rightParenthesis: )
   body: Block
@@ -811,7 +811,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@36
+          element: a@36
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -838,7 +838,7 @@ ForStatement
       pattern: DeclaredVariablePattern
         type: NamedType
           name: num
-          element: dart:core::@class::num
+          element2: dart:core::@class::num
           type: num
         name: a
         declaredElement: a@38
@@ -849,7 +849,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: List<int>
   rightParenthesis: )
   body: Block
@@ -858,7 +858,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@38
+          element: a@38
           staticType: num
         semicolon: ;
     rightBracket: }
@@ -897,7 +897,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: dynamic
   rightParenthesis: )
   body: Block
@@ -906,7 +906,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@36
+          element: a@36
           staticType: dynamic
         semicolon: ;
     rightBracket: }
@@ -943,7 +943,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: Object
   rightParenthesis: )
   body: Block
@@ -952,7 +952,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@43
+          element: a@43
           staticType: InvalidType
         semicolon: ;
     rightBracket: }
@@ -987,7 +987,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: Stream<int>
   rightParenthesis: )
   body: Block
@@ -996,7 +996,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@48
+          element: a@48
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -1026,7 +1026,7 @@ ForStatement
       pattern: DeclaredVariablePattern
         type: NamedType
           name: int
-          element: dart:core::@class::int
+          element2: dart:core::@class::int
           type: int
         name: a
         declaredElement: a@39
@@ -1038,7 +1038,7 @@ ForStatement
     iterable: MethodInvocation
       methodName: SimpleIdentifier
         token: g
-        staticElement: self::@function::g
+        element: <testLibrary>::@function::g
         staticType: T Function<T>()
       argumentList: ArgumentList
         leftParenthesis: (
@@ -1054,7 +1054,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@39
+          element: a@39
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -1092,7 +1092,7 @@ ForStatement
     iterable: MethodInvocation
       methodName: SimpleIdentifier
         token: g
-        staticElement: self::@function::g
+        element: <testLibrary>::@function::g
         staticType: T Function<T>()
       argumentList: ArgumentList
         leftParenthesis: (
@@ -1108,7 +1108,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@35
+          element: a@35
           staticType: Object?
         semicolon: ;
     rightBracket: }
@@ -1143,7 +1143,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: Stream<int>
   rightParenthesis: )
   body: Block
@@ -1152,7 +1152,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@50
+          element: a@50
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -1180,7 +1180,7 @@ ForStatement
       pattern: DeclaredVariablePattern
         type: NamedType
           name: num
-          element: dart:core::@class::num
+          element2: dart:core::@class::num
           type: num
         name: a
         declaredElement: a@52
@@ -1191,7 +1191,7 @@ ForStatement
     inKeyword: in
     iterable: SimpleIdentifier
       token: x
-      staticElement: self::@function::f::@parameter::x
+      element: <testLibraryFragment>::@function::f::@parameter::x#element
       staticType: Stream<int>
   rightParenthesis: )
   body: Block
@@ -1200,7 +1200,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@52
+          element: a@52
           staticType: num
         semicolon: ;
     rightBracket: }
@@ -1218,7 +1218,7 @@ void f(bool Function() b) {
 }
 ''');
 
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -1228,12 +1228,12 @@ ForStatement
     condition: FunctionExpressionInvocation
       function: SimpleIdentifier
         token: b
-        staticElement: self::@function::f::@parameter::b
+        element: <testLibraryFragment>::@function::f::@parameter::b#element
         staticType: bool Function()
       argumentList: ArgumentList
         leftParenthesis: (
         rightParenthesis: )
-      staticElement: <null>
+      element: <null>
       staticInvokeType: bool Function()
       staticType: bool
     rightSeparator: ;
@@ -1254,7 +1254,7 @@ void f() {
 }
 ''');
 
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -1265,7 +1265,7 @@ ForStatement
         leftParenthesis: (
         pattern: AssignedVariablePattern
           name: a
-          element: a@17
+          element2: a@17
           matchedValueType: int
         rightParenthesis: )
         matchedValueType: int
@@ -1284,7 +1284,7 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@17
+          element: a@17
           staticType: int
         semicolon: ;
     rightBracket: }
@@ -1302,7 +1302,7 @@ class A {
       error(ParserErrorCode.MISSING_ASSIGNABLE_SELECTOR, 35, 5),
     ]);
 
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -1335,7 +1335,7 @@ void f((int, bool) x) {
 }
 ''');
 
-    final node = findNode.singleForStatement;
+    var node = findNode.singleForStatement;
     assertResolvedNodeText(node, r'''
 ForStatement
   forKeyword: for
@@ -1352,40 +1352,40 @@ ForStatement
               declaredElement: hasImplicitType a@36
                 type: int
               matchedValueType: int
-            element: <null>
+            element2: <null>
           PatternField
             pattern: DeclaredVariablePattern
               name: b
               declaredElement: hasImplicitType b@39
                 type: bool
               matchedValueType: bool
-            element: <null>
+            element2: <null>
         rightParenthesis: )
         matchedValueType: (int, bool)
       equals: =
       expression: SimpleIdentifier
         token: x
-        staticElement: self::@function::f::@parameter::x
+        element: <testLibraryFragment>::@function::f::@parameter::x#element
         staticType: (int, bool)
       patternTypeSchema: (_, _)
     leftSeparator: ;
     condition: SimpleIdentifier
       token: b
-      staticElement: b@39
+      element: b@39
       staticType: bool
     rightSeparator: ;
     updaters
       PostfixExpression
         operand: SimpleIdentifier
           token: a
-          staticElement: a@36
+          element: a@36
           staticType: null
         operator: --
-        readElement: a@36
+        readElement2: a@36
         readType: int
-        writeElement: a@36
+        writeElement2: a@36
         writeType: int
-        staticElement: dart:core::@class::num::@method::-
+        element: dart:core::<fragment>::@class::num::@method::-#element
         staticType: int
   rightParenthesis: )
   body: Block
@@ -1394,13 +1394,13 @@ ForStatement
       ExpressionStatement
         expression: SimpleIdentifier
           token: a
-          staticElement: a@36
+          element: a@36
           staticType: int
         semicolon: ;
       ExpressionStatement
         expression: SimpleIdentifier
           token: b
-          staticElement: b@39
+          element: b@39
           staticType: bool
         semicolon: ;
     rightBracket: }
